;;; variant-jis.el -- JIS variant kanji search & replace.

;; Copyright (C) 1996 KAWABATA, Taichi (kawabata@is.s.u-tokyo.ac.jp)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; see the file COPYING.  If not, write to
;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

;;; Commentary:

;;;
;;; $B0[BN;z8!:w!&CV49(B(JIS X 0208/JIS X 0212)
;;;
;;
;;  $B$3$N%G!<%?$rF~NO!"Ds6!$7$F2<$5$C$?EEAm8&$NH>ED$5$s$K46<UCW$7$^$9!#(B
;;
;;  $B!yCm0U!y(B
;;  
;;  $B$3$3$G8!:w!&CV49$,$G$-$k$N$O!"$"$/$^$G$b(BJIS X 0208/JIS X 0212$B$N5,(B
;;  $B3J=q$K5-:\$5$l$F$$$k0[BN;z4X78$K$"$k4A;z$N$_$G$9!#9q8l?35D2q$K$h$k(B
;;  $B4A;z$N=q$-49$($K$OBP1~$7$F$$$^$;$s!#(B
;;
;;
;;    $B9q8l?35D2q$N=q$-49$($NNc!'(B
;;
;;       $B0&M]"*0&M_(B
;;       $B0BPE"*0B0o(B
;;       $B0EfJ"*0E1F(B
;;       $B0EkV"*0E>'(B
;;

(require 'mini-menu)

(defvar jis-variant-alist
  '[
    (?$B0!(B ?$BP3(B)
    (?$B0"(B ?$(D5`(B ?$(DMd(B)
    (?$B0,(B ?$B=)(B ?$BcT(B)
    (?$B0-(B ?$BX((B)
    (?$B02(B ?$BiC(B)
    (?$B03(B ?$BrM(B)
    (?$B05(B ?$BTZ(B)
    (?$B0A(B ?$(D\G(B)
    (?$B0C(B ?$Bh?(B ?$(DXR(B)
    (?$B0O(B ?$BT#(B)
    (?$B0S(B ?$(D4_(B)
    (?$B0Y(B ?$B`*(B)
    (?$B0e(B ?$BnP(B)
    (?$B0i(B ?$B]Z(B)
    (?$B0l(B ?$BP!(B)
    (?$B0m(B ?$BTe(B)
    (?$B0p(B ?$BcK(B)
    (?$B0v(B ?$(DU}(B)
    (?$B0x(B ?$(D6r(B)
    (?$B0y(B ?$(D9c(B)
    (?$B0{(B ?$B];(B)
    (?$B0|(B ?$BU5(B)
    (?$B1"(B ?$(D1$(B ?$(DfH(B ?$(Dfa(B)
    (?$B1#(B ?$Bp,(B ?$(D04(B)
    (?$B1,(B ?$BRI(B)
    (?$B1/(B ?$(D0%(B)
    (?$B15(B ?$B]5(B)
    (?$B19(B ?$BV}(B ?$BV~(B)
    (?$B1C(B ?$BbO(B ?$(D8[(B)
    (?$B1D(B ?$BS[(B)
    (?$B1H(B ?$B[*(B)
    (?$B1I(B ?$B\F(B)
    (?$B1N(B ?$(DNI(B)
    (?$B1O(B ?$B1P(B)
    (?$B1P(B ?$B1O(B)
    (?$B1Q(B ?$(D1_(B)
    (?$B1R(B ?$BjL(B)
    (?$B1S(B ?$BRi(B)
    (?$B1X(B ?$Bqc(B)
    (?$B1Y(B ?$(D=j(B)
    (?$B1_(B ?$BT$(B)
    (?$B1k(B ?$(DIo(B ?$(DJ4(B)
    (?$B1l(B ?$B_](B)
    (?$B1m(B ?$(DlI(B)
    (?$B1n(B ?$(DK0(B)
    (?$B1p(B ?$Bgf(B ?$(D^l(B ?$(D^m(B)
    (?$B1t(B ?$(Dc<(B)
    (?$B1v(B ?$BsE(B)
    (?$B1x(B ?$(DF^(B)
    (?$B1|(B ?$BT|(B ?$(D;s(B)
    (?$B1}(B ?$BWH(B)
    (?$B1~(B ?$BXf(B)
    (?$B2"(B ?$(DBK(B)
    (?$B2$(B ?$B]?(B)
    (?$B2%(B ?$B]X(B)
    (?$B2)(B ?$Brt(B)
    (?$B2*(B ?$(Dl?(B)
    (?$B2-(B ?$BQU(B)
    (?$B2.(B ?$(DY2(B)
    (?$B2:(B ?$BcS(B)
    (?$B2<(B ?$(D0#(B)
    (?$B2>(B ?$BPq(B)
    (?$B2A(B ?$BQ+(B)
    (?$B2F(B ?$(D8d(B)
    (?$B2P(B ?$(D0\(B)
    (?$B2V(B ?$(DWG(B)
    (?$B2Z(B ?$(DYC(B)
    (?$B2^(B ?$Bkv(B)
    (?$B2c(B ?$(D[R(B)
    (?$B2e(B ?$BV6(B)
    (?$B2h(B ?$BaA(B)
    (?$B2q(B ?$BPr(B)
    (?$B2r(B ?$Bk;(B)
    (?$B2s(B ?$BQE(B)
    (?$B2t(B ?$(D3/(B)
    (?$B2u(B ?$BTU(B)
    (?$B2x(B ?$BW_(B)
    (?$B2{(B ?$BXg(B ?$(D\e(B)
    (?$B3((B ?$Bei(B)
    (?$B3*(B ?$Bj7(B)
    (?$B3,(B ?$(D8'(B)
    (?$B3-(B ?$(DZp(B)
    (?$B33(B ?$(D4G(B)
    (?$B36(B ?$(DHA(B)
    (?$B37(B ?$Bc((B)
    (?$B38(B ?$Bb5(B ?$Bhd(B)
    (?$B3A(B ?$(DC8(B)
    (?$B3B(B ?$BiZ(B)
    (?$B3C(B ?$Bnl(B)
    (?$B3H(B ?$BZ2(B ?$(D?\(B)
    (?$B3I(B ?$BYx(B ?$(D?k(B)
    (?$B3L(B ?$B]W(B ?$(D8^(B)
    (?$B3N(B ?$(DP!(B)
    (?$B3P(B ?$Bk4(B ?$(D]&(B)
    (?$B3X(B ?$BU\(B ?$BU](B ?$(DAW(B)
    (?$B3Y(B ?$BVV(B)
    (?$B3Z(B ?$B\[(B)
    (?$B3m(B ?$(De)(B)
    (?$B3v(B ?$Bc^(B ?$(DIG(B)
    (?$B3x(B ?$Bn](B)
    (?$B3y(B ?$(De`(B)
    (?$B3z(B ?$(D6Z(B ?$(DmN(B)
    (?$B3~(B ?$(DYW(B ?$(DY~(B ?$(DZ'(B)
    (?$B4!(B ?$Bdx(B ?$(D1F(B)
    (?$B4%(B ?$(D0;(B)
    (?$B4+(B ?$BR0(B)
    (?$B4,(B ?$BRK(B)
    (?$B4/(B ?$(D9E(B)
    (?$B44(B ?$(DD\(B)
    (?$B4>(B ?$(DEm(B)
    (?$B4?(B ?$B]D(B)
    (?$B4C(B ?$B^u(B)
    (?$B4F(B ?$(D^U(B)
    (?$B4L(B ?$Bf%(B ?$(DTl(B)
    (?$B4Q(B ?$Bk7(B)
    (?$B4R(B ?$Bk](B)
    (?$B4U(B ?$BoH(B ?$(Dd|(B)
    (?$B4X(B ?$Bop(B)
    (?$B4Y(B ?$Bo|(B)
    (?$B4[(B ?$B4\(B)
    (?$B4\(B ?$B4[(B)
    (?$B4`(B ?$BV^(B)
    (?$B4g(B ?$Brn(B ?$Bro(B)
    (?$B4i(B ?$Bpz(B)
    (?$B4o(B ?$BSZ(B)
    (?$B4q(B ?$BTt(B)
    (?$B4|(B ?$B[.(B)
    (?$B4}(B ?$B[w(B ?$(DEF(B)
    (?$B4~(B ?$BW1(B)
    (?$B5"(B ?$B]E(B ?$Bb'(B)
    (?$B5$(B ?$B]f(B ?$(DII(B)
    (?$B55(B ?$Bs}(B)
    (?$B56(B ?$BQ&(B)
    (?$B59(B ?$(D2u(B ?$(D:L(B)
    (?$B5:(B ?$BY&(B)
    (?$B5>(B ?$B`:(B)
    (?$B5B(B ?$(D[E(B)
    (?$B5C(B ?$(DQk(B)
    (?$B5E(B ?$(D3}(B)
    (?$B5J(B ?$(D6A(B)
    (?$B5Q(B ?$BRJ(B)
    (?$B5S(B ?$(D_x(B)
    (?$B5V(B ?$(D7M(B)
    (?$B5g(B ?$(DQd(B)
    (?$B5j(B ?$Bd}(B)
    (?$B5l(B ?$BgQ(B)
    (?$B5n(B ?$(D4U(B)
    (?$B5o(B ?$(D3*(B)
    (?$B5r(B ?$BZ!(B)
    (?$B5s(B ?$BZ)(B ?$BZ*(B)
    (?$B5u(B ?$(DZ<(B)
    (?$B5}(B ?$(D0A(B)
    (?$B5~(B ?$BP7(B)
    (?$B6"(B ?$(D1B(B)
    (?$B6)(B ?$(D4,(B)
    (?$B6.(B ?$BV7(B)
    (?$B64(B ?$BYQ(B)
    (?$B66(B ?$(DDi(B)
    (?$B67(B ?$BQW(B)
    (?$B69(B ?$B`E(B)
    (?$B6<(B ?$(DV)(B)
    (?$B6@(B ?$(DK9(B)
    (?$B6A(B ?$(D5;(B)
    (?$B6F(B ?$Bt!(B)
    (?$B6G(B ?$BZ|(B)
    (?$B6U(B ?$(D1G(B ?$(D>0(B)
    (?$B6W(B ?$(DKs(B ?$(DL6(B)
    (?$B6Z(B ?$(D]4(B)
    (?$B6h(B ?$BR?(B)
    (?$B6m(B ?$(D`T(B)
    (?$B6n(B ?$Bq\(B ?$B6o(B)
    (?$B6o(B ?$Bq\(B ?$B6n(B)
    (?$B6w(B ?$(D<M(B)
    (?$B7$(B ?$(DgV(B)
    (?$B7,(B ?$(DCI(B)
    (?$B7.(B ?$BR.(B ?$(D3n(B)
    (?$B70(B ?$(DZ%(B)
    (?$B72(B ?$Bf:(B)
    (?$B7<(B ?$(D^1(B)
    (?$B7B(B ?$BWM(B ?$Bmt(B)
    (?$B7C(B ?$BX*(B)
    (?$B7F(B ?$BX\(B)
    (?$B7H(B ?$BZ8(B ?$(DA)(B)
    (?$B7L(B ?$B^d(B ?$Bl0(B ?$(D;Y(B ?$(DP((B)
    (?$B7P(B ?$Be4(B)
    (?$B7Q(B ?$Bek(B)
    (?$B7R(B ?$(DTZ(B)
    (?$B7T(B ?$Bh3(B)
    (?$B7V(B ?$Bj%(B)
    (?$B7Z(B ?$BmK(B)
    (?$B7[(B ?$Bpt(B)
    (?$B7\(B ?$Bs1(B ?$(Dfx(B)
    (?$B7](B ?$Bi:(B ?$(DPv(B)
    (?$B7b(B ?$(DA#(B)
    (?$B7d(B ?$(Dfi(B)
    (?$B7g(B ?$Be~(B ?$(DTk(B)
    (?$B7h(B ?$BQS(B)
    (?$B7i(B ?$(DG8(B)
    (?$B7p(B ?$BQ-(B)
    (?$B7r(B ?$(D=2(B)
    (?$B7u(B ?$BQx(B ?$BQy(B ?$BQz(B ?$BQ{(B ?$Bn_(B)
    (?$B7w(B ?$BT!(B)
    (?$B8!(B ?$B\}(B)
    (?$B8"(B ?$B\^(B)
    (?$B8%(B ?$B`[(B)
    (?$B8)(B ?$BeQ(B)
    (?$B8-(B ?$(D_C(B)
    (?$B81(B ?$Bp*(B ?$(DP<(B)
    (?$B82(B ?$Bp}(B)
    (?$B83(B ?$Bqd(B ?$(Di<(B)
    (?$B84(B ?$(DO|(B ?$(Dl[(B)
    (?$B86(B ?$(D4K(B)
    (?$B87(B ?$BSn(B)
    (?$B8:(B ?$(D3"(B)
    (?$B8;(B ?$(D4R(B)
    (?$B8S(B ?$(DSi(B)
    (?$B8T(B ?$(DV4(B)
    (?$B8V(B ?$(DW[(B)
    (?$B8W(B ?$BiI(B ?$(DZ?(B)
    (?$B8](B ?$Bsi(B)
    (?$B8b(B ?$(D4m(B)
    (?$B8g(B ?$(D=D(B)
    (?$B8t(B ?$(DOF(B)
    (?$B8w(B ?$(DIE(B ?$(DIO(B)
    (?$B8z(B ?$BZC(B)
    (?$B8|(B ?$(D7`(B)
    (?$B9+(B ?$(D\-(B)
    (?$B9-(B ?$BW"(B)
    (?$B91(B ?$BWq(B)
    (?$B98(B ?$BZh(B)
    (?$B9=(B ?$(DC((B)
    (?$B9@(B ?$(DHl(B)
    (?$B9F(B ?$BcL(B ?$(DY|(B)
    (?$B9I(B ?$(DSx(B)
    (?$B9N(B ?$(DUl(B)
    (?$B9O(B ?$BRS(B ?$(D4S(B)
    (?$B9[(B ?$Bbh(B ?$BoJ(B ?$B9\(B)
    (?$B9\(B ?$Bbh(B ?$BoJ(B ?$B9[(B)
    (?$B9_(B ?$(D8_(B)
    (?$B9e(B ?$BQg(B)
    (?$B9f(B ?$BiK(B)
    (?$B9l(B ?$BmD(B)
    (?$B9m(B ?$(Dlo(B)
    (?$B9q(B ?$BT"(B)
    (?$B9r(B ?$(DS@(B)
    (?$B:%(B ?$(D7z(B)
    (?$B:*(B ?$(DB*(B)
    (?$B:7(B ?$BVM(B)
    (?$B:?(B ?$(De<(B)
    (?$B:G(B ?$(D2w(B)
    (?$B:P(B ?$(D0?(B)
    (?$B:Q(B ?$B_;(B)
    (?$B:R(B ?$(DIH(B ?$(DI](B)
    (?$B:U(B ?$Bbl(B)
    (?$B:X(B ?$Bc7(B)
    (?$B:^(B ?$BQ}(B)
    (?$B:b(B ?$BlC(B)
    (?$B:c(B ?$BQT(B ?$B]l(B)
    (?$B:d(B ?$B:e(B)
    (?$B:e(B ?$B:d(B)
    (?$B:j(B ?$BV?(B ?$B:k(B ?$B:l(B)
    (?$B:k(B ?$BV?(B ?$B:j(B ?$B:l(B)
    (?$B:l(B ?$BV?(B ?$B:j(B ?$B:k(B)
    (?$B:m(B ?$(Dkk(B)
    (?$B:v(B ?$(DQw(B)
    (?$B:y(B ?$B]/(B)
    (?$B:}(B ?$BQF(B)
    (?$B;&(B ?$(DI}(B)
    (?$B;((B ?$Bp8(B)
    (?$B;)(B ?$Bb((B)
    (?$B;/(B ?$(DBk(B)
    (?$B;0(B ?$(D<`(B)
    (?$B;1(B ?$(D0D(B)
    (?$B;2(B ?$BRT(B ?$(D4X(B)
    (?$B;4(B ?$BXN(B)
    (?$B;7(B ?$B\"(B)
    (?$B;=(B ?$BjD(B ?$(D[-(B ?$(D\!(B)
    (?$B;>(B ?$Bl-(B)
    (?$B;?(B ?$BlU(B)
    (?$B;A(B ?$(DhH(B)
    (?$B;D(B ?$B]L(B)
    (?$B;M(B ?$(D0>(B)
    (?$B;O(B ?$(D07(B ?$(D2k(B)
    (?$B;P(B ?$(D9=(B)
    (?$B;W(B ?$(D=e(B)
    (?$B;e(B ?$Be/(B)
    (?$B;f(B ?$BVc(B)
    (?$B;k(B ?$(DN](B)
    (?$B;u(B ?$Bso(B)
    (?$B;v(B ?$BP/(B ?$(D4[(B)
    (?$B;w(B ?$(D0f(B)
    (?$B;y(B ?$BQ;(B)
    (?$B;~(B ?$(DAr(B)
    (?$B<$(B ?$BUu(B ?$(D0^(B ?$(D0_(B ?$(D2X(B ?$(D={(B)
    (?$B<%(B ?$(D8U(B)
    (?$B<'(B ?$(DPC(B)
    (?$B<-(B ?$Bmf(B ?$(Da-(B ?$(Da0(B)
    (?$B<>(B ?$B_<(B)
    (?$B<?(B ?$(DCj(B)
    (?$B<A(B ?$BlD(B ?$(D3S(B)
    (?$B<B(B ?$BUi(B)
    (?$B<D(B ?$Bd,(B)
    (?$B<H(B ?$(D:z(B)
    (?$B<I(B ?$Bi"(B ?$Bi#(B)
    (?$B<K(B ?$BgR(B)
    (?$B<L(B ?$BQP(B ?$BUm(B)
    (?$B<X(B ?$(DZH(B)
    (?$B<a(B ?$BnY(B)
    (?$B<i(B ?$(D7b(B)
    (?$B<v(B ?$BRp(B)
    (?$B<w(B ?$BTh(B)
    (?$B<}(B ?$BZ@(B)
    (?$B=$(B ?$(D1C(B)
    (?$B=)(B ?$B0,(B ?$BcT(B)
    (?$B=+(B ?$(DTW(B)
    (?$B=-(B ?$(DVd(B)
    (?$B=0(B ?$(DNo(B)
    (?$B=2(B ?$Bl((B)
    (?$B=6(B ?$(Dbl(B)
    (?$B=7(B ?$(Db^(B ?$(Db{(B)
    (?$B=>(B ?$BWO(B)
    (?$B=B(B ?$B_'(B ?$B_((B ?$(DE{(B)
    (?$B=C(B ?$B`Y(B)
    (?$B=D(B ?$BeT(B)
    (?$B=M(B ?$Bfi(B)
    (?$B=U(B ?$(DAs(B)
    (?$B=_(B ?$(DH%(B)
    (?$B=`(B ?$BRE(B)
    (?$B=f(B ?$(Dbm(B)
    (?$B=h(B ?$BQ](B)
    (?$B=v(B ?$BZF(B ?$BZG(B)
    (?$B>"(B ?$(D4'(B)
    (?$B>'(B ?$(D]}(B)
    (?$B>((B ?$Ba3(B)
    (?$B>)(B ?$BT}(B ?$B`R(B)
    (?$B>-(B ?$BUr(B)
    (?$B>3(B ?$BRR(B)
    (?$B>:(B ?$(DB?(B)
    (?$B>>(B ?$B[@(B ?$(DC@(B ?$(DCu(B)
    (?$B>F(B ?$B_v(B)
    (?$B>H(B ?$(DBc(B ?$(DO;(B)
    (?$B>N(B ?$BcJ(B ?$(DQM(B)
    (?$B>U(B ?$(DY6(B)
    (?$B>Z(B ?$Bkz(B)
    (?$B>_(B ?$(Dbs(B)
    (?$B>e(B ?$(D0"(B)
    (?$B>h(B ?$BP+(B ?$(DD6(B)
    (?$B>j(B ?$BQt(B)
    (?$B>l(B ?$BTG(B)
    (?$B>m(B ?$BTa(B)
    (?$B>n(B ?$BUP(B)
    (?$B>r(B ?$B[j(B)
    (?$B>t(B ?$B^F(B)
    (?$B>v(B ?$BaH(B ?$BaI(B ?$BaJ(B ?$(D4`(B)
    (?$B>w(B ?$BcU(B)
    (?$B>y(B ?$Bl*(B)
    (?$B>z(B ?$BnV(B)
    (?$B>|(B ?$BSv(B)
    (?$B?&(B ?$(DUb(B ?$(D`W(B)
    (?$B?((B ?$Bk=(B)
    (?$B?.(B ?$(D]P(B)
    (?$B?0(B ?$Bf|(B)
    (?$B?2(B ?$BUj(B)
    (?$B?3(B ?$(D:X(B)
    (?$B?4(B ?$(D=8(B)
    (?$B?5(B ?$BXF(B)
    (?$B?8(B ?$BZi(B)
    (?$B??(B ?$BbC(B)
    (?$B?O(B ?$BQc(B)
    (?$B?T(B ?$Bb8(B)
    (?$B?Y(B ?$BpV(B ?$BpW(B)
    (?$B?](B ?$BnL(B)
    (?$B?^(B ?$BT&(B)
    (?$B?_(B ?$BW$(B ?$(DE4(B)
    (?$B?b(B ?$BT1(B)
    (?$B?h(B ?$Bdo(B)
    (?$B?i(B ?$BfC(B)
    (?$B?l(B ?$BnM(B)
    (?$B?o(B ?$Bn.(B)
    (?$B?q(B ?$Bg;(B ?$Bqr(B)
    (?$B?t(B ?$BZK(B)
    (?$B?u(B ?$B\d(B)
    (?$B?w(B ?$(Dl4(B)
    (?$B?y(B ?$(DE9(B)
    (?$B@$(B ?$BRB(B ?$(D48(B)
    (?$B@&(B ?$Ba<(B ?$(DM6(B ?$(DM8(B)
    (?$B@'(B ?$(DB,(B)
    (?$B@((B ?$B^G(B)
    (?$B@,(B ?$(D=5(B)
    (?$B@1(B ?$(DNE(B)
    (?$B@2(B ?$(DBQ(B)
    (?$B@3(B ?$B@4(B ?$(D@$(B)
    (?$B@4(B ?$B@3(B ?$(D@$(B)
    (?$B@;(B ?$(D7c(B)
    (?$B@<(B ?$Bfa(B)
    (?$B@E(B ?$BpP(B)
    (?$B@F(B ?$Bsn(B ?$(D0@(B ?$(DAX(B)
    (?$B@H(B ?$(DV((B ?$(DV5(B)
    (?$B@\(B ?$(DA((B)
    (?$B@](B ?$BYp(B)
    (?$B@`(B ?$Bcf(B)
    (?$B@l(B ?$BUs(B)
    (?$B@o(B ?$BY%(B)
    (?$B@u(B ?$B^I(B)
    (?$B@x(B ?$B_*(B ?$B_+(B)
    (?$B@~(B ?$Be@(B)
    (?$BA!(B ?$Bey(B ?$Bez(B)
    (?$BA%(B ?$BgU(B)
    (?$BA((B ?$BlM(B)
    (?$BA)(B ?$Blx(B)
    (?$BA+(B ?$(Da8(B)
    (?$BA,(B ?$Bo"(B)
    (?$BA1(B ?$BfA(B)
    (?$BA5(B ?$Bc8(B)
    (?$BA7(B ?$(Dhm(B)
    (?$BA:(B ?$(D81(B)
    (?$BA=(B ?$BA>(B)
    (?$BA>(B ?$BA=(B)
    (?$BAB(B ?$Bls(B)
    (?$BAI(B ?$Bi?(B)
    (?$BAL(B ?$B^j(B)
    (?$BAM(B ?$Bsk(B)
    (?$BAO(B ?$(D?.(B)
    (?$BAP(B ?$BRV(B)
    (?$BAQ(B ?$(DE"(B ?$(DYo(B)
    (?$BAT(B ?$BTc(B)
    (?$BA\(B ?$BYS(B)
    (?$BA](B ?$(D7w(B)
    (?$BA^(B ?$BYg(B)
    (?$BA_(B ?$(D@K(B)
    (?$BA`(B ?$(D@v(B)
    (?$BAb(B ?$(DBm(B)
    (?$BAh(B ?$B`'(B)
    (?$BAi(B ?$(DMw(B)
    (?$BAk(B ?$BcY(B ?$(D6|(B ?$(DJQ(B ?$(DJU(B ?$(DQb(B)
    (?$BAm(B ?$BeA(B ?$(D@d(B ?$(DT8(B)
    (?$BAo(B ?$Bfb(B ?$(DUf(B)
    (?$BAq(B ?$Bh7(B)
    (?$BAr(B ?$(D83(B)
    (?$BAu(B ?$Bjf(B)
    (?$BAv(B ?$Bla(B)
    (?$BA{(B ?$Bq[(B)
    (?$BB!(B ?$BgG(B)
    (?$BB"(B ?$Bi6(B ?$(D4+(B)
    (?$BB((B ?$(DN8(B)
    (?$BB0(B ?$BV$(B)
    (?$BB3(B ?$Bet(B ?$(D_5(B)
    (?$BB4(B ?$BR@(B)
    (?$BB6(B ?$(D0$(B)
    (?$BB?(B ?$BTl(B)
    (?$BBD(B ?$BTX(B)
    (?$BBH(B ?$BBI(B)
    (?$BBI(B ?$BBH(B)
    (?$BBJ(B ?$B\s(B)
    (?$BBK(B ?$(D7D(B ?$(DfS(B)
    (?$BBN(B ?$Bm<(B ?$Bm=(B ?$Bqs(B ?$(Di\(B)
    (?$BBP(B ?$BUt(B)
    (?$BBS(B ?$BVh(B)
    (?$BBY(B ?$(D8n(B)
    (?$BBZ(B ?$B^|(B)
    (?$BB^(B ?$(D<'(B)
    (?$BBd(B ?$(DjW(B)
    (?$BBf(B ?$(D7G(B)
    (?$BBl(B ?$BBm(B)
    (?$BBm(B ?$BBl(B)
    (?$BBn(B ?$(DC[(B)
    (?$BBr(B ?$BZ$(B)
    (?$BBt(B ?$B_7(B)
    (?$BBx(B ?$Bne(B)
    (?$BC#(B ?$Bm}(B)
    (?$BC((B ?$Bl3(B)
    (?$BC,(B ?$Bl>(B ?$(DK'(B)
    (?$BC1(B ?$BSE(B ?$(D6<(B)
    (?$BC4(B ?$BY?(B)
    (?$BC?(B ?$(D`N(B)
    (?$BC@(B ?$Bg<(B ?$(DVT(B)
    (?$BCC(B ?$(DIs(B)
    (?$BCD(B ?$BT%(B)
    (?$BCF(B ?$BW<(B)
    (?$BCG(B ?$BZR(B)
    (?$BCK(B ?$(D14(B)
    (?$BCQ(B ?$BfW(B)
    (?$BCT(B ?$Baw(B)
    (?$BCU(B ?$BcP(B ?$(DQ>(B)
    (?$BCY(B ?$Bn/(B)
    (?$BCk(B ?$BZl(B)
    (?$BCn(B ?$Bj5(B)
    (?$BCr(B ?$BoI(B)
    (?$BCu(B ?$B_L(B)
    (?$BCv(B ?$Bl7(B)
    (?$BD"(B ?$(D_7(B)
    (?$BD#(B ?$BW,(B ?$BW-(B)
    (?$BD.(B ?$Ba6(B)
    (?$BD0(B ?$Bfe(B)
    (?$BD1(B ?$(DM_(B)
    (?$BD2(B ?$Bg6(B)
    (?$BD8(B ?$(Dei(B)
    (?$BD9(B ?$(D2g(B ?$(De}(B)
    (?$BD<(B ?$BZE(B)
    (?$BD@(B ?$(DFl(B)
    (?$BDA(B ?$B`_(B)
    (?$BDC(B ?$Bo/(B)
    (?$BDG(B ?$(DC^(B)
    (?$BDO(B ?$(D@[(B)
    (?$BDV(B ?$(D4\(B)
    (?$BD[(B ?$BTd(B)
    (?$BDa(B ?$(Dg0(B ?$(Dg1(B ?$(DlU(B)
    (?$BDc(B ?$(D0P(B)
    (?$BDf(B ?$(Di{(B)
    (?$BDi(B ?$(D7m(B)
    (?$BDv(B ?$(DD<(B ?$(DOK(B)
    (?$BD}(B ?$(D`0(B)
    (?$BD~(B ?$Bn*(B)
    (?$BE$(B ?$(Dm((B)
    (?$BE%(B ?$(D7F(B)
    (?$BE/(B ?$(D5h(B ?$(D6](B)
    (?$BE4(B ?$Bnn(B ?$BoD(B ?$BoE(B ?$(DdL(B)
    (?$BE6(B ?$(D84(B)
    (?$BE:(B ?$(DFo(B)
    (?$BE;(B ?$Beu(B)
    (?$BE>(B ?$Bm[(B)
    (?$BE?(B ?$(Dh3(B)
    (?$BE@(B ?$BsZ(B)
    (?$BEA(B ?$BQ#(B)
    (?$BEF(B ?$BEQ(B ?$BQ=(B ?$Bh9(B)
    (?$BEJ(B ?$(D9+(B)
    (?$BEP(B ?$(D2<(B)
    (?$BEQ(B ?$BEF(B ?$BQ=(B ?$Bh9(B)
    (?$BEV(B ?$(D4F(B)
    (?$BEW(B ?$Bbj(B)
    (?$BEX(B ?$(D0](B)
    (?$BE^(B ?$Bs^(B)
    (?$BEa(B ?$(D32(B)
    (?$BEc(B ?$(D8F(B)
    (?$BEg(B ?$BV:(B ?$BEh(B)
    (?$BEh(B ?$BV:(B ?$BEg(B)
    (?$BEn(B ?$B[m(B)
    (?$BEp(B ?$B]9(B)
    (?$BEs(B ?$B^9(B)
    (?$BEt(B ?$BEu(B)
    (?$BEu(B ?$BEt(B)
    (?$BEv(B ?$BaD(B)
    (?$BEx(B ?$(DPp(B)
    (?$BE}(B ?$(DSs(B)
    (?$BF((B ?$Bmm(B)
    (?$BF.(B ?$Br,(B ?$(Dj0(B ?$(Dj2(B)
    (?$BF/(B ?$BP>(B)
    (?$BF;(B ?$(D6S(B ?$(D\0(B ?$(D\1(B)
    (?$BFB(B ?$(DI,(B)
    (?$BFH(B ?$B`W(B)
    (?$BFI(B ?$Bl&(B)
    (?$BFJ(B ?$B[=(B)
    (?$BFM(B ?$(D:J(B)
    (?$BFO(B ?$BU|(B)
    (?$BFS(B ?$(D0'(B)
    (?$BFZ(B ?$(D^o(B)
    (?$BF`(B ?$(DCE(B)
    (?$BFl(B ?$Bej(B)
    (?$BFo(B ?$(DC*(B)
    (?$BFs(B ?$BP1(B)
    (?$BFu(B ?$BlH(B ?$BlI(B)
    (?$BFv(B ?$Bmn(B)
    (?$BG#(B ?$Bpl(B)
    (?$BG%(B ?$BU,(B)
    (?$BG)(B ?$BG*(B)
    (?$BG*(B ?$BG)(B)
    (?$BG+(B ?$(D:](B)
    (?$BG,(B ?$(DY8(B)
    (?$BG-(B ?$(D_%(B)
    (?$BG/(B ?$(DPx(B)
    (?$BG6(B ?$Bmr(B)
    (?$BG8(B ?$BLn(B ?$(D8O(B)
    (?$BG9(B ?$(D6l(B)
    (?$BG:(B ?$BX=(B)
    (?$BG>(B ?$Bg*(B ?$(D4$(B)
    (?$BGF(B ?$B[1(B ?$(DI@(B)
    (?$BGM(B ?$(D5|(B)
    (?$BGQ(B ?$BW&(B)
    (?$BGR(B ?$BYA(B)
    (?$BGT(B ?$(D_@(B)
    (?$BGU(B ?$BGV(B)
    (?$BGV(B ?$BGU(B)
    (?$BGZ(B ?$(D`_(B)
    (?$BG_(B ?$BG`(B ?$(DDg(B)
    (?$BG`(B ?$BG_(B ?$(DDg(B)
    (?$BGd(B ?$BlN(B)
    (?$BGh(B ?$Bj$(B)
    (?$BGj(B ?$(DOE(B ?$(D]L(B)
    (?$BG~(B ?$BsN(B)
    (?$BH!(B ?$BQb(B)
    (?$BH%(B ?$(DUk(B)
    (?$BH-(B ?$(DTm(B)
    (?$BH.(B ?$(DHU(B)
    (?$BH/(B ?$Bb$(B)
    (?$BH0(B ?$(Dbw(B)
    (?$BH1(B ?$Bq{(B)
    (?$BH2(B ?$(D2)(B ?$(DJ](B)
    (?$BH3(B ?$Bf/(B)
    (?$BH4(B ?$BY6(B)
    (?$BH5(B ?$(DCS(B)
    (?$BHZ(B ?$BjG(B)
    (?$BHf(B ?$(D8p(B)
    (?$BHk(B ?$Bc0(B)
    (?$BHw(B ?$(D23(B)
    (?$BI#(B ?$(DYt(B)
    (?$BI&(B ?$(Dh)(B)
    (?$BI+(B ?$(D<o(B)
    (?$BI.(B ?$(DQt(B)
    (?$BI/(B ?$(D1r(B)
    (?$BI0(B ?$B[X(B)
    (?$BI9(B ?$BQV(B)
    (?$BI@(B ?$(D<O(B)
    (?$BIK(B ?$BIL(B ?$(D0O(B)
    (?$BIL(B ?$BIK(B ?$(D0O(B)
    (?$BIM(B ?$B_@(B ?$(DI&(B)
    (?$BIR(B ?$(D3f(B)
    (?$BIY(B ?$BIZ(B)
    (?$BIZ(B ?$BIY(B)
    (?$BI](B ?$(D=r(B)
    (?$BI_(B ?$(DAg(B)
    (?$BIa(B ?$(DBU(B)
    (?$BIt(B ?$(Db.(B)
    (?$BIw(B ?$(D3+(B ?$(DhG(B)
    (?$BJ%(B ?$B^<(B ?$B^=(B ?$(D6y(B)
    (?$BJ'(B ?$BYD(B)
    (?$BJ)(B ?$BPG(B)
    (?$BJ2(B ?$(DJ6(B ?$(DJ7(B)
    (?$BJ>(B ?$BVr(B)
    (?$BJB(B ?$Bcm(B ?$(D2*(B)
    (?$BJD(B ?$BoZ(B)
    (?$BJO(B ?$BdD(B)
    (?$BJQ(B ?$BZN(B)
    (?$BJU(B ?$Bn4(B ?$Bn5(B)
    (?$BJ[(B ?$BQ~(B ?$BR!(B ?$Ba"(B ?$Bmg(B)
    (?$BJ^(B ?$BgT(B)
    (?$BJ`(B ?$(D7((B)
    (?$BJe(B ?$(D1=(B)
    (?$BJf(B ?$BcO(B)
    (?$BJu(B ?$BUo(B ?$BUp(B ?$(D:c(B)
    (?$BJv(B ?$BJw(B)
    (?$BJw(B ?$BJv(B)
    (?$BK!(B ?$(D0u(B ?$(DI<(B)
    (?$BK((B ?$BhN(B)
    (?$BK*(B ?$(D[z(B)
    (?$BK+(B ?$Bjq(B ?$(D\K(B)
    (?$BK-(B ?$Bl4(B)
    (?$BK4(B ?$(D2n(B)
    (?$BK9(B ?$(D2p(B)
    (?$BK;(B ?$(D=k(B)
    (?$BKA(B ?$Bfn(B)
    (?$BKF(B ?$Bb&(B)
    (?$BKK(B ?$(Dh$(B)
    (?$BKW(B ?$B]s(B)
    (?$BKZ(B ?$(DTH(B)
    (?$BK\(B ?$BTq(B)
    (?$BK](B ?$BfL(B)
    (?$BK^(B ?$(D3)(B)
    (?$BK`(B ?$(DA1(B)
    (?$BKc(B ?$(DY>(B)
    (?$BKj(B ?$Bt"(B)
    (?$BKq(B ?$B[F(B)
    (?$BKy(B ?$BPV(B)
    (?$BKz(B ?$(DSn(B ?$(D[p(B)
    (?$BK|(B ?$Bh_(B)
    (?$BK~(B ?$B^`(B)
    (?$BL!(B ?$(DJ/(B)
    (?$BL+(B ?$(D3#(B)
    (?$BL,(B ?$BdB(B ?$BdC(B)
    (?$BL.(B ?$Bfw(B)
    (?$BL/(B ?$(DKP(B)
    (?$BL4(B ?$BTm(B ?$(D8i(B)
    (?$BL8(B ?$(Df}(B ?$(Dg$(B)
    (?$BL;(B ?$BTf(B ?$Bf](B)
    (?$BL@(B ?$(DBr(B)
    (?$BLE(B ?$(D96(B)
    (?$BLL(B ?$(Dg7(B)
    (?$BLM(B ?$BsQ(B ?$(Dlp(B)
    (?$BL[(B ?$B`T(B)
    (?$BL_(B ?$Bq6(B)
    (?$BLn(B ?$BG8(B ?$(D8O(B)
    (?$BLo(B ?$BW=(B)
    (?$BLt(B ?$Bi;(B)
    (?$BLu(B ?$Bl#(B)
    (?$BLx(B ?$(DCh(B)
    (?$BLy(B ?$BdX(B ?$Bi.(B)
    (?$BL~(B ?$Bah(B)
    (?$BM&(B ?$(D3h(B)
    (?$BM/(B ?$BM0(B)
    (?$BM0(B ?$BM/(B)
    (?$BM6(B ?$(D5E(B)
    (?$BM=(B ?$BP.(B)
    (?$BM>(B ?$Bq1(B)
    (?$BM?(B ?$BgP(B)
    (?$BM@(B ?$Bl%(B)
    (?$BMI(B ?$BYj(B)
    (?$BMM(B ?$B\k(B)
    (?$BMR(B ?$Bc_(B ?$(DQY(B)
    (?$BMT(B ?$B`"(B)
    (?$BMX(B ?$Bko(B)
    (?$BMY(B ?$Bl}(B)
    (?$BMZ(B ?$Bt#(B)
    (?$BM[(B ?$(DfI(B ?$(DfL(B)
    (?$BM\(B ?$(DU1(B)
    (?$BMh(B ?$BPT(B)
    (?$BMi(B ?$(DXG(B)
    (?$BMk(B ?$(Dg-(B)
    (?$BMp(B ?$BP,(B)
    (?$BMs(B ?$(DEe(B)
    (?$BMw(B ?$Bk5(B)
    (?$BN((B ?$(D4:(B)
    (?$BN,(B ?$Ba@(B)
    (?$BN-(B ?$(D37(B)
    (?$BN/(B ?$B_1(B)
    (?$BN1(B ?$Ba7(B ?$(DM<(B)
    (?$BN5(B ?$BN6(B ?$(Dm[(B)
    (?$BN6(B ?$BN5(B ?$(Dm[(B)
    (?$BN:(B ?$(DA!(B)
    (?$BN>(B ?$BQ@(B ?$(D0((B)
    (?$BNB(B ?$(DDv(B)
    (?$BNC(B ?$BQZ(B)
    (?$BND(B ?$B`Z(B)
    (?$BNF(B ?$B["(B)
    (?$BNH(B ?$Bdn(B)
    (?$BNU(B ?$(DS2(B)
    (?$BNY(B ?$BnC(B ?$(D4T(B)
    (?$BN\(B ?$B`e(B)
    (?$BN](B ?$BT^(B ?$(DMB(B)
    (?$BN^(B ?$B^%(B)
    (?$BNe(B ?$BR/(B)
    (?$BNi(B ?$Bc9(B)
    (?$BNl(B ?$Bp1(B)
    (?$BNn(B ?$BpM(B ?$(DIF(B ?$(Dg%(B)
    (?$BNp(B ?$Bst(B)
    (?$BNq(B ?$(D4O(B)
    (?$BNx(B ?$BXx(B)
    (?$BN~(B ?$Bf_(B)
    (?$BO'(B ?$B`$(B)
    (?$BO+(B ?$BR)(B)
    (?$BO,(B ?$(D9M(B)
    (?$BO.(B ?$(D?](B ?$(D?g(B)
    (?$BO/(B ?$B[-(B)
    (?$BO0(B ?$B\l(B)
    (?$BO6(B ?$BdF(B)
    (?$BO9(B ?$(D[x(B)
    (?$BO:(B ?$(Db-(B)
    (?$BO=(B ?$Bc3(B)
    (?$BOB(B ?$(Dma(B)
    (?$BOJ(B ?$BOK(B)
    (?$BOK(B ?$BOJ(B)
    (?$BOQ(B ?$B_T(B)
    (?$BOR(B ?$(D7o(B)
    (?$BP!(B ?$B0l(B)
    (?$BP+(B ?$B>h(B ?$(DD6(B)
    (?$BP,(B ?$BMp(B)
    (?$BP.(B ?$BM=(B)
    (?$BP/(B ?$B;v(B ?$(D4[(B)
    (?$BP1(B ?$BFs(B)
    (?$BP3(B ?$B0!(B)
    (?$BP4(B ?$(DIi(B)
    (?$BP7(B ?$B5~(B)
    (?$BP>(B ?$BF/(B)
    (?$BP@(B ?$BPA(B)
    (?$BPA(B ?$BP@(B)
    (?$BPG(B ?$BJ)(B)
    (?$BPT(B ?$BMh(B)
    (?$BPV(B ?$BKy(B)
    (?$BPW(B ?$(D=s(B)
    (?$BPY(B ?$B`,(B)
    (?$BPf(B ?$BPg(B)
    (?$BPg(B ?$BPf(B)
    (?$BPq(B ?$B2>(B)
    (?$BPr(B ?$B2q(B)
    (?$BPx(B ?$(D2-(B)
    (?$BP{(B ?$(D1E(B)
    (?$BQ#(B ?$BEA(B)
    (?$BQ&(B ?$B56(B)
    (?$BQ((B ?$BQ)(B)
    (?$BQ)(B ?$BQ((B)
    (?$BQ+(B ?$B2A(B)
    (?$BQ-(B ?$B7p(B)
    (?$BQ;(B ?$B;y(B)
    (?$BQ<(B ?$(D2f(B)
    (?$BQ=(B ?$BEF(B ?$BEQ(B ?$Bh9(B)
    (?$BQ@(B ?$BN>(B ?$(D0((B)
    (?$BQC(B ?$(D2o(B)
    (?$BQD(B ?$(D2r(B)
    (?$BQE(B ?$B2s(B)
    (?$BQF(B ?$B:}(B)
    (?$BQG(B ?$(D2q(B)
    (?$BQH(B ?$(D6z(B)
    (?$BQM(B ?$BUc(B)
    (?$BQN(B ?$BUd(B ?$(D:Z(B)
    (?$BQP(B ?$B<L(B ?$BUm(B)
    (?$BQQ(B ?$Bf2(B)
    (?$BQS(B ?$B7h(B)
    (?$BQT(B ?$B:c(B ?$B]l(B)
    (?$BQU(B ?$B2-(B)
    (?$BQV(B ?$BI9(B)
    (?$BQW(B ?$B67(B)
    (?$BQX(B ?$B^0(B)
    (?$BQY(B ?$B^A(B)
    (?$BQZ(B ?$BNC(B)
    (?$BQ[(B ?$Bt%(B)
    (?$BQ](B ?$B=h(B)
    (?$BQb(B ?$BH!(B)
    (?$BQc(B ?$B?O(B)
    (?$BQg(B ?$B9e(B)
    (?$BQn(B ?$BUq(B)
    (?$BQt(B ?$B>j(B)
    (?$BQu(B ?$Bd4(B)
    (?$BQx(B ?$B7u(B ?$Bn_(B ?$BQy(B ?$BQz(B ?$BQ{(B)
    (?$BQy(B ?$B7u(B ?$Bn_(B ?$BQx(B ?$BQz(B ?$BQ{(B)
    (?$BQz(B ?$B7u(B ?$Bn_(B ?$BQx(B ?$BQy(B ?$BQ{(B)
    (?$BQ{(B ?$B7u(B ?$Bn_(B ?$BQx(B ?$BQy(B ?$BQz(B)
    (?$BQ}(B ?$B:^(B)
    (?$BQ~(B ?$BJ[(B ?$BR!(B)
    (?$BR!(B ?$BJ[(B ?$BQ~(B)
    (?$BR)(B ?$BO+(B)
    (?$BR.(B ?$B7.(B ?$(D3n(B)
    (?$BR/(B ?$BNe(B)
    (?$BR0(B ?$B4+(B)
    (?$BR=(B ?$BT~(B ?$(D41(B)
    (?$BR?(B ?$B6h(B)
    (?$BR@(B ?$BB4(B)
    (?$BRB(B ?$B@$(B ?$(D48(B)
    (?$BRC(B ?$(DW8(B)
    (?$BRE(B ?$B=`(B)
    (?$BRH(B ?$BVb(B)
    (?$BRI(B ?$B1,(B)
    (?$BRJ(B ?$B5Q(B)
    (?$BRK(B ?$B4,(B)
    (?$BRL(B ?$(D4E(B)
    (?$BRN(B ?$BVz(B)
    (?$BRO(B ?$BV|(B)
    (?$BRQ(B ?$BW#(B)
    (?$BRR(B ?$B>3(B)
    (?$BRS(B ?$B9O(B ?$(D4S(B)
    (?$BRT(B ?$B;2(B ?$(D4X(B)
    (?$BRV(B ?$BAP(B)
    (?$BR_(B ?$(D4r(B)
    (?$BRi(B ?$B1S(B)
    (?$BRp(B ?$B<v(B)
    (?$BS#(B ?$(D5*(B)
    (?$BS%(B ?$(D5j(B)
    (?$BS1(B ?$(D6,(B)
    (?$BS8(B ?$(D6C(B)
    (?$BS=(B ?$BS>(B)
    (?$BS>(B ?$BS=(B)
    (?$BS?(B ?$(D_X(B)
    (?$BSE(B ?$BC1(B ?$(D6<(B)
    (?$BSL(B ?$(DmB(B)
    (?$BSO(B ?$(D4y(B)
    (?$BSX(B ?$(D^A(B)
    (?$BSZ(B ?$B4o(B)
    (?$BS[(B ?$B1D(B)
    (?$BSd(B ?$Bl!(B)
    (?$BSi(B ?$BSj(B)
    (?$BSj(B ?$BSi(B)
    (?$BSn(B ?$B87(B)
    (?$BSv(B ?$B>|(B)
    (?$BSw(B ?$Bsv(B)
    (?$BS{(B ?$B9q(B ?$BT"(B ?$(D7!(B)
    (?$BT!(B ?$B7w(B)
    (?$BT"(B ?$B9q(B ?$BS{(B ?$(D7!(B)
    (?$BT#(B ?$B0O(B)
    (?$BT$(B ?$B1_(B)
    (?$BT%(B ?$BCD(B)
    (?$BT&(B ?$B?^(B)
    (?$BT.(B ?$Bow(B)
    (?$BT1(B ?$B?b(B)
    (?$BT6(B ?$(DM:(B)
    (?$BT?(B ?$BT@(B)
    (?$BT@(B ?$BT?(B)
    (?$BTG(B ?$B>l(B)
    (?$BTO(B ?$(D8S(B)
    (?$BTU(B ?$B2u(B)
    (?$BTX(B ?$BBD(B)
    (?$BTZ(B ?$B05(B)
    (?$BT^(B ?$BN](B ?$(DMB(B)
    (?$BT`(B ?$Bf$(B)
    (?$BTa(B ?$B>m(B)
    (?$BTc(B ?$BAT(B)
    (?$BTd(B ?$BD[(B)
    (?$BTe(B ?$B0m(B)
    (?$BTf(B ?$BL;(B ?$Bf](B)
    (?$BTh(B ?$B<w(B)
    (?$BTl(B ?$BB?(B)
    (?$BTm(B ?$BL4(B ?$(D8i(B)
    (?$BTo(B ?$(D4Y(B)
    (?$BTq(B ?$BK\(B)
    (?$BTt(B ?$B4q(B)
    (?$BTy(B ?$BW2(B)
    (?$BT|(B ?$B1|(B ?$(D;s(B)
    (?$BT}(B ?$B>)(B ?$B`R(B)
    (?$BT~(B ?$BR=(B ?$(D41(B)
    (?$BU#(B ?$(D9U(B)
    (?$BU$(B ?$BU%(B)
    (?$BU%(B ?$BU$(B)
    (?$BU((B ?$(D9Q(B)
    (?$BU,(B ?$BG%(B)
    (?$BU5(B ?$B0|(B)
    (?$BU>(B ?$(D:5(B)
    (?$BUC(B ?$(D9F(B)
    (?$BUF(B ?$BUG(B)
    (?$BUG(B ?$BUF(B)
    (?$BUK(B ?$BUL(B)
    (?$BUL(B ?$BUK(B)
    (?$BUP(B ?$B>n(B)
    (?$BU\(B ?$B3X(B ?$BU](B ?$(DAW(B)
    (?$BU](B ?$B3X(B ?$BU\(B ?$(DAW(B)
    (?$BUc(B ?$BQM(B)
    (?$BUd(B ?$BQN(B ?$(D:Z(B)
    (?$BUi(B ?$B<B(B)
    (?$BUj(B ?$B?2(B)
    (?$BUm(B ?$B<L(B ?$BQP(B)
    (?$BUo(B ?$BJu(B ?$BUp(B ?$(D:c(B)
    (?$BUp(B ?$BJu(B ?$BUo(B ?$(D:c(B)
    (?$BUq(B ?$BQn(B)
    (?$BUr(B ?$B>-(B)
    (?$BUs(B ?$B@l(B)
    (?$BUt(B ?$BBP(B)
    (?$BUu(B ?$B<$(B ?$(D0^(B ?$(D0_(B ?$(D2X(B ?$(D={(B)
    (?$BUv(B ?$(D:l(B)
    (?$BUw(B ?$(D:m(B)
    (?$BU|(B ?$BFO(B)
    (?$BV$(B ?$BB0(B)
    (?$BV,(B ?$(D9{(B)
    (?$BV6(B ?$B2e(B)
    (?$BV7(B ?$B6.(B)
    (?$BV:(B ?$BEg(B ?$BEh(B ?$(D;u(B)
    (?$BV?(B ?$B:j(B ?$B:k(B ?$B:l(B)
    (?$BVF(B ?$BVG(B)
    (?$BVG(B ?$BVF(B)
    (?$BVH(B ?$Bd=(B)
    (?$BVI(B ?$(DOu(B)
    (?$BVM(B ?$B:7(B)
    (?$BVO(B ?$(D;6(B)
    (?$BVV(B ?$B3Y(B)
    (?$BV^(B ?$B4`(B)
    (?$BVb(B ?$BRH(B)
    (?$BVc(B ?$B;f(B)
    (?$BVf(B ?$(D0Z(B)
    (?$BVh(B ?$BBS(B)
    (?$BVp(B ?$(DAl(B)
    (?$BVr(B ?$BJ>(B)
    (?$BVs(B ?$(D<-(B ?$(D<=(B)
    (?$BVz(B ?$BRN(B)
    (?$BV|(B ?$BRO(B)
    (?$BV}(B ?$B19(B ?$BV~(B)
    (?$BV~(B ?$B19(B ?$BV}(B)
    (?$BW"(B ?$B9-(B)
    (?$BW#(B ?$BRQ(B)
    (?$BW$(B ?$B?_(B ?$(DE4(B)
    (?$BW%(B ?$(DbR(B)
    (?$BW&(B ?$BGQ(B)
    (?$BW,(B ?$BD#(B ?$BW-(B)
    (?$BW-(B ?$BD#(B ?$BW,(B)
    (?$BW/(B ?$Bml(B)
    (?$BW1(B ?$B4~(B)
    (?$BW2(B ?$BTy(B)
    (?$BW3(B ?$BW4(B ?$(D<z(B)
    (?$BW4(B ?$BW3(B ?$(D<z(B)
    (?$BW<(B ?$BCF(B)
    (?$BW=(B ?$BLo(B)
    (?$BW>(B ?$BW?(B)
    (?$BW?(B ?$BW>(B)
    (?$BW@(B ?$(D<w(B)
    (?$BWB(B ?$(DRT(B)
    (?$BWH(B ?$B1}(B)
    (?$BWJ(B ?$Bq|(B)
    (?$BWK(B ?$(D0r(B)
    (?$BWL(B ?$(D0v(B)
    (?$BWM(B ?$B7B(B ?$Bmt(B)
    (?$BWN(B ?$(DJz(B)
    (?$BWO(B ?$B=>(B)
    (?$BWT(B ?$(D2&(B)
    (?$BW_(B ?$B2x(B)
    (?$BWd(B ?$(D=F(B ?$(D=y(B)
    (?$BWm(B ?$(D>C(B)
    (?$BWq(B ?$B91(B)
    (?$BW{(B ?$(DK"(B)
    (?$BX#(B ?$(D>8(B)
    (?$BX'(B ?$(D=h(B)
    (?$BX((B ?$B0-(B)
    (?$BX*(B ?$B7C(B)
    (?$BX,(B ?$BX-(B)
    (?$BX-(B ?$BX,(B)
    (?$BX;(B ?$(D>\(B)
    (?$BX=(B ?$BG:(B)
    (?$BXC(B ?$(D9~(B ?$(DUg(B)
    (?$BXF(B ?$B?5(B)
    (?$BXN(B ?$B;4(B)
    (?$BXO(B ?$BXP(B)
    (?$BXP(B ?$BXO(B)
    (?$BXZ(B ?$(D>d(B)
    (?$BX[(B ?$(D>c(B)
    (?$BX\(B ?$B7F(B)
    (?$BX^(B ?$(D:,(B ?$(DN'(B)
    (?$BXa(B ?$(D>Z(B)
    (?$BXf(B ?$B1~(B)
    (?$BXg(B ?$B2{(B ?$(D\e(B)
    (?$BXo(B ?$(D>|(B)
    (?$BXs(B ?$BXt(B)
    (?$BXt(B ?$BXs(B)
    (?$BXx(B ?$BNx(B)
    (?$BX~(B ?$BY!(B)
    (?$BY!(B ?$BX~(B)
    (?$BY$(B ?$(D3L(B)
    (?$BY%(B ?$B@o(B)
    (?$BY&(B ?$B5:(B)
    (?$BY)(B ?$(D@>(B)
    (?$BY-(B ?$BY.(B)
    (?$BY.(B ?$BY-(B)
    (?$BY6(B ?$BH4(B)
    (?$BY?(B ?$BC4(B)
    (?$BYA(B ?$BGR(B)
    (?$BYD(B ?$BJ'(B)
    (?$BYQ(B ?$B64(B)
    (?$BYS(B ?$BA\(B)
    (?$BYg(B ?$BA^(B)
    (?$BYj(B ?$BMI(B)
    (?$BYp(B ?$B@](B)
    (?$BYx(B ?$B3I(B ?$(D?k(B)
    (?$BZ!(B ?$B5r(B)
    (?$BZ$(B ?$BBr(B)
    (?$BZ)(B ?$B5s(B ?$BZ*(B)
    (?$BZ*(B ?$B5s(B ?$BZ)(B)
    (?$BZ,(B ?$BZ-(B)
    (?$BZ-(B ?$BZ,(B)
    (?$BZ0(B ?$(DA,(B)
    (?$BZ2(B ?$B3H(B ?$(D?\(B)
    (?$BZ6(B ?$(DA9(B)
    (?$BZ8(B ?$B7H(B ?$(DA)(B)
    (?$BZ9(B ?$(DAB(B)
    (?$BZ<(B ?$(DJJ(B)
    (?$BZ@(B ?$B<}(B)
    (?$BZC(B ?$B8z(B)
    (?$BZE(B ?$BD<(B)
    (?$BZF(B ?$B=v(B ?$BZG(B)
    (?$BZG(B ?$B=v(B ?$BZF(B)
    (?$BZH(B ?$(D2;(B)
    (?$BZK(B ?$B?t(B)
    (?$BZN(B ?$BJQ(B)
    (?$BZP(B ?$(DbY(B)
    (?$BZR(B ?$BCG(B)
    (?$BZX(B ?$(DAf(B)
    (?$BZY(B ?$BZZ(B)
    (?$BZZ(B ?$BZY(B)
    (?$BZ_(B ?$(DB&(B)
    (?$BZh(B ?$B98(B)
    (?$BZi(B ?$B?8(B)
    (?$BZl(B ?$BCk(B)
    (?$BZm(B ?$(DAt(B)
    (?$BZo(B ?$(DBh(B)
    (?$BZp(B ?$(DB=(B)
    (?$BZ|(B ?$B6G(B)
    (?$B["(B ?$BNF(B)
    (?$B[%(B ?$B[&(B)
    (?$B[&(B ?$B[%(B)
    (?$B[*(B ?$B1H(B)
    (?$B[-(B ?$BO/(B)
    (?$B[.(B ?$B4|(B)
    (?$B[1(B ?$BGF(B ?$(DI@(B)
    (?$B[2(B ?$(DQ%(B)
    (?$B[=(B ?$BFJ(B)
    (?$B[@(B ?$B>>(B ?$(DC@(B ?$(DCu(B)
    (?$B[F(B ?$BKq(B)
    (?$B[M(B ?$(D4%(B)
    (?$B[X(B ?$BI0(B)
    (?$B[j(B ?$B>r(B)
    (?$B[m(B ?$BEn(B)
    (?$B[w(B ?$B4}(B ?$(DEF(B)
    (?$B\"(B ?$B;7(B)
    (?$B\#(B ?$B\$(B)
    (?$B\$(B ?$B\#(B)
    (?$B\7(B ?$(DE?(B)
    (?$B\;(B ?$(DXZ(B)
    (?$B\D(B ?$(DJO(B)
    (?$B\F(B ?$B1I(B)
    (?$B\V(B ?$(DJT(B)
    (?$B\X(B ?$(DE)(B)
    (?$B\[(B ?$B3Z(B)
    (?$B\^(B ?$B8"(B)
    (?$B\d(B ?$B?u(B)
    (?$B\i(B ?$B\j(B)
    (?$B\j(B ?$B\i(B)
    (?$B\k(B ?$BMM(B)
    (?$B\l(B ?$BO0(B)
    (?$B\s(B ?$BBJ(B)
    (?$B\}(B ?$B8!(B)
    (?$B]!(B ?$B]"(B)
    (?$B]"(B ?$B]!(B)
    (?$B]+(B ?$B],(B)
    (?$B],(B ?$B]+(B)
    (?$B]/(B ?$B:y(B)
    (?$B]2(B ?$(DEg(B)
    (?$B]3(B ?$(D7,(B)
    (?$B]5(B ?$B15(B)
    (?$B]9(B ?$BEp(B)
    (?$B];(B ?$B0{(B)
    (?$B]?(B ?$B2$(B)
    (?$B]C(B ?$(DEh(B)
    (?$B]D(B ?$B4?(B)
    (?$B]E(B ?$B5"(B ?$Bb'(B)
    (?$B]G(B ?$(DF!(B)
    (?$B]L(B ?$B;D(B)
    (?$B]S(B ?$B]T(B)
    (?$B]T(B ?$B]S(B)
    (?$B]W(B ?$B3L(B ?$(D8^(B)
    (?$B]X(B ?$B2%(B)
    (?$B]Z(B ?$B0i(B)
    (?$B][(B ?$(DF>(B)
    (?$B]a(B ?$(DF:(B)
    (?$B]f(B ?$B5$(B ?$(DII(B)
    (?$B]l(B ?$B:c(B ?$BQT(B)
    (?$B]r(B ?$(DFd(B)
    (?$B]s(B ?$BKW(B)
    (?$B]}(B ?$(DFt(B)
    (?$B^#(B ?$(D2z(B)
    (?$B^%(B ?$BN^(B)
    (?$B^((B ?$(DFg(B)
    (?$B^0(B ?$BQX(B)
    (?$B^9(B ?$BEs(B)
    (?$B^<(B ?$BJ%(B ?$B^=(B ?$(D6y(B)
    (?$B^=(B ?$BJ%(B ?$B^<(B ?$(D6y(B)
    (?$B^A(B ?$BQY(B)
    (?$B^F(B ?$B>t(B)
    (?$B^G(B ?$B@((B)
    (?$B^I(B ?$B@u(B)
    (?$B^`(B ?$BK~(B)
    (?$B^d(B ?$B7L(B ?$Bl0(B ?$(D;Y(B ?$(DP((B)
    (?$B^j(B ?$BAL(B)
    (?$B^u(B ?$B4C(B)
    (?$B^v(B ?$(DR_(B)
    (?$B^w(B ?$(DFh(B)
    (?$B^|(B ?$BBZ(B)
    (?$B_'(B ?$B=B(B ?$B_((B ?$(DE{(B)
    (?$B_((B ?$B=B(B ?$B_'(B ?$(DE{(B)
    (?$B_*(B ?$B@x(B ?$B_+(B)
    (?$B_+(B ?$B@x(B ?$B_*(B)
    (?$B_1(B ?$BN/(B)
    (?$B_4(B ?$(DHn(B)
    (?$B_7(B ?$BBt(B)
    (?$B_;(B ?$B:Q(B)
    (?$B_<(B ?$B<>(B)
    (?$B_@(B ?$BIM(B ?$(DI&(B)
    (?$B_L(B ?$BCu(B)
    (?$B_R(B ?$(DHw(B)
    (?$B_T(B ?$BOQ(B)
    (?$B_W(B ?$B_X(B)
    (?$B_X(B ?$B_W(B)
    (?$B_](B ?$B1l(B)
    (?$B_b(B ?$(DJ+(B)
    (?$B_f(B ?$Bt&(B ?$B_g(B)
    (?$B_g(B ?$Bt&(B ?$B_f(B)
    (?$B_i(B ?$(DIm(B)
    (?$B_l(B ?$(DIX(B)
    (?$B_m(B ?$B_n(B)
    (?$B_n(B ?$B_m(B)
    (?$B_t(B ?$(DJ0(B)
    (?$B_v(B ?$B>F(B)
    (?$B_y(B ?$(D:k(B)
    (?$B`"(B ?$BMT(B)
    (?$B`$(B ?$BO'(B)
    (?$B`%(B ?$(DJG(B)
    (?$B`'(B ?$BAh(B)
    (?$B`*(B ?$B0Y(B)
    (?$B`,(B ?$BPY(B)
    (?$B`4(B ?$B`5(B)
    (?$B`5(B ?$B`4(B)
    (?$B`:(B ?$B5>(B)
    (?$B`<(B ?$Bl9(B)
    (?$B`B(B ?$Bl;(B)
    (?$B`E(B ?$B69(B)
    (?$B`I(B ?$Bl?(B)
    (?$B`N(B ?$(D_$(B)
    (?$B`O(B ?$(DJu(B)
    (?$B`R(B ?$B>)(B ?$BT}(B)
    (?$B`S(B ?$BlB(B)
    (?$B`T(B ?$BL[(B)
    (?$B`W(B ?$BFH(B)
    (?$B`Y(B ?$B=C(B)
    (?$B`Z(B ?$BND(B)
    (?$B`[(B ?$B8%(B)
    (?$B`^(B ?$(DL;(B)
    (?$B`_(B ?$BDA(B)
    (?$B`e(B ?$BN\(B)
    (?$B`f(B ?$B`g(B)
    (?$B`g(B ?$B`f(B)
    (?$B`o(B ?$Bbu(B)
    (?$B`s(B ?$(DLl(B)
    (?$B`t(B ?$(DL'(B)
    (?$B`v(B ?$Bt$(B)
    (?$B`}(B ?$B`~(B)
    (?$B`~(B ?$B`}(B)
    (?$Ba"(B ?$BJ[(B)
    (?$Ba*(B ?$(DL~(B)
    (?$Ba.(B ?$(DLx(B)
    (?$Ba3(B ?$B>((B)
    (?$Ba6(B ?$BD.(B)
    (?$Ba7(B ?$BN1(B ?$(DM<(B)
    (?$Ba<(B ?$B@&(B ?$(DM6(B ?$(DM8(B)
    (?$Ba@(B ?$BN,(B)
    (?$BaA(B ?$B2h(B)
    (?$BaD(B ?$BEv(B)
    (?$BaF(B ?$BaG(B)
    (?$BaG(B ?$BaF(B)
    (?$BaH(B ?$B>v(B ?$BaI(B ?$BaJ(B ?$(D4`(B)
    (?$BaI(B ?$B>v(B ?$BaH(B ?$BaJ(B ?$(D4`(B)
    (?$BaJ(B ?$B>v(B ?$BaH(B ?$BaI(B ?$(D4`(B)
    (?$BaO(B ?$Bfo(B)
    (?$Ba^(B ?$(DMM(B)
    (?$Bac(B ?$(DMb(B)
    (?$Bah(B ?$BL~(B)
    (?$Ban(B ?$(DN((B)
    (?$Baq(B ?$(DN!(B)
    (?$Baw(B ?$BCT(B)
    (?$Ba~(B ?$(DN+(B ?$(DVV(B)
    (?$Bb$(B ?$BH/(B)
    (?$Bb&(B ?$BKF(B)
    (?$Bb'(B ?$B5"(B ?$B]E(B)
    (?$Bb((B ?$B;)(B)
    (?$Bb-(B ?$(D3$(B)
    (?$Bb0(B ?$Bb1(B)
    (?$Bb1(B ?$Bb0(B)
    (?$Bb5(B ?$B38(B ?$Bhd(B)
    (?$Bb8(B ?$B?T(B)
    (?$Bb;(B ?$Bb<(B)
    (?$Bb<(B ?$Bb;(B)
    (?$BbC(B ?$B??(B)
    (?$BbD(B ?$BbE(B)
    (?$BbE(B ?$BbD(B)
    (?$BbJ(B ?$(D>2(B)
    (?$BbN(B ?$(DO!(B)
    (?$BbO(B ?$B1C(B ?$(D8[(B)
    (?$BbU(B ?$(DO6(B)
    (?$BbW(B ?$(DOA(B)
    (?$Bbg(B ?$(DP$(B)
    (?$Bbh(B ?$B9[(B ?$B9\(B ?$BoJ(B ?$(DP9(B)
    (?$Bbj(B ?$BEW(B)
    (?$Bbl(B ?$B:U(B)
    (?$Bbu(B ?$B`o(B)
    (?$Bby(B ?$(D4D(B)
    (?$Bc&(B ?$(DOk(B)
    (?$Bc((B ?$B37(B)
    (?$Bc0(B ?$BHk(B)
    (?$Bc3(B ?$BO=(B)
    (?$Bc7(B ?$B:X(B)
    (?$Bc8(B ?$BA5(B)
    (?$Bc9(B ?$BNi(B)
    (?$BcH(B ?$BcI(B)
    (?$BcI(B ?$BcH(B)
    (?$BcJ(B ?$B>N(B ?$(DQM(B)
    (?$BcK(B ?$B0p(B)
    (?$BcL(B ?$B9F(B ?$(DY|(B)
    (?$BcO(B ?$BJf(B)
    (?$BcP(B ?$BCU(B ?$(DQ>(B)
    (?$BcS(B ?$B2:(B)
    (?$BcT(B ?$B0,(B ?$B=)(B)
    (?$BcU(B ?$B>w(B)
    (?$BcV(B ?$(D:I(B)
    (?$BcY(B ?$BAk(B ?$(D6|(B ?$(DJQ(B ?$(DJU(B ?$(DQb(B)
    (?$Bc^(B ?$B3v(B ?$(DIG(B)
    (?$Bc_(B ?$BMR(B ?$(DQY(B)
    (?$Bcf(B ?$B@`(B)
    (?$Bcm(B ?$BJB(B ?$(D2*(B)
    (?$Bc~(B ?$Bd!(B)
    (?$Bd!(B ?$Bc~(B)
    (?$Bd#(B ?$Bd$(B ?$(DR@(B)
    (?$Bd$(B ?$Bd#(B ?$(DR@(B)
    (?$Bd&(B ?$(DRA(B)
    (?$Bd,(B ?$B<D(B)
    (?$Bd2(B ?$(DQu(B)
    (?$Bd4(B ?$BQu(B)
    (?$Bd7(B ?$Bd8(B)
    (?$Bd8(B ?$Bd7(B)
    (?$Bd:(B ?$(D4*(B)
    (?$Bd=(B ?$BVH(B)
    (?$BdA(B ?$(DR\(B ?$(DS%(B)
    (?$BdB(B ?$BL,(B ?$BdC(B)
    (?$BdC(B ?$BL,(B ?$BdB(B)
    (?$BdD(B ?$BJO(B)
    (?$BdF(B ?$BO6(B)
    (?$BdG(B ?$(DY?(B)
    (?$BdQ(B ?$(D2e(B)
    (?$BdX(B ?$BLy(B ?$Bi.(B)
    (?$BdY(B ?$(DRm(B)
    (?$BdZ(B ?$(DRw(B)
    (?$Bd[(B ?$Bd\(B)
    (?$Bd\(B ?$Bd[(B)
    (?$Bd^(B ?$Bd_(B)
    (?$Bd_(B ?$Bd^(B)
    (?$Bdk(B ?$(DPz(B ?$(DQ-(B)
    (?$Bdn(B ?$BNH(B)
    (?$Bdo(B ?$B?h(B)
    (?$Bdp(B ?$(DS=(B)
    (?$Bdx(B ?$B4!(B ?$(D1F(B)
    (?$Bd}(B ?$B5j(B)
    (?$Be%(B ?$(DS}(B)
    (?$Be+(B ?$(Dg@(B)
    (?$Be-(B ?$(DTc(B)
    (?$Be/(B ?$B;e(B)
    (?$Be4(B ?$B7P(B)
    (?$Be6(B ?$(DTG(B)
    (?$Be@(B ?$B@~(B)
    (?$BeA(B ?$BAm(B ?$(D@d(B ?$(DT8(B)
    (?$BeN(B ?$(DT/(B)
    (?$BeQ(B ?$B8)(B)
    (?$BeT(B ?$B=D(B)
    (?$Be^(B ?$(DT%(B)
    (?$Bei(B ?$B3((B)
    (?$Bej(B ?$BFl(B)
    (?$Bek(B ?$B7Q(B)
    (?$Bem(B ?$Ben(B)
    (?$Ben(B ?$Bem(B)
    (?$Bes(B ?$(DTg(B)
    (?$Bet(B ?$BB3(B ?$(D_5(B)
    (?$Beu(B ?$BE;(B)
    (?$Bey(B ?$BA!(B ?$Bez(B)
    (?$Bez(B ?$BA!(B ?$Bey(B)
    (?$Be}(B ?$(DLu(B)
    (?$Be~(B ?$B7g(B ?$(DTk(B)
    (?$Bf"(B ?$(DM"(B)
    (?$Bf$(B ?$BT`(B)
    (?$Bf%(B ?$B4L(B ?$(DTl(B)
    (?$Bf&(B ?$(DTt(B ?$(DTu(B)
    (?$Bf/(B ?$BH3(B)
    (?$Bf2(B ?$BQQ(B)
    (?$Bf3(B ?$Bk+(B ?$Bf4(B)
    (?$Bf4(B ?$Bk+(B ?$Bf3(B)
    (?$Bf5(B ?$(DU,(B)
    (?$Bf:(B ?$B72(B)
    (?$Bf=(B ?$Bf>(B)
    (?$Bf>(B ?$Bf=(B)
    (?$Bf?(B ?$(DU3(B)
    (?$BfA(B ?$BA1(B)
    (?$BfC(B ?$B?i(B)
    (?$BfL(B ?$BK](B)
    (?$BfO(B ?$(DUJ(B)
    (?$BfU(B ?$(DDf(B ?$(De,(B)
    (?$BfW(B ?$BCQ(B)
    (?$Bf](B ?$BL;(B ?$BTf(B)
    (?$Bf_(B ?$BN~(B)
    (?$Bfa(B ?$B@<(B)
    (?$Bfb(B ?$BAo(B ?$(DUf(B)
    (?$Bfe(B ?$BD0(B)
    (?$Bfi(B ?$B=M(B)
    (?$Bfn(B ?$BKA(B)
    (?$Bfo(B ?$BaO(B)
    (?$Bft(B ?$(D0b(B)
    (?$Bfu(B ?$(DUp(B)
    (?$Bfw(B ?$BL.(B)
    (?$Bfz(B ?$(D_t(B)
    (?$Bf|(B ?$B?0(B)
    (?$Bg"(B ?$(D1O(B)
    (?$Bg#(B ?$(DV<(B)
    (?$Bg*(B ?$BG>(B ?$(D4$(B)
    (?$Bg0(B ?$(DVF(B)
    (?$Bg4(B ?$Bg5(B)
    (?$Bg5(B ?$Bg4(B)
    (?$Bg6(B ?$BD2(B)
    (?$Bg;(B ?$B?q(B ?$Bqr(B)
    (?$Bg<(B ?$BC@(B ?$(DVT(B)
    (?$Bg=(B ?$(DVU(B)
    (?$BgD(B ?$BgE(B)
    (?$BgE(B ?$BgD(B)
    (?$BgG(B ?$BB!(B)
    (?$BgJ(B ?$BBf(B)
    (?$BgP(B ?$BM?(B)
    (?$BgQ(B ?$B5l(B)
    (?$BgR(B ?$B<K(B)
    (?$BgS(B ?$(DVp(B)
    (?$BgT(B ?$BJ^(B)
    (?$BgU(B ?$BA%(B)
    (?$Bgb(B ?$(DW((B)
    (?$Bgc(B ?$Bgd(B)
    (?$Bgd(B ?$Bgc(B)
    (?$Bge(B ?$(D6n(B)
    (?$Bgf(B ?$B1p(B ?$(D^l(B ?$(D^m(B)
    (?$Bgo(B ?$(DWS(B)
    (?$Bgu(B ?$Bgv(B)
    (?$Bgv(B ?$Bgu(B)
    (?$Bh$(B ?$(DWa(B)
    (?$Bh*(B ?$(DSj(B)
    (?$Bh-(B ?$(DWc(B)
    (?$Bh.(B ?$(DXm(B)
    (?$Bh3(B ?$B7T(B)
    (?$Bh7(B ?$BAq(B)
    (?$Bh9(B ?$BEF(B ?$BEQ(B ?$BQ=(B)
    (?$Bh?(B ?$B0C(B ?$(DXR(B)
    (?$BhL(B ?$(DY&(B)
    (?$BhN(B ?$BK((B)
    (?$BhO(B ?$(DX4(B)
    (?$BhU(B ?$BhV(B)
    (?$BhV(B ?$BhU(B)
    (?$Bh_(B ?$BK|(B)
    (?$Bhd(B ?$B38(B ?$Bb5(B)
    (?$Bhs(B ?$(DXk(B)
    (?$Bi"(B ?$B<I(B ?$Bi#(B)
    (?$Bi#(B ?$B<I(B ?$Bi"(B)
    (?$Bi)(B ?$(DX`(B)
    (?$Bi.(B ?$BLy(B ?$BdX(B)
    (?$Bi5(B ?$(DXJ(B)
    (?$Bi6(B ?$BB"(B ?$(D4+(B)
    (?$Bi:(B ?$B7](B ?$(DPv(B)
    (?$Bi;(B ?$BLt(B)
    (?$Bi?(B ?$BAI(B)
    (?$BiC(B ?$B02(B)
    (?$BiI(B ?$B8W(B ?$(DZ?(B)
    (?$BiK(B ?$B9f(B)
    (?$BiM(B ?$Bi|(B)
    (?$BiR(B ?$(D[&(B)
    (?$BiS(B ?$(D[#(B)
    (?$BiZ(B ?$B3B(B)
    (?$Bi\(B ?$(DZY(B)
    (?$Bib(B ?$(D[J(B)
    (?$Biv(B ?$(DK1(B)
    (?$Bi|(B ?$BiM(B)
    (?$Bj$(B ?$BGh(B)
    (?$Bj%(B ?$B7V(B)
    (?$Bj1(B ?$Bj2(B)
    (?$Bj2(B ?$Bj1(B)
    (?$Bj5(B ?$BCn(B)
    (?$Bj7(B ?$B3*(B)
    (?$Bj<(B ?$Bj=(B)
    (?$Bj=(B ?$Bj<(B)
    (?$Bj@(B ?$(D[1(B)
    (?$BjB(B ?$(D[e(B)
    (?$BjD(B ?$B;=(B ?$(D[-(B ?$(D\!(B)
    (?$BjE(B ?$BjF(B ?$(D[F(B)
    (?$BjF(B ?$BjE(B ?$(D[F(B)
    (?$BjG(B ?$BHZ(B)
    (?$BjH(B ?$BjI(B)
    (?$BjI(B ?$BjH(B)
    (?$BjL(B ?$B1R(B)
    (?$BjS(B ?$BjT(B)
    (?$BjT(B ?$BjS(B)
    (?$Bjf(B ?$BAu(B)
    (?$Bjj(B ?$(D\S(B)
    (?$Bjk(B ?$(DBo(B)
    (?$Bjo(B ?$(D>6(B)
    (?$Bjp(B ?$(DT5(B)
    (?$Bjq(B ?$BK+(B ?$(D\K(B)
    (?$Bj{(B ?$Bj|(B)
    (?$Bj|(B ?$Bj{(B)
    (?$Bk#(B ?$(DA2(B)
    (?$Bk&(B ?$(D]#(B)
    (?$Bk+(B ?$Bf3(B ?$Bf4(B ?$(D]$(B)
    (?$Bk,(B ?$(D]'(B)
    (?$Bk4(B ?$B3P(B ?$(D]&(B)
    (?$Bk5(B ?$BMw(B)
    (?$Bk7(B ?$B4Q(B)
    (?$Bk;(B ?$B2r(B)
    (?$Bk=(B ?$B?((B)
    (?$BkE(B ?$(D5?(B)
    (?$BkI(B ?$(D4x(B)
    (?$BkM(B ?$(D]U(B)
    (?$Bk](B ?$B4R(B)
    (?$Bk`(B ?$(D^[(B)
    (?$Bkc(B ?$(D^6(B)
    (?$Bkj(B ?$Bkk(B)
    (?$Bkk(B ?$Bkj(B)
    (?$Bko(B ?$BMX(B)
    (?$Bks(B ?$(D^W(B)
    (?$Bkv(B ?$B2^(B)
    (?$Bkz(B ?$B>Z(B)
    (?$Bk{(B ?$Bk|(B)
    (?$Bk|(B ?$Bk{(B)
    (?$Bk~(B ?$(D6J(B)
    (?$Bl!(B ?$BSd(B)
    (?$Bl#(B ?$BLu(B)
    (?$Bl%(B ?$BM@(B)
    (?$Bl&(B ?$BFI(B)
    (?$Bl((B ?$B=2(B)
    (?$Bl*(B ?$B>y(B)
    (?$Bl-(B ?$B;>(B)
    (?$Bl.(B ?$(D;*(B)
    (?$Bl0(B ?$B7L(B ?$B^d(B ?$(D;Y(B ?$(DP((B)
    (?$Bl3(B ?$BC((B)
    (?$Bl4(B ?$BK-(B)
    (?$Bl7(B ?$BCv(B)
    (?$Bl9(B ?$B`<(B)
    (?$Bl:(B ?$(Dm2(B)
    (?$Bl;(B ?$B`B(B)
    (?$Bl>(B ?$BC,(B ?$(DK'(B)
    (?$Bl?(B ?$B`I(B)
    (?$Bl@(B ?$BlA(B)
    (?$BlA(B ?$Bl@(B)
    (?$BlB(B ?$B`S(B)
    (?$BlC(B ?$B:b(B)
    (?$BlD(B ?$B<A(B ?$(D3S(B)
    (?$BlH(B ?$BFu(B ?$BlI(B)
    (?$BlI(B ?$BFu(B ?$BlH(B)
    (?$BlM(B ?$BA((B)
    (?$BlN(B ?$BGd(B)
    (?$BlU(B ?$B;?(B)
    (?$BlZ(B ?$(D_<(B)
    (?$Bl[(B ?$Bl\(B)
    (?$Bl\(B ?$Bl[(B)
    (?$Bla(B ?$BAv(B)
    (?$Bls(B ?$BAB(B)
    (?$Blx(B ?$BA)(B)
    (?$Bl}(B ?$BMY(B)
    (?$Bm2(B ?$(D`B(B)
    (?$Bm3(B ?$(Dfn(B)
    (?$Bm4(B ?$(D`<(B ?$(D`F(B)
    (?$Bm8(B ?$Bm9(B)
    (?$Bm9(B ?$Bm8(B)
    (?$Bm;(B ?$(D`P(B)
    (?$Bm<(B ?$BBN(B ?$Bqs(B ?$Bm=(B)
    (?$Bm=(B ?$BBN(B ?$Bqs(B ?$Bm<(B)
    (?$BmD(B ?$B9l(B)
    (?$BmK(B ?$B7Z(B)
    (?$BmL(B ?$BmM(B)
    (?$BmM(B ?$BmL(B)
    (?$BmO(B ?$(D`|(B)
    (?$BmQ(B ?$BmR(B)
    (?$BmR(B ?$BmQ(B)
    (?$Bm[(B ?$BE>(B)
    (?$Bm^(B ?$(D`p(B)
    (?$Bm_(B ?$(D`e(B)
    (?$Bmf(B ?$B<-(B ?$(Da-(B ?$(Da0(B)
    (?$Bmg(B ?$BJ[(B)
    (?$Bmj(B ?$(DaM(B)
    (?$Bml(B ?$BW/(B)
    (?$Bmm(B ?$BF((B)
    (?$Bmn(B ?$BFv(B)
    (?$Bmr(B ?$BG6(B)
    (?$Bmt(B ?$B7B(B ?$BWM(B)
    (?$Bm}(B ?$BC#(B)
    (?$Bn$(B ?$Bn%(B)
    (?$Bn%(B ?$Bn$(B)
    (?$Bn*(B ?$BD~(B)
    (?$Bn.(B ?$B?o(B)
    (?$Bn/(B ?$BCY(B)
    (?$Bn4(B ?$BJU(B ?$Bn5(B)
    (?$Bn5(B ?$BJU(B ?$Bn4(B)
    (?$BnC(B ?$BNY(B ?$(D4T(B)
    (?$BnL(B ?$B?](B)
    (?$BnM(B ?$B?l(B)
    (?$BnP(B ?$B0e(B)
    (?$BnV(B ?$B>z(B)
    (?$BnW(B ?$(D\%(B)
    (?$BnY(B ?$B<a(B)
    (?$Bn](B ?$B3x(B)
    (?$Bn_(B ?$B7u(B ?$BQx(B ?$BQy(B ?$BQz(B ?$BQ{(B)
    (?$Bne(B ?$BBx(B)
    (?$Bnl(B ?$B3C(B)
    (?$Bnn(B ?$BE4(B ?$BoD(B ?$BoE(B ?$(DdL(B)
    (?$Bnr(B ?$(D\.(B)
    (?$Bnu(B ?$(Dd0(B)
    (?$Bny(B ?$(DIf(B)
    (?$Bnz(B ?$(Dc1(B)
    (?$Bo!(B ?$(De#(B)
    (?$Bo"(B ?$BA,(B)
    (?$Bo)(B ?$(Dej(B)
    (?$Bo/(B ?$BDC(B)
    (?$Bo5(B ?$(DeS(B)
    (?$BoD(B ?$BE4(B ?$Bnn(B ?$BoE(B ?$(DdL(B)
    (?$BoE(B ?$BE4(B ?$Bnn(B ?$BoD(B ?$(DdL(B)
    (?$BoH(B ?$B4U(B ?$(Dd|(B)
    (?$BoI(B ?$BCr(B)
    (?$BoJ(B ?$B9[(B ?$B9\(B ?$Bbh(B ?$(DP9(B)
    (?$BoN(B ?$BoO(B)
    (?$BoO(B ?$BoN(B)
    (?$BoS(B ?$BoT(B)
    (?$BoT(B ?$BoS(B)
    (?$BoZ(B ?$BJD(B)
    (?$Bo_(B ?$Br)(B)
    (?$Bof(B ?$(D3H(B)
    (?$Boh(B ?$Boi(B)
    (?$Boi(B ?$Boh(B)
    (?$Boj(B ?$(Df/(B)
    (?$Bop(B ?$B4X(B)
    (?$Bou(B ?$(DfN(B)
    (?$Bow(B ?$BT.(B)
    (?$Bo|(B ?$B4Y(B)
    (?$Bo}(B ?$(Df_(B)
    (?$Bp"(B ?$(D=+(B)
    (?$Bp#(B ?$(Dfh(B ?$(Dfo(B)
    (?$Bp((B ?$(DP)(B)
    (?$Bp*(B ?$B81(B ?$(DP<(B)
    (?$Bp,(B ?$B1#(B ?$(D04(B)
    (?$Bp1(B ?$BNl(B)
    (?$Bp8(B ?$B;((B)
    (?$Bp:(B ?$(Dk{(B)
    (?$BpM(B ?$BNn(B ?$(DIF(B ?$(Dg%(B)
    (?$BpP(B ?$B@E(B)
    (?$BpV(B ?$B?Y(B ?$BpW(B)
    (?$BpW(B ?$B?Y(B ?$BpV(B)
    (?$Bp^(B ?$(DgP(B)
    (?$Bpb(B ?$(DOv(B)
    (?$Bpi(B ?$(Dgl(B)
    (?$Bpk(B ?$(D`~(B ?$(DgN(B)
    (?$Bpl(B ?$BG#(B)
    (?$Bpm(B ?$Bpn(B)
    (?$Bpn(B ?$Bpm(B)
    (?$Bpt(B ?$B7[(B)
    (?$Bpu(B ?$(Dh((B)
    (?$Bpz(B ?$B4i(B)
    (?$Bp}(B ?$B82(B)
    (?$Bq!(B ?$(Dik(B ?$(DlT(B)
    (?$Bq((B ?$Bq)(B)
    (?$Bq)(B ?$Bq((B)
    (?$Bq*(B ?$(Dh<(B ?$(Dh?(B ?$(DhF(B)
    (?$Bq.(B ?$(Dep(B ?$(Dhu(B)
    (?$Bq/(B ?$(Dh](B ?$(Dhc(B)
    (?$Bq1(B ?$BM>(B)
    (?$Bq6(B ?$BL_(B)
    (?$BqL(B ?$(Di,(B)
    (?$Bq[(B ?$BA{(B)
    (?$Bq\(B ?$B6n(B ?$B6o(B ?$(DAT(B)
    (?$Bqc(B ?$B1X(B)
    (?$Bqd(B ?$B83(B ?$(Di<(B)
    (?$Bqf(B ?$(Di$(B)
    (?$Bqg(B ?$(DZ&(B)
    (?$Bqr(B ?$B?q(B ?$Bg;(B)
    (?$Bqs(B ?$BBN(B ?$Bm<(B ?$Bm=(B ?$(Di\(B)
    (?$Bq{(B ?$BH1(B)
    (?$Bq|(B ?$BWJ(B)
    (?$Br&(B ?$(Dir(B ?$(Di}(B)
    (?$Br'(B ?$(Dj-(B)
    (?$Br)(B ?$Bo_(B)
    (?$Br,(B ?$BF.(B ?$(Dj0(B ?$(Dj2(B)
    (?$Br4(B ?$(D[)(B)
    (?$BrM(B ?$B03(B)
    (?$BrW(B ?$(Dk4(B)
    (?$Br[(B ?$Br\(B)
    (?$Br\(B ?$Br[(B)
    (?$Br](B ?$(DkK(B)
    (?$Br^(B ?$(DjL(B)
    (?$Brh(B ?$(Dj_(B ?$(Djs(B)
    (?$Brj(B ?$Brk(B)
    (?$Brk(B ?$Brj(B)
    (?$Brn(B ?$B4g(B ?$Bro(B)
    (?$Bro(B ?$B4g(B ?$Brn(B)
    (?$Brt(B ?$B2)(B)
    (?$Brv(B ?$Brw(B)
    (?$Brw(B ?$Brv(B)
    (?$Bs!(B ?$Bs"(B)
    (?$Bs"(B ?$Bs!(B)
    (?$Bs)(B ?$Bs*(B)
    (?$Bs*(B ?$Bs)(B)
    (?$Bs.(B ?$(Dl"(B)
    (?$Bs1(B ?$B7\(B ?$(Dfx(B)
    (?$Bs6(B ?$Bs7(B)
    (?$Bs7(B ?$Bs6(B)
    (?$BsA(B ?$(Dfv(B)
    (?$BsD(B ?$(Dbi(B)
    (?$BsE(B ?$B1v(B)
    (?$BsN(B ?$BG~(B)
    (?$BsO(B ?$BsP(B ?$(Dlj(B)
    (?$BsP(B ?$BsO(B ?$(Dlj(B)
    (?$BsQ(B ?$BLM(B ?$(Dlp(B)
    (?$BsZ(B ?$BE@(B)
    (?$Bs^(B ?$BE^(B)
    (?$Bsh(B ?$(Dk@(B ?$(Dm_(B)
    (?$Bsi(B ?$B8](B)
    (?$Bsk(B ?$BAM(B)
    (?$Bsn(B ?$B@F(B ?$(D0@(B ?$(DAX(B)
    (?$Bso(B ?$B;u(B)
    (?$Bsp(B ?$(DmE(B)
    (?$Bst(B ?$BNp(B)
    (?$Bsv(B ?$BSw(B)
    (?$Bsx(B ?$(DmS(B)
    (?$Bs{(B ?$(DVB(B)
    (?$Bs}(B ?$B55(B)
    (?$Bt!(B ?$B6F(B)
    (?$Bt"(B ?$BKj(B)
    (?$Bt#(B ?$BMZ(B)
    (?$Bt$(B ?$B`v(B)
    (?$Bt%(B ?$BQ[(B)
    (?$Bt&(B ?$B_f(B ?$B_g(B)
    (?$(D0"(B ?$B>e(B)
    (?$(D0#(B ?$B2<(B)
    (?$(D0$(B ?$BB6(B)
    (?$(D0%(B ?$B1/(B)
    (?$(D0'(B ?$BFS(B)
    (?$(D0((B ?$BN>(B ?$BQ@(B)
    (?$(D04(B ?$B1#(B ?$Bp,(B)
    (?$(D07(B ?$B;O(B ?$(D2k(B)
    (?$(D0;(B ?$B4%(B)
    (?$(D0>(B ?$B;M(B)
    (?$(D0?(B ?$B:P(B)
    (?$(D0@(B ?$B@F(B ?$Bsn(B ?$(DAX(B)
    (?$(D0A(B ?$B5}(B)
    (?$(D0D(B ?$B;1(B)
    (?$(D0I(B ?$(D=#(B)
    (?$(D0O(B ?$BIK(B ?$BIL(B)
    (?$(D0P(B ?$BDc(B)
    (?$(D0Z(B ?$BVf(B)
    (?$(D0\(B ?$B2P(B)
    (?$(D0](B ?$BEX(B)
    (?$(D0^(B ?$B<$(B ?$BUu(B ?$(D0_(B ?$(D2X(B ?$(D={(B)
    (?$(D0_(B ?$B<$(B ?$BUu(B ?$(D0^(B ?$(D2X(B ?$(D={(B)
    (?$(D0a(B ?$(D1&(B)
    (?$(D0b(B ?$Bft(B)
    (?$(D0f(B ?$B;w(B)
    (?$(D0g(B ?$(D=U(B)
    (?$(D0r(B ?$BWK(B)
    (?$(D0u(B ?$BK!(B ?$(DI<(B)
    (?$(D0v(B ?$BWL(B)
    (?$(D1$(B ?$B1"(B ?$(DfH(B ?$(Dfa(B)
    (?$(D1&(B ?$(D0a(B)
    (?$(D14(B ?$BCK(B)
    (?$(D1=(B ?$BJe(B)
    (?$(D1B(B ?$B6"(B)
    (?$(D1C(B ?$B=$(B)
    (?$(D1E(B ?$BP{(B)
    (?$(D1F(B ?$B4!(B ?$Bdx(B)
    (?$(D1G(B ?$B6U(B ?$(D>0(B)
    (?$(D1O(B ?$Bg"(B)
    (?$(D1W(B ?$(D2/(B)
    (?$(D1](B ?$(D3C(B)
    (?$(D1_(B ?$B1Q(B)
    (?$(D1c(B ?$(D_9(B)
    (?$(D1k(B ?$(D22(B)
    (?$(D1r(B ?$BI/(B)
    (?$(D2&(B ?$BWT(B)
    (?$(D2)(B ?$BH2(B ?$(DJ](B)
    (?$(D2*(B ?$BJB(B ?$Bcm(B)
    (?$(D2-(B ?$BPx(B)
    (?$(D2/(B ?$(D1W(B)
    (?$(D22(B ?$(D1k(B)
    (?$(D23(B ?$BHw(B)
    (?$(D24(B ?$(D=6(B)
    (?$(D2;(B ?$BZH(B)
    (?$(D2<(B ?$BEP(B)
    (?$(D2X(B ?$B<$(B ?$BUu(B ?$(D0^(B ?$(D0_(B ?$(D={(B)
    (?$(D2Z(B ?$(D2d(B)
    (?$(D2d(B ?$(D2Z(B)
    (?$(D2e(B ?$BdQ(B)
    (?$(D2f(B ?$BQ<(B)
    (?$(D2g(B ?$BD9(B ?$(De}(B)
    (?$(D2k(B ?$B;O(B ?$(D07(B)
    (?$(D2n(B ?$BK4(B)
    (?$(D2o(B ?$BQC(B)
    (?$(D2p(B ?$BK9(B)
    (?$(D2q(B ?$BQG(B)
    (?$(D2r(B ?$BQD(B)
    (?$(D2s(B ?$(D3I(B ?$(D4b(B)
    (?$(D2u(B ?$B59(B ?$(D:L(B)
    (?$(D2w(B ?$B:G(B)
    (?$(D2z(B ?$B^#(B)
    (?$(D3"(B ?$B8:(B)
    (?$(D3#(B ?$BL+(B)
    (?$(D3$(B ?$Bb-(B)
    (?$(D3)(B ?$BK^(B)
    (?$(D3*(B ?$B5o(B)
    (?$(D3+(B ?$BIw(B ?$(DhG(B)
    (?$(D3,(B ?$(D:t(B ?$(D:v(B)
    (?$(D3-(B ?$(DEM(B)
    (?$(D3/(B ?$B2t(B)
    (?$(D32(B ?$BEa(B)
    (?$(D37(B ?$BN-(B)
    (?$(D3A(B ?$(D3J(B)
    (?$(D3C(B ?$(D1](B)
    (?$(D3H(B ?$Bof(B)
    (?$(D3I(B ?$(D2s(B ?$(D4b(B)
    (?$(D3J(B ?$(D3A(B)
    (?$(D3L(B ?$BY$(B)
    (?$(D3S(B ?$B<A(B ?$BlD(B)
    (?$(D3f(B ?$BIR(B)
    (?$(D3h(B ?$BM&(B)
    (?$(D3n(B ?$B7.(B ?$BR.(B)
    (?$(D3}(B ?$B5E(B)
    (?$(D4$(B ?$BG>(B ?$Bg*(B)
    (?$(D4%(B ?$B[M(B)
    (?$(D4'(B ?$B>"(B)
    (?$(D4*(B ?$Bd:(B)
    (?$(D4+(B ?$BB"(B ?$Bi6(B)
    (?$(D4,(B ?$B6)(B)
    (?$(D41(B ?$BR=(B ?$BT~(B)
    (?$(D48(B ?$B@$(B ?$BRB(B)
    (?$(D4:(B ?$BN((B)
    (?$(D4A(B ?$(D_.(B)
    (?$(D4D(B ?$Bby(B)
    (?$(D4E(B ?$BRL(B)
    (?$(D4F(B ?$BEV(B)
    (?$(D4G(B ?$B33(B)
    (?$(D4K(B ?$B86(B)
    (?$(D4O(B ?$BNq(B)
    (?$(D4R(B ?$B8;(B)
    (?$(D4S(B ?$B9O(B ?$BRS(B)
    (?$(D4T(B ?$BNY(B ?$BnC(B)
    (?$(D4U(B ?$B5n(B)
    (?$(D4X(B ?$B;2(B ?$BRT(B)
    (?$(D4Y(B ?$BTo(B)
    (?$(D4[(B ?$B;v(B ?$BP/(B)
    (?$(D4\(B ?$BDV(B)
    (?$(D4_(B ?$B0S(B)
    (?$(D4`(B ?$B>v(B ?$BaH(B ?$BaI(B ?$BaJ(B)
    (?$(D4b(B ?$(D2s(B ?$(D3I(B)
    (?$(D4m(B ?$B8b(B)
    (?$(D4r(B ?$BR_(B)
    (?$(D4x(B ?$BkI(B)
    (?$(D4y(B ?$BSO(B)
    (?$(D4{(B ?$(D]\(B)
    (?$(D5*(B ?$BS#(B)
    (?$(D5;(B ?$B6A(B)
    (?$(D5?(B ?$BkE(B)
    (?$(D5A(B ?$(DU&(B)
    (?$(D5E(B ?$BM6(B)
    (?$(D5`(B ?$B0"(B ?$(DMd(B)
    (?$(D5h(B ?$BE/(B ?$(D6](B)
    (?$(D5j(B ?$BS%(B)
    (?$(D5|(B ?$BGM(B)
    (?$(D6,(B ?$BS1(B)
    (?$(D6<(B ?$BC1(B ?$BSE(B)
    (?$(D6A(B ?$B5J(B)
    (?$(D6C(B ?$BS8(B)
    (?$(D6J(B ?$Bk~(B)
    (?$(D6S(B ?$BF;(B ?$(D\0(B ?$(D\1(B)
    (?$(D6Z(B ?$B3z(B ?$(DmN(B)
    (?$(D6](B ?$BE/(B ?$(D5h(B)
    (?$(D6l(B ?$BG9(B)
    (?$(D6n(B ?$Bge(B)
    (?$(D6r(B ?$B0x(B)
    (?$(D6u(B ?$(Dh0(B)
    (?$(D6y(B ?$BJ%(B ?$B^<(B ?$B^=(B)
    (?$(D6z(B ?$BQH(B)
    (?$(D6|(B ?$BAk(B ?$BcY(B ?$(DJQ(B ?$(DJU(B ?$(DQb(B)
    (?$(D7!(B ?$B9q(B ?$BS{(B ?$BT"(B)
    (?$(D7((B ?$BJ`(B)
    (?$(D7,(B ?$B]3(B)
    (?$(D74(B ?$(DBy(B)
    (?$(D7C(B ?$(D8A(B)
    (?$(D7D(B ?$BBK(B ?$(DfS(B)
    (?$(D7F(B ?$BE%(B)
    (?$(D7G(B ?$BBf(B)
    (?$(D7I(B ?$(D7a(B)
    (?$(D7M(B ?$B5V(B)
    (?$(D7W(B ?$(Df\(B)
    (?$(D7`(B ?$B8|(B)
    (?$(D7a(B ?$(D7I(B)
    (?$(D7b(B ?$B<i(B)
    (?$(D7c(B ?$B@;(B)
    (?$(D7h(B ?$(DfV(B)
    (?$(D7m(B ?$BDi(B)
    (?$(D7o(B ?$BOR(B)
    (?$(D7w(B ?$BA](B)
    (?$(D7z(B ?$B:%(B)
    (?$(D8'(B ?$B3,(B)
    (?$(D8/(B ?$(DM?(B)
    (?$(D81(B ?$BA:(B)
    (?$(D83(B ?$BAr(B)
    (?$(D84(B ?$BE6(B)
    (?$(D85(B ?$(D8T(B)
    (?$(D8A(B ?$(D7C(B)
    (?$(D8F(B ?$BEc(B)
    (?$(D8O(B ?$BG8(B ?$BLn(B)
    (?$(D8S(B ?$BTO(B)
    (?$(D8T(B ?$(D85(B)
    (?$(D8U(B ?$B<%(B)
    (?$(D8[(B ?$B1C(B ?$BbO(B)
    (?$(D8^(B ?$B3L(B ?$B]W(B)
    (?$(D8_(B ?$B9_(B)
    (?$(D8d(B ?$B2F(B)
    (?$(D8e(B ?$(D8f(B)
    (?$(D8f(B ?$(D8e(B)
    (?$(D8i(B ?$BL4(B ?$BTm(B)
    (?$(D8n(B ?$BBY(B)
    (?$(D8p(B ?$BHf(B)
    (?$(D9+(B ?$BEJ(B)
    (?$(D95(B ?$(D:8(B)
    (?$(D96(B ?$BLE(B)
    (?$(D9=(B ?$B;P(B)
    (?$(D9?(B ?$(D9Z(B)
    (?$(D9E(B ?$B4/(B)
    (?$(D9F(B ?$BUC(B)
    (?$(D9M(B ?$BO,(B)
    (?$(D9Q(B ?$BU((B)
    (?$(D9U(B ?$BU#(B)
    (?$(D9Z(B ?$(D9?(B)
    (?$(D9c(B ?$B0y(B)
    (?$(D9{(B ?$BV,(B)
    (?$(D9~(B ?$BXC(B ?$(DUg(B)
    (?$(D:,(B ?$BX^(B ?$(DN'(B)
    (?$(D:5(B ?$BU>(B)
    (?$(D:8(B ?$(D95(B)
    (?$(D:C(B ?$(D:D(B)
    (?$(D:D(B ?$(D:C(B)
    (?$(D:I(B ?$BcV(B)
    (?$(D:J(B ?$BFM(B)
    (?$(D:L(B ?$B59(B ?$(D2u(B)
    (?$(D:X(B ?$B?3(B)
    (?$(D:Z(B ?$BQN(B ?$BUd(B)
    (?$(D:](B ?$BG+(B)
    (?$(D:`(B ?$(DM*(B)
    (?$(D:c(B ?$BJu(B ?$BUo(B ?$BUp(B)
    (?$(D:k(B ?$B_y(B)
    (?$(D:l(B ?$BUv(B)
    (?$(D:m(B ?$BUw(B)
    (?$(D:o(B ?$(D:p(B)
    (?$(D:p(B ?$(D:o(B)
    (?$(D:t(B ?$(D3,(B ?$(D:v(B)
    (?$(D:v(B ?$(D3,(B ?$(D:t(B)
    (?$(D:z(B ?$B<H(B)
    (?$(D;*(B ?$Bl.(B)
    (?$(D;6(B ?$BVO(B)
    (?$(D;Y(B ?$B7L(B ?$B^d(B ?$Bl0(B ?$(DP((B)
    (?$(D;s(B ?$B1|(B ?$BT|(B)
    (?$(D;u(B ?$BEg(B ?$BEh(B ?$BV:(B)
    (?$(D<$(B ?$(Da:(B)
    (?$(D<'(B ?$BB^(B)
    (?$(D<)(B ?$(DSa(B)
    (?$(D<-(B ?$BVs(B ?$(D<=(B)
    (?$(D<=(B ?$BVs(B ?$(D<-(B)
    (?$(D<M(B ?$B6w(B)
    (?$(D<O(B ?$BI@(B)
    (?$(D<`(B ?$B;0(B)
    (?$(D<o(B ?$BI+(B)
    (?$(D<w(B ?$BW@(B)
    (?$(D<z(B ?$BW3(B ?$BW4(B)
    (?$(D<{(B ?$(DXn(B)
    (?$(D=#(B ?$(D0I(B)
    (?$(D=+(B ?$Bp"(B)
    (?$(D=2(B ?$B7r(B)
    (?$(D=5(B ?$B@,(B)
    (?$(D=6(B ?$(D24(B)
    (?$(D=8(B ?$B?4(B)
    (?$(D=D(B ?$B8g(B)
    (?$(D=F(B ?$BWd(B ?$(D=y(B)
    (?$(D=U(B ?$(D0g(B)
    (?$(D=e(B ?$B;W(B)
    (?$(D=h(B ?$BX'(B)
    (?$(D=j(B ?$B1Y(B)
    (?$(D=k(B ?$BK;(B)
    (?$(D=r(B ?$BI](B)
    (?$(D=s(B ?$BPW(B)
    (?$(D=y(B ?$BWd(B ?$(D=F(B)
    (?$(D={(B ?$B<$(B ?$BUu(B ?$(D0^(B ?$(D0_(B ?$(D2X(B)
    (?$(D>0(B ?$B6U(B ?$(D1G(B)
    (?$(D>2(B ?$BbJ(B)
    (?$(D>6(B ?$Bjo(B)
    (?$(D>8(B ?$BX#(B)
    (?$(D>C(B ?$BWm(B)
    (?$(D>Z(B ?$BXa(B)
    (?$(D>\(B ?$BX;(B)
    (?$(D>c(B ?$BX[(B)
    (?$(D>d(B ?$BXZ(B)
    (?$(D>|(B ?$BXo(B)
    (?$(D?.(B ?$BAO(B)
    (?$(D?S(B ?$(D?T(B)
    (?$(D?T(B ?$(D?S(B)
    (?$(D?\(B ?$B3H(B ?$BZ2(B)
    (?$(D?](B ?$BO.(B ?$(D?g(B)
    (?$(D?g(B ?$BO.(B ?$(D?](B)
    (?$(D?k(B ?$B3I(B ?$BYx(B)
    (?$(D@$(B ?$B@3(B ?$B@4(B)
    (?$(D@>(B ?$BY)(B)
    (?$(D@K(B ?$BA_(B)
    (?$(D@[(B ?$BDO(B)
    (?$(D@d(B ?$BAm(B ?$BeA(B ?$(DT8(B)
    (?$(D@o(B ?$(D@p(B)
    (?$(D@p(B ?$(D@o(B)
    (?$(D@v(B ?$BA`(B)
    (?$(DA!(B ?$BN:(B)
    (?$(DA#(B ?$B7b(B)
    (?$(DA((B ?$B@\(B)
    (?$(DA)(B ?$B7H(B ?$BZ8(B)
    (?$(DA,(B ?$BZ0(B)
    (?$(DA1(B ?$BK`(B)
    (?$(DA2(B ?$Bk#(B)
    (?$(DA7(B ?$(DAA(B)
    (?$(DA9(B ?$BZ6(B)
    (?$(DAA(B ?$(DA7(B)
    (?$(DAB(B ?$BZ9(B)
    (?$(DAT(B ?$B6n(B ?$B6o(B ?$Bq\(B)
    (?$(DAV(B ?$(DEw(B)
    (?$(DAW(B ?$B3X(B ?$BU\(B ?$BU](B)
    (?$(DAX(B ?$B@F(B ?$Bsn(B ?$(D0@(B)
    (?$(DAf(B ?$BZX(B)
    (?$(DAg(B ?$BI_(B)
    (?$(DAl(B ?$BVp(B)
    (?$(DAr(B ?$B;~(B)
    (?$(DAs(B ?$B=U(B)
    (?$(DAt(B ?$BZm(B)
    (?$(DB&(B ?$BZ_(B)
    (?$(DB*(B ?$B:*(B)
    (?$(DB,(B ?$B@'(B)
    (?$(DB=(B ?$BZp(B)
    (?$(DB?(B ?$B>:(B)
    (?$(DBK(B ?$B2"(B)
    (?$(DBQ(B ?$B@2(B)
    (?$(DBU(B ?$BIa(B)
    (?$(DBX(B ?$(DBY(B ?$(DNB(B)
    (?$(DBY(B ?$(DBX(B ?$(DNB(B)
    (?$(DBc(B ?$B>H(B ?$(DO;(B)
    (?$(DBh(B ?$BZo(B)
    (?$(DBk(B ?$B;/(B)
    (?$(DBm(B ?$BAb(B)
    (?$(DBo(B ?$Bjk(B)
    (?$(DBr(B ?$BL@(B)
    (?$(DBy(B ?$(D74(B)
    (?$(DC((B ?$B9=(B)
    (?$(DC*(B ?$BFo(B)
    (?$(DC5(B ?$(DCO(B)
    (?$(DC8(B ?$B3A(B)
    (?$(DC@(B ?$B>>(B ?$B[@(B ?$(DCu(B)
    (?$(DCE(B ?$BF`(B)
    (?$(DCI(B ?$B7,(B)
    (?$(DCO(B ?$(DC5(B)
    (?$(DCS(B ?$BH5(B)
    (?$(DC[(B ?$BBn(B)
    (?$(DC^(B ?$BDG(B)
    (?$(DCg(B ?$(DDt(B)
    (?$(DCh(B ?$BLx(B)
    (?$(DCj(B ?$B<?(B)
    (?$(DCl(B ?$(DDn(B)
    (?$(DCu(B ?$B>>(B ?$B[@(B ?$(DC@(B)
    (?$(DD6(B ?$B>h(B ?$BP+(B)
    (?$(DD<(B ?$BDv(B ?$(DOK(B)
    (?$(DD\(B ?$B44(B)
    (?$(DDd(B ?$(Dbn(B)
    (?$(DDf(B ?$BfU(B ?$(De,(B)
    (?$(DDg(B ?$BG_(B ?$BG`(B)
    (?$(DDi(B ?$B66(B)
    (?$(DDn(B ?$(DCl(B)
    (?$(DDt(B ?$(DCg(B)
    (?$(DDv(B ?$BNB(B)
    (?$(DE"(B ?$BAQ(B ?$(DYo(B)
    (?$(DE)(B ?$B\X(B)
    (?$(DE4(B ?$B?_(B ?$BW$(B)
    (?$(DE8(B ?$(DE\(B)
    (?$(DE9(B ?$B?y(B)
    (?$(DE?(B ?$B\7(B)
    (?$(DEF(B ?$B4}(B ?$B[w(B)
    (?$(DEM(B ?$(D3-(B)
    (?$(DEN(B ?$(DUZ(B)
    (?$(DEQ(B ?$(DEd(B)
    (?$(DE\(B ?$(DE8(B)
    (?$(DEd(B ?$(DEQ(B)
    (?$(DEe(B ?$BMs(B)
    (?$(DEg(B ?$B]2(B)
    (?$(DEh(B ?$B]C(B)
    (?$(DEm(B ?$B4>(B)
    (?$(DEo(B ?$(DEv(B)
    (?$(DEv(B ?$(DEo(B)
    (?$(DEw(B ?$(DAV(B)
    (?$(DE{(B ?$B=B(B ?$B_'(B ?$B_((B)
    (?$(DF!(B ?$B]G(B)
    (?$(DF:(B ?$B]a(B)
    (?$(DF>(B ?$B][(B)
    (?$(DF^(B ?$B1x(B)
    (?$(DFd(B ?$B]r(B)
    (?$(DFg(B ?$B^((B)
    (?$(DFh(B ?$B^w(B)
    (?$(DFl(B ?$BD@(B)
    (?$(DFo(B ?$BE:(B)
    (?$(DFt(B ?$B]}(B)
    (?$(DG8(B ?$B7i(B)
    (?$(DGU(B ?$(DH&(B)
    (?$(DH%(B ?$B=_(B)
    (?$(DH&(B ?$(DGU(B)
    (?$(DHA(B ?$B36(B)
    (?$(DHU(B ?$BH.(B)
    (?$(DHl(B ?$B9@(B)
    (?$(DHn(B ?$B_4(B)
    (?$(DHw(B ?$B_R(B)
    (?$(DI!(B ?$(DI2(B)
    (?$(DI&(B ?$BIM(B ?$B_@(B)
    (?$(DI,(B ?$BFB(B)
    (?$(DI2(B ?$(DI!(B)
    (?$(DI<(B ?$BK!(B ?$(D0u(B)
    (?$(DI=(B ?$(DIA(B)
    (?$(DI@(B ?$BGF(B ?$B[1(B)
    (?$(DIA(B ?$(DI=(B)
    (?$(DIE(B ?$B8w(B ?$(DIO(B)
    (?$(DIF(B ?$BNn(B ?$BpM(B ?$(Dg%(B)
    (?$(DIG(B ?$B3v(B ?$Bc^(B)
    (?$(DIH(B ?$B:R(B ?$(DI](B)
    (?$(DII(B ?$B5$(B ?$B]f(B)
    (?$(DIO(B ?$B8w(B ?$(DIE(B)
    (?$(DIX(B ?$B_l(B)
    (?$(DI](B ?$B:R(B ?$(DIH(B)
    (?$(DIf(B ?$Bny(B)
    (?$(DIi(B ?$BP4(B)
    (?$(DIm(B ?$B_i(B)
    (?$(DIo(B ?$B1k(B ?$(DJ4(B)
    (?$(DIs(B ?$BCC(B)
    (?$(DI}(B ?$B;&(B)
    (?$(DJ+(B ?$B_b(B)
    (?$(DJ/(B ?$BL!(B)
    (?$(DJ0(B ?$B_t(B)
    (?$(DJ3(B ?$(DJC(B)
    (?$(DJ4(B ?$B1k(B ?$(DIo(B)
    (?$(DJ6(B ?$BJ2(B ?$(DJ7(B)
    (?$(DJ7(B ?$BJ2(B ?$(DJ6(B)
    (?$(DJC(B ?$(DJ3(B)
    (?$(DJG(B ?$B`%(B)
    (?$(DJJ(B ?$BZ<(B)
    (?$(DJO(B ?$B\D(B)
    (?$(DJQ(B ?$BAk(B ?$BcY(B ?$(D6|(B ?$(DJU(B ?$(DQb(B)
    (?$(DJT(B ?$B\V(B)
    (?$(DJU(B ?$BAk(B ?$BcY(B ?$(D6|(B ?$(DJQ(B ?$(DQb(B)
    (?$(DJ](B ?$BH2(B ?$(D2)(B)
    (?$(DJp(B ?$(D^|(B)
    (?$(DJt(B ?$(D^}(B)
    (?$(DJu(B ?$B`O(B)
    (?$(DJz(B ?$BWN(B)
    (?$(DK!(B ?$(DK*(B)
    (?$(DK"(B ?$BW{(B)
    (?$(DK%(B ?$(DZ:(B)
    (?$(DK'(B ?$BC,(B ?$Bl>(B)
    (?$(DK*(B ?$(DK!(B)
    (?$(DK0(B ?$B1n(B)
    (?$(DK1(B ?$Biv(B)
    (?$(DK3(B ?$(DKB(B)
    (?$(DK4(B ?$(DKI(B)
    (?$(DK9(B ?$B6@(B)
    (?$(DK:(B ?$(Dlg(B)
    (?$(DKB(B ?$(DK3(B)
    (?$(DKE(B ?$(DKN(B)
    (?$(DKI(B ?$(DK4(B)
    (?$(DKN(B ?$(DKE(B)
    (?$(DKO(B ?$(D\"(B ?$(D_((B)
    (?$(DKP(B ?$BL/(B)
    (?$(DKs(B ?$B6W(B ?$(DL6(B)
    (?$(DKz(B ?$(DOq(B)
    (?$(DL'(B ?$B`t(B)
    (?$(DL6(B ?$B6W(B ?$(DKs(B)
    (?$(DL;(B ?$B`^(B)
    (?$(DLE(B ?$(DL[(B)
    (?$(DL[(B ?$(DLE(B)
    (?$(DLk(B ?$(DLp(B)
    (?$(DLl(B ?$B`s(B)
    (?$(DLp(B ?$(DLk(B)
    (?$(DLu(B ?$Be}(B)
    (?$(DLx(B ?$Ba.(B)
    (?$(DL~(B ?$Ba*(B)
    (?$(DM"(B ?$Bf"(B)
    (?$(DM*(B ?$(D:`(B)
    (?$(DM-(B ?$(DM4(B)
    (?$(DM4(B ?$(DM-(B)
    (?$(DM6(B ?$B@&(B ?$Ba<(B ?$(DM8(B)
    (?$(DM8(B ?$B@&(B ?$Ba<(B ?$(DM6(B)
    (?$(DM:(B ?$BT6(B)
    (?$(DM<(B ?$BN1(B ?$Ba7(B)
    (?$(DM>(B ?$(DMD(B)
    (?$(DM?(B ?$(D8/(B)
    (?$(DMB(B ?$BN](B ?$BT^(B)
    (?$(DMD(B ?$(DM>(B)
    (?$(DMM(B ?$Ba^(B)
    (?$(DM_(B ?$BD1(B)
    (?$(DMb(B ?$Bac(B)
    (?$(DMd(B ?$B0"(B ?$(D5`(B)
    (?$(DMw(B ?$BAi(B)
    (?$(DN!(B ?$Baq(B)
    (?$(DN'(B ?$BX^(B ?$(D:,(B)
    (?$(DN((B ?$Ban(B)
    (?$(DN+(B ?$Ba~(B ?$(DVV(B)
    (?$(DN2(B ?$(DV_(B)
    (?$(DN8(B ?$BB((B)
    (?$(DNB(B ?$(DBX(B ?$(DBY(B)
    (?$(DNE(B ?$B@1(B)
    (?$(DNI(B ?$B1N(B)
    (?$(DNP(B ?$(DRh(B)
    (?$(DN](B ?$B;k(B)
    (?$(DNo(B ?$B=0(B)
    (?$(DO!(B ?$BbN(B)
    (?$(DO4(B ?$(DO?(B)
    (?$(DO6(B ?$BbU(B)
    (?$(DO;(B ?$B>H(B ?$(DBc(B)
    (?$(DO?(B ?$(DO4(B)
    (?$(DOA(B ?$BbW(B)
    (?$(DOE(B ?$BGj(B ?$(D]L(B)
    (?$(DOF(B ?$B8t(B)
    (?$(DOK(B ?$BDv(B ?$(DD<(B)
    (?$(DOk(B ?$Bc&(B)
    (?$(DOq(B ?$(DKz(B)
    (?$(DOu(B ?$BVI(B)
    (?$(DOv(B ?$Bpb(B)
    (?$(DO|(B ?$B84(B ?$(Dl[(B)
    (?$(DP!(B ?$B3N(B)
    (?$(DP$(B ?$Bbg(B)
    (?$(DP((B ?$B7L(B ?$B^d(B ?$Bl0(B ?$(D;Y(B)
    (?$(DP)(B ?$Bp((B)
    (?$(DP9(B ?$B9[(B ?$B9\(B ?$Bbh(B ?$BoJ(B)
    (?$(DP<(B ?$B81(B ?$Bp*(B)
    (?$(DPC(B ?$B<'(B)
    (?$(DPM(B ?$(DPq(B)
    (?$(DPp(B ?$BEx(B)
    (?$(DPq(B ?$(DPM(B)
    (?$(DPv(B ?$B7](B ?$Bi:(B)
    (?$(DPw(B ?$(DS*(B)
    (?$(DPx(B ?$BG/(B)
    (?$(DPz(B ?$Bdk(B ?$(DQ-(B)
    (?$(DQ%(B ?$B[2(B)
    (?$(DQ((B ?$(DQ7(B)
    (?$(DQ-(B ?$Bdk(B ?$(DPz(B)
    (?$(DQ7(B ?$(DQ((B)
    (?$(DQ>(B ?$BCU(B ?$BcP(B)
    (?$(DQ@(B ?$(DS-(B)
    (?$(DQM(B ?$B>N(B ?$BcJ(B)
    (?$(DQV(B ?$(DQ_(B)
    (?$(DQY(B ?$BMR(B ?$Bc_(B)
    (?$(DQ_(B ?$(DQV(B)
    (?$(DQb(B ?$BAk(B ?$BcY(B ?$(D6|(B ?$(DJQ(B ?$(DJU(B)
    (?$(DQd(B ?$B5g(B)
    (?$(DQk(B ?$B5C(B)
    (?$(DQr(B ?$(DRS(B)
    (?$(DQt(B ?$BI.(B)
    (?$(DQu(B ?$Bd2(B)
    (?$(DQw(B ?$B:v(B)
    (?$(DR>(B ?$(DRQ(B)
    (?$(DR@(B ?$Bd#(B ?$Bd$(B)
    (?$(DRA(B ?$Bd&(B)
    (?$(DRN(B ?$(DRs(B)
    (?$(DRQ(B ?$(DR>(B)
    (?$(DRS(B ?$(DQr(B)
    (?$(DRT(B ?$BWB(B)
    (?$(DR\(B ?$BdA(B ?$(DS%(B)
    (?$(DR_(B ?$B^v(B)
    (?$(DRh(B ?$(DNP(B)
    (?$(DRm(B ?$BdY(B)
    (?$(DRs(B ?$(DRN(B)
    (?$(DRw(B ?$BdZ(B)
    (?$(DS%(B ?$BdA(B ?$(DR\(B)
    (?$(DS*(B ?$(DPw(B)
    (?$(DS-(B ?$(DQ@(B)
    (?$(DS2(B ?$BNU(B)
    (?$(DS;(B ?$(Dh_(B)
    (?$(DS=(B ?$Bdp(B)
    (?$(DS@(B ?$B9r(B)
    (?$(DSB(B ?$(Dhf(B)
    (?$(DSG(B ?$(Dhn(B)
    (?$(DST(B ?$(DSb(B)
    (?$(DSV(B ?$(DT'(B)
    (?$(DSa(B ?$(D<)(B)
    (?$(DSb(B ?$(DST(B)
    (?$(DSg(B ?$(DT7(B)
    (?$(DSi(B ?$B8S(B)
    (?$(DSj(B ?$Bh*(B)
    (?$(DSn(B ?$BKz(B ?$(D[p(B)
    (?$(DSs(B ?$BE}(B)
    (?$(DSx(B ?$B9I(B)
    (?$(DS}(B ?$Be%(B)
    (?$(DT%(B ?$Be^(B)
    (?$(DT'(B ?$(DSV(B)
    (?$(DT/(B ?$BeN(B)
    (?$(DT5(B ?$Bjp(B)
    (?$(DT7(B ?$(DSg(B)
    (?$(DT8(B ?$BAm(B ?$BeA(B ?$(D@d(B)
    (?$(DTG(B ?$Be6(B)
    (?$(DTH(B ?$BKZ(B)
    (?$(DTM(B ?$(Di#(B)
    (?$(DTW(B ?$B=+(B)
    (?$(DTZ(B ?$B7R(B)
    (?$(DT[(B ?$(DgX(B)
    (?$(DTc(B ?$Be-(B)
    (?$(DTg(B ?$Bes(B)
    (?$(DTk(B ?$B7g(B ?$Be~(B)
    (?$(DTl(B ?$B4L(B ?$Bf%(B)
    (?$(DTm(B ?$BH-(B)
    (?$(DTt(B ?$Bf&(B ?$(DTu(B)
    (?$(DTu(B ?$Bf&(B ?$(DTt(B)
    (?$(DU&(B ?$(D5A(B)
    (?$(DU)(B ?$(DU*(B)
    (?$(DU*(B ?$(DU)(B)
    (?$(DU,(B ?$Bf5(B)
    (?$(DU1(B ?$BM\(B)
    (?$(DU3(B ?$Bf?(B)
    (?$(DUH(B ?$(DUI(B)
    (?$(DUI(B ?$(DUH(B)
    (?$(DUJ(B ?$BfO(B)
    (?$(DUZ(B ?$(DEN(B)
    (?$(DUb(B ?$B?&(B ?$(D`W(B)
    (?$(DUf(B ?$BAo(B ?$Bfb(B)
    (?$(DUg(B ?$BXC(B ?$(D9~(B)
    (?$(DUk(B ?$BH%(B)
    (?$(DUl(B ?$B9N(B)
    (?$(DUp(B ?$Bfu(B)
    (?$(DU}(B ?$B0v(B)
    (?$(DV((B ?$B@H(B ?$(DV5(B)
    (?$(DV)(B ?$B6<(B)
    (?$(DV4(B ?$B8T(B)
    (?$(DV5(B ?$B@H(B ?$(DV((B)
    (?$(DV<(B ?$Bg#(B)
    (?$(DVB(B ?$Bs{(B)
    (?$(DVF(B ?$Bg0(B)
    (?$(DVT(B ?$BC@(B ?$Bg<(B)
    (?$(DVU(B ?$Bg=(B)
    (?$(DVV(B ?$Ba~(B ?$(DN+(B)
    (?$(DVZ(B ?$(Dii(B)
    (?$(DV_(B ?$(DN2(B)
    (?$(DVd(B ?$B=-(B)
    (?$(DVp(B ?$BgS(B)
    (?$(DW((B ?$Bgb(B)
    (?$(DW8(B ?$BRC(B)
    (?$(DWG(B ?$B2V(B)
    (?$(DWO(B ?$(DWy(B)
    (?$(DWS(B ?$Bgo(B)
    (?$(DW[(B ?$B8V(B)
    (?$(DWa(B ?$Bh$(B)
    (?$(DWc(B ?$Bh-(B)
    (?$(DWv(B ?$(DX*(B)
    (?$(DWy(B ?$(DWO(B)
    (?$(DX*(B ?$(DWv(B)
    (?$(DX4(B ?$BhO(B)
    (?$(DX;(B ?$(DXX(B)
    (?$(DXC(B ?$(DXO(B)
    (?$(DXG(B ?$BMi(B)
    (?$(DXJ(B ?$Bi5(B)
    (?$(DXO(B ?$(DXC(B)
    (?$(DXR(B ?$B0C(B ?$Bh?(B)
    (?$(DXX(B ?$(DX;(B)
    (?$(DXZ(B ?$B\;(B)
    (?$(DX\(B ?$(DY_(B)
    (?$(DX`(B ?$Bi)(B)
    (?$(DXk(B ?$Bhs(B)
    (?$(DXm(B ?$Bh.(B)
    (?$(DXn(B ?$(D<{(B)
    (?$(DXo(B ?$(DY=(B)
    (?$(DY&(B ?$BhL(B)
    (?$(DY2(B ?$B2.(B)
    (?$(DY6(B ?$B>U(B)
    (?$(DY8(B ?$BG,(B)
    (?$(DY<(B ?$(DYk(B)
    (?$(DY=(B ?$(DXo(B)
    (?$(DY>(B ?$BKc(B)
    (?$(DY?(B ?$BdG(B)
    (?$(DYC(B ?$B2Z(B)
    (?$(DYW(B ?$B3~(B ?$(DY~(B ?$(DZ'(B)
    (?$(DY_(B ?$(DX\(B)
    (?$(DYk(B ?$(DY<(B)
    (?$(DYo(B ?$BAQ(B ?$(DE"(B)
    (?$(DYt(B ?$BI#(B)
    (?$(DYw(B ?$(DZ5(B ?$(DZ8(B)
    (?$(DY|(B ?$B9F(B ?$BcL(B)
    (?$(DY~(B ?$B3~(B ?$(DYW(B ?$(DZ'(B)
    (?$(DZ%(B ?$B70(B)
    (?$(DZ&(B ?$Bqg(B)
    (?$(DZ'(B ?$B3~(B ?$(DYW(B ?$(DY~(B)
    (?$(DZ5(B ?$(DYw(B ?$(DZ8(B)
    (?$(DZ8(B ?$(DYw(B ?$(DZ5(B)
    (?$(DZ:(B ?$(DK%(B)
    (?$(DZ<(B ?$B5u(B)
    (?$(DZ?(B ?$B8W(B ?$BiI(B)
    (?$(DZF(B ?$(DZG(B)
    (?$(DZG(B ?$(DZF(B)
    (?$(DZH(B ?$B<X(B)
    (?$(DZN(B ?$(D[=(B)
    (?$(DZY(B ?$Bi\(B)
    (?$(DZp(B ?$B3-(B)
    (?$(D[#(B ?$BiS(B)
    (?$(D[&(B ?$BiR(B)
    (?$(D[)(B ?$Br4(B)
    (?$(D[-(B ?$B;=(B ?$BjD(B ?$(D\!(B)
    (?$(D[1(B ?$Bj@(B)
    (?$(D[=(B ?$(DZN(B)
    (?$(D[E(B ?$B5B(B)
    (?$(D[F(B ?$BjE(B ?$BjF(B)
    (?$(D[J(B ?$Bib(B)
    (?$(D[R(B ?$B2c(B)
    (?$(D[e(B ?$BjB(B)
    (?$(D[p(B ?$BKz(B ?$(DSn(B)
    (?$(D[x(B ?$BO9(B)
    (?$(D[z(B ?$BK*(B)
    (?$(D\!(B ?$B;=(B ?$BjD(B ?$(D[-(B)
    (?$(D\"(B ?$(DKO(B ?$(D_((B)
    (?$(D\%(B ?$BnW(B)
    (?$(D\-(B ?$B9+(B)
    (?$(D\.(B ?$Bnr(B)
    (?$(D\0(B ?$BF;(B ?$(D6S(B ?$(D\1(B)
    (?$(D\1(B ?$BF;(B ?$(D6S(B ?$(D\0(B)
    (?$(D\G(B ?$B0A(B)
    (?$(D\K(B ?$BK+(B ?$Bjq(B)
    (?$(D\S(B ?$Bjj(B)
    (?$(D\X(B ?$(D\Y(B)
    (?$(D\Y(B ?$(D\X(B)
    (?$(D\e(B ?$B2{(B ?$BXg(B)
    (?$(D]#(B ?$Bk&(B)
    (?$(D]$(B ?$Bf3(B ?$Bf4(B ?$Bk+(B)
    (?$(D]&(B ?$B3P(B ?$Bk4(B)
    (?$(D]'(B ?$Bk,(B)
    (?$(D].(B ?$(D]2(B)
    (?$(D]1(B ?$(D]3(B)
    (?$(D]2(B ?$(D].(B)
    (?$(D]3(B ?$(D]1(B)
    (?$(D]4(B ?$B6Z(B)
    (?$(D]7(B ?$(D]?(B)
    (?$(D]?(B ?$(D]7(B)
    (?$(D]@(B ?$(D]A(B ?$(D]B(B)
    (?$(D]A(B ?$(D]@(B ?$(D]B(B)
    (?$(D]B(B ?$(D]@(B ?$(D]A(B)
    (?$(D]L(B ?$BGj(B ?$(DOE(B)
    (?$(D]P(B ?$B?.(B)
    (?$(D]U(B ?$BkM(B)
    (?$(D]\(B ?$(D4{(B)
    (?$(D]}(B ?$B>'(B)
    (?$(D^1(B ?$B7<(B)
    (?$(D^6(B ?$Bkc(B)
    (?$(D^@(B ?$(D^V(B)
    (?$(D^A(B ?$BSX(B)
    (?$(D^U(B ?$B4F(B)
    (?$(D^V(B ?$(D^@(B)
    (?$(D^W(B ?$Bks(B)
    (?$(D^[(B ?$Bk`(B)
    (?$(D^l(B ?$B1p(B ?$Bgf(B ?$(D^m(B)
    (?$(D^m(B ?$B1p(B ?$Bgf(B ?$(D^l(B)
    (?$(D^o(B ?$BFZ(B)
    (?$(D^t(B ?$(D_!(B)
    (?$(D^|(B ?$(DJp(B)
    (?$(D^}(B ?$(DJt(B)
    (?$(D_!(B ?$(D^t(B)
    (?$(D_$(B ?$B`N(B)
    (?$(D_%(B ?$BG-(B)
    (?$(D_((B ?$(DKO(B ?$(D\"(B)
    (?$(D_.(B ?$(D4A(B)
    (?$(D_5(B ?$BB3(B ?$Bet(B)
    (?$(D_7(B ?$BD"(B)
    (?$(D_9(B ?$(D1c(B)
    (?$(D_<(B ?$BlZ(B)
    (?$(D_@(B ?$BGT(B)
    (?$(D_C(B ?$B8-(B)
    (?$(D_P(B ?$(D_U(B)
    (?$(D_U(B ?$(D_P(B)
    (?$(D_W(B ?$(D`?(B)
    (?$(D_X(B ?$BS?(B)
    (?$(D_](B ?$(D`((B)
    (?$(D_t(B ?$Bfz(B)
    (?$(D_x(B ?$B5S(B)
    (?$(D`((B ?$(D_](B)
    (?$(D`-(B ?$(D`>(B ?$(D`K(B)
    (?$(D`0(B ?$BD}(B)
    (?$(D`<(B ?$Bm4(B ?$(D`F(B)
    (?$(D`>(B ?$(D`-(B ?$(D`K(B)
    (?$(D`?(B ?$(D_W(B)
    (?$(D`B(B ?$Bm2(B)
    (?$(D`F(B ?$Bm4(B ?$(D`<(B)
    (?$(D`K(B ?$(D`-(B ?$(D`>(B)
    (?$(D`N(B ?$BC?(B)
    (?$(D`P(B ?$Bm;(B)
    (?$(D`T(B ?$B6m(B)
    (?$(D`W(B ?$B?&(B ?$(DUb(B)
    (?$(D`_(B ?$BGZ(B)
    (?$(D`e(B ?$Bm_(B)
    (?$(D`i(B ?$(D`z(B)
    (?$(D`p(B ?$Bm^(B)
    (?$(D`z(B ?$(D`i(B)
    (?$(D`|(B ?$BmO(B)
    (?$(D`~(B ?$Bpk(B ?$(DgN(B)
    (?$(Da-(B ?$B<-(B ?$Bmf(B ?$(Da0(B)
    (?$(Da0(B ?$B<-(B ?$Bmf(B ?$(Da-(B)
    (?$(Da3(B ?$(Da4(B)
    (?$(Da4(B ?$(Da3(B)
    (?$(Da8(B ?$BA+(B)
    (?$(Da9(B ?$(DaC(B)
    (?$(Da:(B ?$(D<$(B)
    (?$(DaC(B ?$(Da9(B)
    (?$(DaM(B ?$Bmj(B)
    (?$(Da{(B ?$(Da|(B)
    (?$(Da|(B ?$(Da{(B)
    (?$(Db-(B ?$BO:(B)
    (?$(Db.(B ?$BIt(B)
    (?$(DbQ(B ?$(DbT(B)
    (?$(DbR(B ?$BW%(B)
    (?$(DbT(B ?$(DbQ(B)
    (?$(DbY(B ?$BZP(B)
    (?$(Db^(B ?$B=7(B ?$(Db{(B)
    (?$(Dbh(B ?$(DhZ(B)
    (?$(Dbi(B ?$BsD(B)
    (?$(Dbl(B ?$B=6(B)
    (?$(Dbm(B ?$B=f(B)
    (?$(Dbn(B ?$(DDd(B)
    (?$(Dbs(B ?$B>_(B)
    (?$(Dbw(B ?$BH0(B)
    (?$(Db{(B ?$B=7(B ?$(Db^(B)
    (?$(Dc$(B ?$(Dc((B ?$(Dc6(B)
    (?$(Dc((B ?$(Dc$(B ?$(Dc6(B)
    (?$(Dc1(B ?$Bnz(B)
    (?$(Dc6(B ?$(Dc$(B ?$(Dc((B)
    (?$(Dc<(B ?$B1t(B)
    (?$(DcL(B ?$(De:(B)
    (?$(DcM(B ?$(Dcj(B)
    (?$(Dcf(B ?$(Ddi(B)
    (?$(Dcj(B ?$(DcM(B)
    (?$(Dd0(B ?$Bnu(B)
    (?$(DdF(B ?$(Dex(B)
    (?$(DdI(B ?$(De%(B)
    (?$(DdL(B ?$BE4(B ?$Bnn(B ?$BoD(B ?$BoE(B)
    (?$(Ddi(B ?$(Dcf(B)
    (?$(Ddy(B ?$(DeF(B)
    (?$(Dd|(B ?$B4U(B ?$BoH(B)
    (?$(De#(B ?$Bo!(B)
    (?$(De%(B ?$(DdI(B)
    (?$(De)(B ?$B3m(B)
    (?$(De,(B ?$BfU(B ?$(DDf(B)
    (?$(De1(B ?$(Dm)(B)
    (?$(De4(B ?$(DeU(B)
    (?$(De:(B ?$(DcL(B)
    (?$(De<(B ?$B:?(B)
    (?$(DeF(B ?$(Ddy(B)
    (?$(DeS(B ?$Bo5(B)
    (?$(DeU(B ?$(De4(B)
    (?$(De`(B ?$B3y(B)
    (?$(Dei(B ?$BD8(B)
    (?$(Dej(B ?$Bo)(B)
    (?$(Dep(B ?$Bq.(B ?$(Dhu(B)
    (?$(Dex(B ?$(DdF(B)
    (?$(De}(B ?$BD9(B ?$(D2g(B)
    (?$(Df/(B ?$Boj(B)
    (?$(DfH(B ?$B1"(B ?$(D1$(B ?$(Dfa(B)
    (?$(DfI(B ?$BM[(B ?$(DfL(B)
    (?$(DfL(B ?$BM[(B ?$(DfI(B)
    (?$(DfN(B ?$Bou(B)
    (?$(DfS(B ?$BBK(B ?$(D7D(B)
    (?$(DfV(B ?$(D7h(B)
    (?$(Df\(B ?$(D7W(B)
    (?$(Df_(B ?$Bo}(B)
    (?$(Dfa(B ?$B1"(B ?$(D1$(B ?$(DfH(B)
    (?$(Dfh(B ?$Bp#(B ?$(Dfo(B)
    (?$(Dfi(B ?$B7d(B)
    (?$(Dfn(B ?$Bm3(B)
    (?$(Dfo(B ?$Bp#(B ?$(Dfh(B)
    (?$(Dft(B ?$(Dfy(B)
    (?$(Dfv(B ?$BsA(B)
    (?$(Dfx(B ?$B7\(B ?$Bs1(B)
    (?$(Dfy(B ?$(Dft(B)
    (?$(Df}(B ?$BL8(B ?$(Dg$(B)
    (?$(Dg$(B ?$BL8(B ?$(Df}(B)
    (?$(Dg%(B ?$BNn(B ?$BpM(B ?$(DIF(B)
    (?$(Dg'(B ?$(Dg((B)
    (?$(Dg((B ?$(Dg'(B)
    (?$(Dg-(B ?$BMk(B)
    (?$(Dg0(B ?$BDa(B ?$(Dg1(B ?$(DlU(B)
    (?$(Dg1(B ?$BDa(B ?$(Dg0(B ?$(DlU(B)
    (?$(Dg7(B ?$BLL(B)
    (?$(Dg8(B ?$(Dh"(B)
    (?$(Dg@(B ?$Be+(B)
    (?$(DgB(B ?$(DgC(B ?$(Dm,(B)
    (?$(DgC(B ?$(DgB(B ?$(Dm,(B)
    (?$(DgJ(B ?$(DgS(B)
    (?$(DgN(B ?$Bpk(B ?$(D`~(B)
    (?$(DgO(B ?$(Dgg(B)
    (?$(DgP(B ?$Bp^(B)
    (?$(DgS(B ?$(DgJ(B)
    (?$(DgV(B ?$B7$(B)
    (?$(DgX(B ?$(DT[(B)
    (?$(Dgg(B ?$(DgO(B)
    (?$(Dgl(B ?$Bpi(B)
    (?$(Dgm(B ?$(Dgn(B)
    (?$(Dgn(B ?$(Dgm(B)
    (?$(Dh"(B ?$(Dg8(B)
    (?$(Dh$(B ?$BKK(B)
    (?$(Dh((B ?$Bpu(B)
    (?$(Dh)(B ?$BI&(B)
    (?$(Dh0(B ?$(D6u(B)
    (?$(Dh3(B ?$BE?(B)
    (?$(Dh<(B ?$Bq*(B ?$(Dh?(B ?$(DhF(B)
    (?$(Dh?(B ?$Bq*(B ?$(Dh<(B ?$(DhF(B)
    (?$(DhF(B ?$Bq*(B ?$(Dh<(B ?$(Dh?(B)
    (?$(DhG(B ?$BIw(B ?$(D3+(B)
    (?$(DhH(B ?$B;A(B)
    (?$(DhO(B ?$(Dhx(B)
    (?$(DhZ(B ?$(Dbh(B)
    (?$(Dh](B ?$Bq/(B ?$(Dhc(B)
    (?$(Dh_(B ?$(DS;(B)
    (?$(Dhb(B ?$(Dhq(B)
    (?$(Dhc(B ?$Bq/(B ?$(Dh](B)
    (?$(Dhf(B ?$(DSB(B)
    (?$(Dhm(B ?$BA7(B)
    (?$(Dhn(B ?$(DSG(B)
    (?$(Dhq(B ?$(Dhb(B)
    (?$(Dhu(B ?$Bq.(B ?$(Dep(B)
    (?$(Dhx(B ?$(DhO(B)
    (?$(Dh}(B ?$(DiU(B)
    (?$(Di#(B ?$(DTM(B)
    (?$(Di$(B ?$Bqf(B)
    (?$(Di,(B ?$BqL(B)
    (?$(Di3(B ?$(DiF(B ?$(DiR(B)
    (?$(Di<(B ?$B83(B ?$Bqd(B)
    (?$(DiF(B ?$(Di3(B ?$(DiR(B)
    (?$(DiR(B ?$(Di3(B ?$(DiF(B)
    (?$(DiU(B ?$(Dh}(B)
    (?$(Di\(B ?$BBN(B ?$Bm<(B ?$Bm=(B ?$Bqs(B)
    (?$(Dii(B ?$(DVZ(B)
    (?$(Dik(B ?$Bq!(B ?$(DlT(B)
    (?$(Dio(B ?$(Diw(B)
    (?$(Dir(B ?$Br&(B ?$(Di}(B)
    (?$(Diw(B ?$(Dio(B)
    (?$(Di{(B ?$BDf(B)
    (?$(Di}(B ?$Br&(B ?$(Dir(B)
    (?$(Dj-(B ?$Br'(B)
    (?$(Dj0(B ?$BF.(B ?$Br,(B ?$(Dj2(B)
    (?$(Dj2(B ?$BF.(B ?$Br,(B ?$(Dj0(B)
    (?$(DjC(B ?$(DkS(B)
    (?$(DjE(B ?$(Djj(B)
    (?$(DjJ(B ?$(Dm"(B)
    (?$(DjL(B ?$Br^(B)
    (?$(DjW(B ?$BBd(B)
    (?$(Dj[(B ?$(Dk!(B)
    (?$(Dj_(B ?$Brh(B ?$(Djs(B)
    (?$(Djb(B ?$(Djh(B ?$(Dj}(B)
    (?$(Djh(B ?$(Djb(B ?$(Dj}(B)
    (?$(Djj(B ?$(DjE(B)
    (?$(Djl(B ?$(Djt(B)
    (?$(Djo(B ?$(Dk%(B)
    (?$(Djs(B ?$Brh(B ?$(Dj_(B)
    (?$(Djt(B ?$(Djl(B)
    (?$(Dj}(B ?$(Djb(B ?$(Djh(B)
    (?$(Dk!(B ?$(Dj[(B)
    (?$(Dk%(B ?$(Djo(B)
    (?$(Dk4(B ?$BrW(B)
    (?$(Dk@(B ?$Bsh(B ?$(Dm_(B)
    (?$(DkK(B ?$Br](B)
    (?$(DkS(B ?$(DjC(B)
    (?$(Dkc(B ?$(DlW(B)
    (?$(Dkh(B ?$(Dl8(B)
    (?$(Dkk(B ?$B:m(B)
    (?$(Dk{(B ?$Bp:(B)
    (?$(Dl"(B ?$Bs.(B)
    (?$(Dl4(B ?$B?w(B)
    (?$(Dl8(B ?$(Dkh(B)
    (?$(Dl?(B ?$B2*(B)
    (?$(DlI(B ?$B1m(B)
    (?$(DlJ(B ?$(DlK(B)
    (?$(DlK(B ?$(DlJ(B)
    (?$(DlT(B ?$Bq!(B ?$(Dik(B)
    (?$(DlU(B ?$BDa(B ?$(Dg0(B ?$(Dg1(B)
    (?$(DlW(B ?$(Dkc(B)
    (?$(Dl[(B ?$B84(B ?$(DO|(B)
    (?$(Dl^(B ?$(Dl`(B)
    (?$(Dl_(B ?$(Dlh(B)
    (?$(Dl`(B ?$(Dl^(B)
    (?$(Dlg(B ?$(DK:(B)
    (?$(Dlh(B ?$(Dl_(B)
    (?$(Dlj(B ?$BsO(B ?$BsP(B)
    (?$(Dlo(B ?$B9m(B)
    (?$(Dlp(B ?$BLM(B ?$BsQ(B)
    (?$(Dlv(B ?$(Dly(B)
    (?$(Dly(B ?$(Dlv(B)
    (?$(Dm"(B ?$(DjJ(B)
    (?$(Dm((B ?$BE$(B)
    (?$(Dm)(B ?$(De1(B)
    (?$(Dm,(B ?$(DgB(B ?$(DgC(B)
    (?$(Dm2(B ?$Bl:(B)
    (?$(Dm8(B ?$(Dm:(B)
    (?$(Dm:(B ?$(Dm8(B)
    (?$(DmB(B ?$BSL(B)
    (?$(DmE(B ?$Bsp(B)
    (?$(DmJ(B ?$(DmR(B)
    (?$(DmN(B ?$B3z(B ?$(D6Z(B)
    (?$(DmR(B ?$(DmJ(B)
    (?$(DmS(B ?$Bsx(B)
    (?$(Dm[(B ?$BN5(B ?$BN6(B)
    (?$(Dm_(B ?$Bsh(B ?$(Dk@(B)
    ])

(defun bin-search (target key)
  (let ((lo 0) 
	(hi (length target))
	(i))
    (while (> hi lo)
      (setq i (/ (+ hi lo) 2))
      (cond ((= (car (aref target i)) key) (setq lo hi))
	    ((> (car (aref target i)) key) (setq hi i))
	    ((< (car (aref target i)) key) (setq lo (+ i 1)))))
    (if (= (car (aref target i)) key) i -1)))

(defun jis-variant (code)
  (mapcar 'char-to-string
	  (let ((q))
	    (setq q (bin-search jis-variant-alist code))
	    (if (= q -1) '() (aref jis-variant-alist q)))))

(defun variant-input-jis ()
  (interactive)
  (let* ((variant (jis-variant (char-after (point))))
	 (inhibit-quit t)
	 (val))
    (if (eq variant nil)
	(message "$B0[BN;z$O$"$j$^$;$s!#(B")
      (setq val 
	    (menu:select-from-menu
	     (list 'menu "$B0[BN;z(B:" variant)))
      (if quit-flag
	  (setq quit-flag nil)
	(delete-char 1)
	(insert val)))))

(defvar charset-lc-alist
  '(("JIS X 0208"  lc-jp)
    ("JIS X 0212"  lc-jp2)
    ("GB 2312"     lc-gb)
    ("CNS 11643-1" lc-cns1)
    ("CNS 11643-2" lc-cns2)
    ("CNS 11643-3" lc-cns3)
    ("CNS 11643-4" lc-cns4)
    ("CNS 11643-5" lc-cns5)
    ("CNS 11643-6" lc-cns6)
    ("CNS 11643-7" lc-cns7)))

(defun lc-to-charset (lc)
  (defun ltc-iter (lc x)
    (cond 
     ((not x) "No Charsets Found")
     ((= (symbol-value (car (cdr (car x)))) lc)
      (car (car x)))
     (t (ltc-iter lc (cdr x)))))
  (ltc-iter lc charset-lc-alist))

;; $B%+!<%=%k$N$"$k>l=j$N4A;z$rD4$Y$k!#(B

(defun what-char ()
  (interactive)
  (let* ((ch (following-char))
	 (lc (char-component ch 0))
	 (charset (lc-to-charset lc))
	 (code1 (logand (char-component ch 1) 127))
	 (code2 (logand (char-component ch 2) 127)))
    (if (= code1 0) (message "ASCII, code = %02x" ch)
      (if (= code2 0) (message "lc = %d, code = %02x" lc code1)
;	(message "lc = %d, code = %02x%02x" lc code1 code2)))))
	(message "lc = %s, code = %02x%02x" charset code1 code2)))))

(autoload 'hexl-hex-string-to-integer "hexl")

;; JIS, GB, CNS$B$N4A;z$r%3!<%I$GF~NO$9$k!#(B

(defun char-input-by-code ()
  (interactive)
  (let* ((completion-ignore-case t)
	 (charset (completing-read "Which charset ? "
				charset-lc-alist
				nil t))
	 (lc-char (symbol-value (car (cdr (assoc charset charset-lc-alist)))))
         (cc-str (read-from-minibuffer "code (prefix 0x for hex code) = "))
	 (cc-q (string-match "^0x" cc-str))
	 (cc-h (if cc-q (/ (hexl-hex-string-to-integer (substring cc-str 2))
			   256)
		        (+ (/ (string-to-int cc-str) 100) 32)))
	 (cc-l (if cc-q (% (hexl-hex-string-to-integer (substring cc-str 2))
			   256)
		        (+ (% (string-to-int cc-str) 100) 32))))
    (if (or (< cc-h 33) (> cc-h 127) (< cc-l 33) (> cc-l 127))
	(message "Invalid code")
      (insert (make-character lc-char cc-h cc-l)))))


;;; variant-jis.el ends here
