;;; radical-jis.el -- JIS X 0208/0212 radicals and strokes data

;; Copyright (C) 1995 James William Breen

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; see the file COPYING.  If not, write to
;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

;;; Commentary:

;;
;;  The tables of radicals ($BIt<s(B) and strokes ($B2h?t(B) for JIS are taken from:
;;  kanjidic and kanjd212 by William Breen (j.breen@rdt.monash.edu.au)
;;
;;  For radical-stroke counting rules, please refer Appendix E of 
;;  kanjidic.doc.


(defvar radical-table-jis ; (busyu-table)
  '[0					; ignore
    (("$B0l(B" . "R1")
     ("$(D0)(B($B$\$&(B)" . "R2")
     ("$BP&(B" . "R3")
     ("$B%N(B" . "R4")
     ("$B25(B" . "R5")
     ("$BP-(B" . "R6")
     )
    (("$BFs(B" . "R7")
     ("$BP5(B" . "R8")
     ("$B?M(B" . "R9")
     ("$BQ9(B" . "R10")
     ("$BF~(B" . "R11")
     ("$BH,(B" . "R12")
     ("$BQD(B" . "R13")
     ("$BQL(B" . "R14")
     ("$BQR(B" . "R15")
     ("$BQ\(B" . "R16")
     ("$BQa(B" . "R17")
     ("$BEa(B" . "R18")
     ("$BNO(B" . "R19")
     ("$B<[(B" . "R20")
     ("$BR8(B" . "R21")
     ("$BR9(B" . "R22")
     ("$BR>(B" . "R23")
     ("$B==(B" . "R24")
     ("$BKN(B" . "R25")
     ("$BRG(B" . "R26")
     ("$BRL(B" . "R27")
     ("$BRS(B" . "R28")
     ("$BKt(B" . "R29")
     )
    (("$B8}(B" . "R30")
     ("$BSx(B" . "R31")
     ("$BEZ(B" . "R32")
     ("$B;N(B" . "R33")
     ("$BTi(B" . "R34")
     ("$BTj(B" . "R35")
     ("$BM<(B" . "R36")
     ("$BBg(B" . "R37")
     ("$B=w(B" . "R38")
     ("$B;R(B" . "R39")
     ("$BU_(B" . "R40")
     ("$B@#(B" . "R41")
     ("$B>.(B" . "R42")
     ("$BUw(B" . "R43")
     ("$BUy(B" . "R44")
     ("$BV%(B" . "R45")
     ("$B;3(B" . "R46")
     ("$BV_(B" . "R47")
     ("$B9)(B" . "R48")
     ("$B8J(B" . "R49")
     ("$B6R(B" . "R50")
     ("$B43(B" . "R51")
     ("$BVv(B" . "R52")
     ("$BVx(B" . "R53")
     ("$BW.(B" . "R54")
     ("$BW0(B" . "R55")
     ("$BW5(B" . "R56")
     ("$B5](B" . "R57")
     ("$BW@(B" . "R58")
     ("$BWD(B" . "R59")
     ("$BWF(B" . "R60")
     )
    (("$B?4(B" . "R61")
     ("$BXy(B" . "R62")
     ("$B8M(B" . "R63")
     ("$B<j(B" . "R64")
     ("$B;Y(B" . "R65")
     ("$BZ=(B" . "R66")
     ("$BJ8(B" . "R67")
     ("$BEM(B" . "R68")
     ("$B6T(B" . "R69")
     ("$BJ}(B" . "R70")
     ("$BZ\(B" . "R71")
     ("$BF|(B" . "R72")
     ("$B[)(B" . "R73")
     ("$B7n(B" . "R74")
     ("$BLZ(B" . "R75")
     ("$B7g(B" . "R76")
     ("$B;_(B" . "R77")
     ("$B]F(B" . "R78")
     ("$B]U(B" . "R79")
     ("$B]Y(B" . "R80")
     ("$BHf(B" . "R81")
     ("$BLS(B" . "R82")
     ("$B;a(B" . "R83")
     ("$B5$(B" . "R84")
     ("$B?e(B" . "R85")
     ("$B2P(B" . "R86")
     ("$BD^(B" . "R87")
     ("$BIc(B" . "R88")
     ("$B`+(B" . "R89")
     ("$B`-(B" . "R90")
     ("$BJR(B" . "R91")
     ("$B2g(B" . "R92")
     ("$B5m(B" . "R93")
     ("$B8$(B" . "R94")
     )
    (("$B8<(B" . "R95")
     ("$B6L(B" . "R96")
     ("$B1;(B" . "R97")
     ("$B4$(B" . "R98")
     ("$B4E(B" . "R99")
     ("$B@8(B" . "R100")
     ("$BMQ(B" . "R101")
     ("$BED(B" . "R102")
     ("$BI%(B" . "R103")
     ("$(DMF(B($B$d$^$$$@$l(B)" . "R104")
     ("$Bb"(B" . "R105")
     ("$BGr(B" . "R106")
     ("$BHi(B" . "R107")
     ("$B;.(B" . "R108")
     ("$BL\(B" . "R109")
     ("$BL7(B" . "R110")
     ("$BLp(B" . "R111")
     ("$B@P(B" . "R112")
     ("$B<((B" . "R113")
     ("$(DPr(B($B$0$&$N$"$7(B)" . "R114")
     ("$B2S(B" . "R115")
     ("$B7j(B" . "R116")
     ("$BN)(B" . "R117")
     )
    (("$BC](B" . "R118")
     ("$BJF(B" . "R119")
     ("$B;e(B" . "R120")
     ("$B4L(B" . "R121")
     ("$Bf&(B" . "R122")
     ("$BMS(B" . "R123")
     ("$B1)(B" . "R124")
     ("$BO7(B" . "R125")
     ("$B<)(B" . "R126")
     ("$BfP(B" . "R127")
     ("$B<*(B" . "R128")
     ("$Bff(B" . "R129")
     ("$BFy(B" . "R130")
     ("$B?C(B" . "R131")
     ("$B<+(B" . "R132")
     ("$B;j(B" . "R133")
     ("$B11(B" . "R134")
     ("$B@e(B" . "R135")
     ("$BA$(B" . "R136")
     ("$B=.(B" . "R137")
     ("$B:1(B" . "R138")
     ("$B?'(B" . "R139")
     ("$Bgg(B" . "R140")
     ("$BiH(B" . "R141")
     ("$BCn(B" . "R142")
     ("$B7l(B" . "R143")
     ("$B9T(B" . "R144")
     ("$B0a(B" . "R145")
     ("$Bk((B" . "R146")
     )
    (("$B8+(B" . "R147")
     ("$B3Q(B" . "R148")
     ("$B8@(B" . "R149")
     ("$BC+(B" . "R150")
     ("$BF&(B" . "R151")
     ("$Bl5(B" . "R152")
     ("$Bl8(B" . "R153")
     ("$B3-(B" . "R154")
     ("$B@V(B" . "R155")
     ("$BAv(B" . "R156")
     ("$BB-(B" . "R157")
     ("$B?H(B" . "R158")
     ("$B<V(B" . "R159")
     ("$B?I(B" . "R160")
     ("$BC$(B" . "R161")
     ("$(Da3(B($B$7$s$K$e$&(B)" . "R162")
     ("$BM8(B" . "R163")
     ("$BFS(B" . "R164")
     ("$BHP(B" . "R165")
     ("$BN$(B" . "R166")
     )
    (("$B6b(B" . "R167")
     ("$BD9(B" . "R168")
     ("$BLg(B" . "R169")
     ("$BIl(B" . "R170")
     ("$Bp0(B" . "R171")
     ("$Bp2(B" . "R172")
     ("$B1+(B" . "R173")
     ("$B@D(B" . "R174")
     ("$BHs(B" . "R175")
     )
    (("$BLL(B" . "R176")
     ("$B3W(B" . "R177")
     ("$Bpj(B" . "R178")
     ("$Bpl(B" . "R179")
     ("$B2;(B" . "R180")
     ("$BJG(B" . "R181")
     ("$BIw(B" . "R182")
     ("$BHt(B" . "R183")
     ("$B?)(B" . "R184")
     ("$B<s(B" . "R185")
     ("$B9a(B" . "R186")
     )
    (("$BGO(B" . "R187")
     ("$B9|(B" . "R188")
     ("$B9b(B" . "R189")
     ("$Bqu(B" . "R190")
     ("$Br((B" . "R191")
     ("$Br.(B" . "R192")
     ("$Br/(B" . "R193")
     ("$B54(B" . "R194")
     )
    (("$B5{(B" . "R195")
     ("$BD;(B" . "R196")
     ("$BsC(B" . "R197")
     ("$B</(B" . "R198")
     ("$BsN(B" . "R199")
     ("$BKc(B" . "R200")
     )
    (("$B2+(B" . "R201")
     ("$B5P(B" . "R202")
     ("$B9u(B" . "R203")
     ("$Bsc(B" . "R204")
     )
    (("$Bsf(B" . "R205")
     ("$BE$(B" . "R206")
     ("$B8](B" . "R207")
     ("$BAM(B" . "R208")
     )
    (("$BI!(B" . "R209")
     ("$Bsn(B" . "R210")
     )
    (("$Bso(B" . "R211")
     )
    (("$BN6(B" . "R212")
     ("$Bs}(B" . "R213")
     )
    (("$Bs~(B" . "R214")
     )
    ])

(defvar radical-strokes-alist-jis ; (busyu-kakusu-alist)
  '(("R1"
     (1 . "$B0l(B")
     (2 . "$B<7Cz$(D0!0"0#(B")
     (3 . "$B2<;0>e>fK|M?$(D0$(B")
     (4 . "$B1/ITP"$(D0%(B")
     (5 . "$B3n5V@$J:P#(B")
     (6 . "$B:F>gN>OJ$(D0&(B")
     (7 . "$BV`$(D0'0((B")
     (8 . "$BJBb3(B")
     (9 . "$BOD(B")
     (11 . "$BX~_a(B")
     (12 . "$Bq$(B"))
    ("R2"
     (1 . "$(D0)(B")
     (3 . "$(D0*(B")
     (4 . "$BCfRA$(D0+0,0-(B")
     (5 . "$B5l:}=PP%RB(B")
     (6 . "$B1H=#(B")
     (7 . "$B6z(B")
     (8 . "$B2L(B")
     (10 . "$(D0.(B")
     (22 . "$BG9(B"))
    ("R3"
     (1 . "$BP&$(D0/00(B")
     (3 . "$B4]G7(B")
     (4 . "$BC0(B")
     (5 . "$B<gI,I9P'(B"))
    ("R4"
     (1 . "$BP((B")
     (2 . "$BG5P)$(D01(B")
     (3 . "$B5W5Z$(D02(B")
     (4 . "$BK3(B")
     (5 . "$B1J8CFcJ&(B")
     (6 . "$B0P$(D03(B")
     (7 . "$BEFiI(B")
     (8 . "$B>5P*(B")
     (9 . "$B0}>hH}(B")
     (10 . "$B1(P+(B")
     (11 . "$B3uAV(B")
     (15 . "$BfI(B")
     (17 . "$BiL(B")
     (24 . "$Br6(B"))
    ("R5"
     (1 . "$B25$(D04(B")
     (2 . "$B6e$(D05(B")
     (3 . "$B8pLi(B")
     (4 . "$(D06(B")
     (6 . "$(D0708(B")
     (7 . "$BMp(B")
     (8 . "$BF}$(D090:(B")
     (9 . "$(D0;(B")
     (11 . "$B4%$(D0<(B")
     (13 . "$BP,(B"))
    ("R6"
     (1 . "$BP-(B")
     (2 . "$BN;(B")
     (4 . "$BM=(B")
     (7 . "$BP/(B")
     (8 . "$B;v(B")
     (16 . "$BP.(B"))
    ("R7"
     (2 . "$BFs(B")
     (3 . "$BP2$(D0=(B")
     (4 . "$B0f1>8^8_$(D0>(B")
     (5 . "$(D0?(B")
     (6 . "$BOK(B")
     (7 . "$B0!(B")
     (8 . "$B:3P3P4$(D0@(B"))
    ("R8"
     (2 . "$BP5(B")
     (3 . "$BK4(B")
     (4 . "$BP6(B")
     (6 . "$B0g8rKr(B")
     (7 . "$B5|(B")
     (8 . "$B5}5~(B")
     (9 . "$BDbN<P7Tu$(D0A(B")
     (10 . "$BP8(B")
     (11 . "$B8#K#(B")
     (13 . "$BP9cH(B")
     (20 . "$BlW(B")
     (21 . "$(D0B(B"))
    ("R9"
     (2 . "$B?M(B")
     (3 . "$BP$(B")
     (4 . "$B2=2p5X:#=:?NJ)P:P;P<P=P>$(D0C0D(B")
     (5 . "$B0J;E;F@gB>BeIUNaP?P@PAPB$(D0E0F0G0H0I0J(B")
     (6 . "$B0K2>2q4k4l5Y6D7o8`A4CgEAG$H2IzPCPDPg$(D0K0L0M0N0O0P0Q0R0S0T0U0V0W0X0Y0Z0[0\(B")
     (7 . "$B0L2?2@:4:n;G;w=;?-BNC"DQDcGlH<M$M>MhNbPEPFPGPHPIPJ$(D0]0^0_0`0a0b0c0d0e0f0g0h0i0j0k0l0m0n0o0p0q(B")
     (8 . "$B0M2A2B4&6!6"8s;H;x<KInJ;KyNcPKPLPMPNPOPPPQPRPSPTPU$(D0r0s0t0u0v0w0x0y0z0{0|0}0~1!1"1#1$1%1&1'1(1)1*1+1,1-1.1/1011(B")
     (9 . "$B2d788t=S?.?/B%B/JXJ]KsN7PWPXPYPZP[P\P]P^P_P`$(D12131415161718191:1;1<1=1>1?1@1A1B1C1D1E(B")
     (10 . "$B266f7p7q8D8u8v<Z=$ARCME]GPG\I6JoJpNQOAPaPbPcPdPePfPhPiPjPkPlPmPnPoY=$(D1F1G1H1I1J1K1L1M1N1O1P1Q1R1S1T1U1V1W1X1Y1Z1[1\1]1^(B")
     (11 . "$B566v7r<EB&DdDeJPPpPqPsPtPuPvPwPxPyb6f{$(D1_1`1a1b1c1d1e1f1g1h1i1j1k1l1m1n1o1p1q1r1s1t1u1v(B")
     (12 . "$B0N;1HwK5PzP{P|fE$(D1w1x1y1z1{1|1}1~2!2"2#2$2%2&2'2(2)2*2+(B")
     (13 . "$B6O6Y797f:D=}ANF/L|MCP}P~Q!Q"Q#Q$$(D2,2-2.2/20212223242526(B")
     (14 . "$B6#A|KMN=Q%Q&Q'Q(Q)Q*$(D2728292:2;2<2=2>2?2@2A2B2C2D2E(B")
     (15 . "$B2/57JHJ^Q+Q,Q-Q.Q/$(D2F2G2H2I2J2K2L2M2N2O2P(B")
     (16 . "$B4\<tPVQ0Q1Q2Q3$(D2Q2R2S2T2U2V2W2X(B")
     (17 . "$B=~M%Q4$(D2Y2Z2[2\(B")
     (18 . "$BLY$(D2]2^2_(B")
     (19 . "$(D2`2a2b(B")
     (21 . "$BQ5Q6$(D2c2d(B")
     (22 . "$BQ7Q8s|(B"))
    ("R10"
     (2 . "$BQ9(B")
     (3 . "$BQ:(B")
     (4 . "$B0t85$(D2e(B")
     (5 . "$B7;(B")
     (6 . "$B6$8w=<@hC{$(D2f(B")
     (7 . "$B9n;yQ<$(D2g(B")
     (8 . "$BLHQ;Q=$(D2h2i2j(B")
     (9 . "$(D2k(B")
     (10 . "$BE^(B")
     (12 . "$(D2l(B")
     (14 . "$BQ>(B")
     (21 . "$(D2m(B"))
    ("R11"
     (2 . "$BF~(B")
     (3 . "$(D2n(B")
     (4 . "$BFb(B")
     (8 . "$BQ@(B")
     (9 . "$BQA(B"))
    ("R12"
     (2 . "$BH,(B")
     (4 . "$B8xO;QB(B")
     (6 . "$B6&(B")
     (7 . "$BJ<(B")
     (8 . "$B6qB6E5(B")
     (9 . "$B=6(B")
     (10 . "$B7s(B")
     (11 . "$BA>gN(B")
     (12 . "$BA=C'(B")
     (13 . "$B@yM2UZgO(B")
     (14 . "$(D2o(B")
     (16 . "$BQCZ*(B")
     (17 . "$BMA(B"))
    ("R13"
     (2 . "$BQD(B")
     (4 . "$B1_$(D2p2q(B")
     (5 . "$BQEQFQG$(D2r(B")
     (6 . "$Bf&$(D2s(B")
     (7 . "$BQH(B")
     (8 . "$Bf((B")
     (10 . "$BQJ(B")
     (11 . "$BQK(B"))
    ("R14"
     (2 . "$BQL(B")
     (4 . "$B>i$(D2t(B")
     (5 . "$B<L(B")
     (7 . "$Bf'$(D2u(B")
     (9 . "$B4'(B")
     (10 . "$BL=QMQNQO$(D2v2w(B")
     (14 . "$BQP(B")
     (16 . "$BQQ(B"))
    ("R15"
     (2 . "$BQR(B")
     (5 . "$BE_$(D2x(B")
     (6 . "$BQSQTQUQV(B")
     (7 . "$B:cLjNdQW$(D2y2z(B")
     (8 . "$BQX$(D2{2|2}(B")
     (9 . "$(D2~(B")
     (10 . "$B=Z@(C|E`N?QYQZ$(D3!(B")
     (11 . "$BIZ$(D3"3#(B")
     (12 . "$(D3$3%3&(B")
     (14 . "$(D3'(B")
     (15 . "$BQ[t%(B")
     (16 . "$B6E$(D3((B"))
    ("R16"
     (2 . "$BQ\(B")
     (3 . "$BK^$(D3)(B")
     (5 . "$BB|$(D3*(B")
     (6 . "$B=HFdQ^(B")
     (8 . "$BQ_$(D3+(B")
     (11 . "$BQ`(B")
     (12 . "$B3.$(D3,(B")
     (14 . "$BK1$(D3-3.(B"))
    ("R17"
     (2 . "$BQa(B")
     (4 . "$B6'(B")
     (5 . "$B1zFL$(D3/(B")
     (8 . "$BH!(B")
     (9 . "$BQb(B"))
    ("R18"
     (2 . "$BEa$(D3031(B")
     (3 . "$B?OQc(B")
     (4 . "$B4"@ZJ,$(D32(B")
     (5 . "$B4)Qd(B")
     (6 . "$B7:NsQeQf$(D3334353637(B")
     (7 . "$B=iH=JLMxQgQh$(D38(B")
     (8 . "$B7t9o:~;I@)E~QjQk$(D393:3;3<3=(B")
     (9 . "$B:oA0B'DfQlQmQnQo$(D3>3?(B")
     (10 . "$B5"7u9d:^GmK6QpQq$(D3@3A3B3C3D3E3F3G3H(B")
     (11 . "$B>jI{QrQ{$(D3I3J3K(B")
     (12 . "$B3dAOQsQtQu(B")
     (13 . "$BQvQw$(D3L(B")
     (14 . "$B3D$(D3M3N(B")
     (15 . "$B7`N-QxQ|$(D3O3P(B")
     (16 . "$BQyQzQ}$(D3Q3R(B")
     (17 . "$(D3S(B")
     (19 . "$(D3T(B")
     (21 . "$(D3U3V(B")
     (23 . "$(D3W(B"))
    ("R19"
     (2 . "$BNO(B")
     (3 . "$(D3X(B")
     (5 . "$B2C8y(B")
     (6 . "$BNt$(D3Y3Z3[3\(B")
     (7 . "$B9e=uEXNeO+R"R#$(D3]3^(B")
     (8 . "$B3/8zR$R%$(D3_3`3a3b3c3d(B")
     (9 . "$BD<KVM&R&$(D3e3f3g3h(B")
     (10 . "$BJYR'$(D3i3j3k(B")
     (11 . "$B4*F0L3R(pU$(D3l3m(B")
     (12 . "$B6P>!JgR)$(D3n3o(B")
     (13 . "$B4+@*R*R+R-$(D3p3q3r(B")
     (14 . "$(D3s3t3u(B")
     (15 . "$B7.$(D3v3w(B")
     (16 . "$BR.(B")
     (17 . "$BR/$(D3x3y(B")
     (19 . "$(D3z(B")
     (20 . "$BR0(B"))
    ("R20"
     (2 . "$BR1(B")
     (3 . "$B<[(B")
     (4 . "$B8{FwL^Lh$(D3{(B")
     (5 . "$BJqR2(B")
     (6 . "$BR3$(D3|(B")
     (8 . "$(D3}3~4!(B")
     (9 . "$BR5(B")
     (11 . "$BR6R7(B")
     (12 . "$(D4"(B")
     (13 . "$(D4#(B"))
    ("R21"
     (2 . "$BR8(B")
     (5 . "$BKL(B")
     (11 . "$B:"$(D4$(B")
     (13 . "$Bpr(B")
     (14 . "$B5?(B")
     (15 . "$Bpupv(B")
     (16 . "$Bpw(B"))
    ("R22"
     (2 . "$BR9(B")
     (5 . "$BAY$(D4%4&4'(B")
     (6 . "$B6)>"$(D4((B")
     (7 . "$BR:$(D4)(B")
     (9 . "$(D4*4+4,(B")
     (10 . "$BH[$(D4-(B")
     (11 . "$(D4.4/(B")
     (13 . "$BR;(B")
     (14 . "$(D40$BR<$(D41(B")
     (15 . "$BR=(B")
     (17 . "$(D42(B"))
    ("R23"
     (2 . "$BR>(B")
     (4 . "$B6hI$(B")
     (7 . "$B0e(B")
     (8 . "$(D43(B")
     (9 . "$(D44(B")
     (10 . "$BF?(B")
     (11 . "$BR?$(D45(B")
     )
    ("R24"
     (2 . "$B==(B")
     (3 . "$B@i$(D46(B")
     (4 . "$B8a>#F{R@(B")
     (5 . "$BH>RC$(D47(B")
     (6 . "$BRD$(D48(B")
     (8 . "$B6(B4Bn(B")
     (9 . "$BFnH\(B")
     (11 . "$(D49(B")
     (12 . "$BGnmc(B")
     (14 . "$B06(B")
     (21 . "$(D4:(B"))
    ("R25"
     (2 . "$BKN(B")
     (4 . "$BRF(B")
     (5 . "$B@j$(D4;(B")
     (7 . "$(D4<(B")
     (8 . "$B75$(D4=(B")
     (24 . "$Bb`(B"))
    ("R26"
     (2 . "$BRG(B")
     (4 . "$(D4>(B")
     (5 . "$B1,RHRI$(D4?(B")
     (6 . "$B0u4m(B")
     (7 . "$B5QB(Mq$(D4@(B")
     (8 . "$BRK$(D4A(B")
     (9 . "$B27RJ(B")
     (11 . "$(D4B(B")
     (12 . "$B6*(B"))
    ("R27"
     (2 . "$BRL(B")
     (4 . "$BLq$(D4C(B")
     (5 . "$(D4D4E(B")
     (7 . "$(D4F(B")
     (8 . "$(D4G4H(B")
     (9 . "$B8|NRRM$(D4I(B")
     (10 . "$B86$(D4J(B")
     (11 . "$BRN$(D4K(B")
     (12 . "$B4g?_RORP$(D4L(B")
     (13 . "$B19$(D4M4N4O(B")
     (14 . "$B1^RQRR(B")
     (15 . "$(D4P(B")
     (19 . "$B4f$(D4Q(B")
     (30 . "$(D4R(B"))
    ("R28"
     (2 . "$BRS(B")
     (4 . "$(D4S4T(B")
     (5 . "$B5n$(D4U(B")
     (6 . "$BL6$(D4V(B")
     (8 . "$B;2$(D4W(B")
     (11 . "$BRT(B")
     (12 . "$(D4X(B"))
    ("R29"
     (2 . "$BKt(B")
     (3 . "$B:5(B")
     (4 . "$BAPH?M'(B")
     (5 . "$B<}$(D4Y(B")
     (6 . "$(D4Z(B")
     (7 . "$(D4[(B")
     (8 . "$B<h<u=G$(D4\(B")
     (9 . "$B=vH@$(D4]4^(B")
     (10 . "$BRW$(D4_(B")
     (13 . "$(D4`(B")
     (16 . "$B1C(B")
     (18 . "$BAQ(B")
     (20 . "$Bb_(B"))
    ("R30"
     (3 . "$B8}(B")
     (5 . "$B1&2D3p6g8E9f;J;K<8>$BfB~C!RZR[R\R]$(D4a4b4c(B")
     (6 . "$B1%3F5H5I5[6+8~9!9gD_EGF1L>MyR^$(D4d4e(B")
     (7 . "$B4^6c7/8b8c9p?aDhF]H]J-JrKJO$R_R`RaRbRcRdReRfRgRh$(D4f4g4h4i4j4k4l4m4n4o4p4q4r4s(B")
     (8 . "$B8F:p<v<~L#L?RiRjRkRlRmRnRpRqRrRsRtRuRv$(D4t4u4v4w4x4y4z4{4|4}4~5!5"5#5$5%5&5'5(5)5*(B")
     (9 . "$B0%0v31:H:iC1IJRoRwRxRyRzR{R|R}R~S!S"S#S$S%S&S>$(D5+5,5-5.5/505152535455565758595:5;5<(B")
     (10 . "$B0"0w14:6>%?0BoE/EbKiS'S(S)S*S+S,S-S.S/$(D5=5>5?5@5A5B5C5D5E5F5G5H5I5J5K5L5M(B")
     (11 . "$B3e7<>&>'BCM#S0S1S2S3S4S5S6S7S8S9S:S;$(D5N5O5P5Q5R5S5T5U5V5W5X5Y5Z5[5\5]5^5_5`5a5b5c5d(B")
     (12 . "$B4-4n5J6,6t7v9"A1ASC}S<S=S?S@SASBSCSDSESFSGSHSISJ$(D5e5f5g5h5i5j5k5l5m5n5o5p5q5r5s5t(B")
     (13 . "$B2^;LC2SKSLSMSNSOSPSQ$(D5u5v5w5x5y5z5{5|5}5~6!6"6#6$6%6&6'6((B")
     (14 . "$B2EA9LDSRSSSTSUSVSWSX$(D6)6*6+6,6-6.6/60616263(B")
     (15 . "$B131=3z4o>|J.SYSZS\S]S^S_$(D6465666768696:6;6<6=6>6?6@6A6B6C6D6E6F6G(B")
     (16 . "$BFUH8S`SaSbScSd$(D6H6I6J6K6L6M6N6O6P6Q6R6S(B")
     (17 . "$B3E87SeSfSgSiSj$(D6T6U6V6W6X(B")
     (18 . "$BSh$(D6Y6Z6[6\6]6^(B")
     (19 . "$BSkSl$(D6_6`6a6b6c6d6e(B")
     (20 . "$BSmSn$(D6f6g6h(B")
     (21 . "$BSoSpSqSrSs$(D6i(B")
     (22 . "$B7%StSu$(D6j6k6l6m(B")
     (23 . "$(D6n6o6p(B")
     (24 . "$BSvSw$(D6q(B"))
    ("R31"
     (3 . "$BSx(B")
     (5 . "$B;M<|$(D6r6s(B")
     (6 . "$B0x2sCD$(D6t6u6v(B")
     (7 . "$B0O:$?^Sy$(D6w6x6y6z6{6|6}6~(B")
     (8 . "$B8G9qSz$(D7!7"(B")
     (9 . "$BS{S|(B")
     (10 . "$BJ`S}$(D7#7$(B")
     (11 . "$BS~T!T"$(D7%7&(B")
     (12 . "$B7wT#$(D7'(B")
     (13 . "$B1`T$T'$(D7(7)(B")
     (14 . "$BT%T&(B")
     (15 . "$(D7*(B")
     (16 . "$BT($(D7+(B")
     (22 . "$(D7,(B"))
    ("R32"
     (3 . "$BEZ(B")
     (4 . "$(D7-(B")
     (5 . "$B05T)$(D7.7/7071(B")
     (6 . "$B7=:_COT*T+$(D7273747576777879(B")
     (7 . "$B6Q9#:A:dK7T,T-T.T/$(D7:7;7<7=7>7?7@(B")
     (8 . "$B6F:%?bC3DZT0T3T4T5$(D7A7B7C7D7E7F7G7H7I7J7K7L7M7N7O7P7Q7R7S7T7U(B")
     (9 . "$B3@7?9$>kT2T6T7T8T9T:T;$(D7V7W7X7Y7Z7[7\7]7^7_7`7a7b7c7d(B")
     (10 . "$BKdT1T<T=T>T?T@TB$(D7e7f7g7h7i7j7k(B")
     (11 . "$B0h4p:k<9>}BOD[F2G8G]IVKYTATCTD$(D7l7m7n7o7p7q7r7s7t7u7v7w7x7y7z7{7|7}7~8!8"(B")
     (12 . "$B1a4.7x:f>lBDDMDiEHEcJ=JsN]TETFTHTNTft!$(D8#8$8%8&8'8(8)8*8+8,(B")
     (13 . "$B1v2t:IA:E6EIEdH9JhTITJTKTM$(D8-8.8/8081828384858687(B")
     (14 . "$B6-=N?PA}KOTGTOTP$(D88898:8;8<8=8>8?8@8A8B8C8D8E8F(B")
     (15 . "$BDFJ/TQTRTSTWTX$(D8G8H8I8J8K8L8M8N(B")
     (16 . "$B2u:&>mCEJITTTY$(D8O8P8Q8R(B")
     (17 . "$B9hTVTZT[T\$(D8S8T8U8V8W8X(B")
     (18 . "$BT]T^fK(B")
     (19 . "$BTUT`Tb$(D8Y8Z8[8\(B")
     (20 . "$BT_Ta(B")
     (22 . "$BjF(B")
     (24 . "$(D8](B"))
    ("R33"
     (3 . "$B;N(B")
     (7 . "$B0m@<GdTc(B")
     (8 . "$(D8^(B")
     (12 . "$BTdTe(B")
     (13 . "$BTg(B")
     (14 . "$BTh(B"))
    ("R34"
     (3 . "$BTi(B")
     (5 . "$B=h(B")
     (6 . "$(D8_(B")
     (7 . "$(D8`(B")
     (9 . "$B7)JQ(B"))
    ("R35"
     (3 . "$BTj(B")
     (7 . "$(D8a(B")
     (8 . "$(D8b(B")
     (10 . "$B2F(B")
     (14 . "$BTk(B")
     (16 . "$(D8c(B")
     (18 . "$(D8d(B")
     (21 . "$(D8e(B")
     (23 . "$(D8f(B"))
    ("R36"
     (3 . "$BM<(B")
     (5 . "$B30(B")
     (6 . "$BB?Tl(B")
     (8 . "$BLk$(D8g(B")
     (11 . "$BTm(B")
     (12 . "$(D8h(B")
     (13 . "$BL4$(D8i(B")
     (14 . "$BTn$(D8j(B"))
    ("R37"
     (3 . "$BBg$(D8k(B")
     (4 . "$BB@E7IWToTp(B")
     (5 . "$B1{<:Tq$(D8l8m8n(B")
     (6 . "$BTr$(D8o8p(B")
     (7 . "$BTs$(D8q(B")
     (8 . "$B1b4qF`JtK[$(D8r8s(B")
     (9 . "$B7@AUTvTw$(D8t8u(B")
     (10 . "$BEeTxTya=(B")
     (11 . "$(D8v8w8x8y8z(B")
     (12 . "$B1|TzT{$(D8{8|(B")
     (13 . "$B>)T|(B")
     (14 . "$BC%T}T~$(D8}(B")
     (15 . "$(D8~(B")
     (16 . "$BJ3$(D9!(B")
     (24 . "$(D9"(B"))
    ("R38"
     (3 . "$B=w(B")
     (5 . "$BE[$(D9#9$(B")
     (6 . "$B9%G!H^LQU!U"$(D9%9&9'(B")
     (7 . "$B58BEG%K8L/MEU#U$U&U+$(D9(9)9*9+9,9-9.9/90(B")
     (8 . "$B090Q8H:J;O;P@+EJKeU%U'U($(D9192939495969798999:9;9<9=9>9?(B")
     (9 . "$B0#0(0R0y184/;QLEU)U*U,U-$(D9@9A9B9C9D9E9F9G9H9I9J9K9L9M(B")
     (10 . "$B8d?1I1L<U.U/U0U1U2U3$(D9N9O9P9Q9R9S9T9U9V9W9X9Y9Z9[(B")
     (11 . "$B:'>+GLIXJZO,U4U5U6U7U8U9U:$(D9\9]9^9_9`9a9b9c9d9e9f(B")
     (12 . "$BG^I2L;U;$(D9g9h9i9j9k9l9m9n9o9p9q9r9s9t9u9v(B")
     (13 . "$B2G7y<;U<U=U>U?U@UL$(D9w9x9y9z9{9|9}9~:!:":#:$(B")
     (14 . "$BCdUAUBUCUDUE$(D:%:&:':(:):*(B")
     (15 . "$B4rUFUGUHUI$(D:+:,:-:.:/:0(B")
     (16 . "$B>nUJ$(D:1:2:3:4:5:6(B")
     (17 . "$B1ED\UKUMUN$(D:7:8(B")
     (18 . "$(D:9(B")
     (19 . "$BUO(B")
     (20 . "$BUPUQUR$(D::(B")
     (22 . "$(D:;:<(B"))
    ("R39"
     (3 . "$B;RUS$(D:=(B")
     (4 . "$B9&(B")
     (5 . "$BUT(B")
     (6 . "$B;zB8$(D:>(B")
     (7 . "$B9';ZUUUV$(D:?(B")
     (8 . "$B3X5(LRUW(B")
     (9 . "$B8IUX$(D:@(B")
     (10 . "$BB9(B")
     (11 . "$BUY$(D:A:B(B")
     (12 . "$BV#(B")
     (14 . "$BU[(B")
     (16 . "$BU\(B")
     (17 . "$BU^(B")
     (19 . "$(D:C(B")
     (20 . "$(D:D:E(B")
     (22 . "$(D:F(B"))
    ("R40"
     (3 . "$BU_(B")
     (5 . "$BU`$(D:G:H(B")
     (6 . "$B0B1'<iBp$(D:I(B")
     (7 . "$B409(<5AWO4$(D:J:K:L:M(B")
     (8 . "$B084159<B=!ChDjEfJu$(D:N:O:P(B")
     (9 . "$B5R<<@kM($(D:Q:R(B")
     (10 . "$B1c2H325\:K>,MFUaUb$(D:S:T:U:V:W:X:Y:Z(B")
     (11 . "$B4s<d=IFRL)UcUd$(D:[:\(B")
     (12 . "$B4(6wIYUfUg$(D:]:^(B")
     (13 . "$B42?2$(D:_:`:a:b:c(B")
     (14 . "$B2I;!G+L*UhUiUjUkUl\M$(D:d(B")
     (15 . "$B?3N@Um(B")
     (16 . "$BUn$(D:e(B")
     (17 . "$Bm!$(D:f(B")
     (19 . "$BC~Up$(D:g(B")
     (20 . "$BUo(B"))
    ("R41"
     (3 . "$B@#(B")
     (6 . "$B;{(B")
     (7 . "$B<wBP$(D:h(B")
     (9 . "$B@lIu(B")
     (10 . "$B<M>-Uq(B")
     (11 . "$B0SUrUs(B")
     (12 . "$B?RB:$(D:i(B")
     (14 . "$BUt(B")
     (15 . "$BF3(B")
     (17 . "$BlP(B"))
    ("R42"
     (3 . "$B>.(B")
     (4 . "$B>/(B")
     (5 . "$BUu(B")
     (6 . "$B@mEv$(D:j(B")
     (8 . "$B>0(B")
     (12 . "$B1D$(D:k(B")
     (13 . "$BUva3aD$(D:l(B")
     (14 . "$B>((B")
     (20 . "$BMT(B"))
    ("R43"
     (3 . "$BUw$(D:m(B")
     (4 . "$BL`(B")
     (6 . "$(D:n(B")
     (7 . "$BUx$(D:o:p:q(B")
     (9 . "$(D:r(B")
     (12 . "$B="$(D:s(B")
     (13 . "$(D:t(B")
     (15 . "$(D:u(B")
     (17 . "$(D:v(B"))
    ("R44"
     (3 . "$BUy(B")
     (4 . "$B<\Uz(B")
     (5 . "$B?,Ft(B")
     (6 . "$B?T(B")
     (7 . "$B6IG"HxU{(B")
     (8 . "$B5o6~FOU|(B")
     (9 . "$B20;SU}V"(B")
     (10 . "$B6}E8U~V!(B")
     (11 . "$(D:w:x:y(B")
     (12 . "$B:T<HB0EK(B")
     (14 . "$BAX$(D:z:{(B")
     (15 . "$BMz$(D:|(B")
     (17 . "$(D:}(B")
     (18 . "$(D:~(B")
     (21 . "$BV$(B")
     (24 . "$(D;!(B"))
    ("R45"
     (3 . "$BV%(B")
     (4 . "$BFV(B")
     (6 . "$(D;"(B"))
    ("R46"
     (3 . "$B;3(B")
     (4 . "$BV&(B")
     (5 . "$BV'$(D;#;$(B")
     (6 . "$BV($(D;%;&;';((B")
     (7 . "$B4tV)V*V+V,$(D;);*;+;,;-(B")
     (8 . "$B2,3Y4_4dA;BRL(V-V.V/V0V1V2V3$(D;.;/;0;1;2;3;4;5;6;7;8(B")
     (9 . "$B6.F=V4V5$(D;9;:;;;<;=(B")
     (10 . "$B2e=TEgJvJwV6V7V8V9V;$(D;>;?;@;A;B(B")
     (11 . "$B33:j?rJxV<V=V>V@VAVBVCVDVEVFVG$(D;C;D;E;F;G;H;I;J(B")
     (12 . "$BMrV?VHVIVJVK$(D;K;L;M;N;O;P;Q;R;S;T;U;V(B")
     (13 . "$B:7?sVLVMVN$(D;W;X;Y;Z(B")
     (14 . "$BEhV:VOVPVQ$(D;[;\;];^;_;`;a;b;c;d;e;f;g(B")
     (15 . "$BVRVSVW$(D;h;i;j;k;l;m;n;o(B")
     (16 . "$BVTVU$(D;p;q;r;s(B")
     (17 . "$BNfVVVXVY$(D;t;u(B")
     (19 . "$(D;v(B")
     (20 . "$B4`VZ$(D;w;x;y;z(B")
     (21 . "$BV[(B")
     (22 . "$BV\V]$(D;|(B")
     (23 . "$BV^$(D;{(B"))
    ("R47"
     (3 . "$B@nV_(B")
     (6 . "$B=d(B")
     (7 . "$(D;}(B")
     (11 . "$BAc(B")
     (12 . "$B=g(B")
     (15 . "$(D;~(B"))
    ("R48"
     (3 . "$B9)(B")
     (5 . "$B5p9*:8(B")
     (6 . "$(D<!(B")
     (7 . "$B96(B")
     (10 . "$B:9(B"))
    ("R49"
     (3 . "$B8JL&Va(B")
     (4 . "$BGC(B")
     (7 . "$B2~Vb(B")
     (9 . "$B4,9+$(D<"<#(B"))
    ("R50"
     (3 . "$B6R(B")
     (4 . "$(D<$(B")
     (5 . "$B;TI[(B")
     (6 . "$BHA$(D<%(B")
     (7 . "$B4uVc$(D<&(B")
     (8 . "$BD!VdVeVfVg$(D<'<(<)<*(B")
     (9 . "$B?cDk$(D<+(B")
     (10 . "$B;U@JBS$(D<,<-<.(B")
     (11 . "$B>oD"VhVi$(D</<0(B")
     (12 . "$BI}K9VjVkVlVs$(D<1(B")
     (13 . "$BKZKkVm$(D<2<3<4(B")
     (14 . "$BVnVo$(D<5<6<7<8<9(B")
     (15 . "$BH(J>VpVqVr$(D<:(B")
     (16 . "$(D<;(B")
     (17 . "$(D<<<=<>(B")
     (18 . "$(D<?<@(B")
     (19 . "$(D<A(B"))
    ("R51"
     (3 . "$B43(B")
     (5 . "$BJ?MD(B")
     (6 . "$BG/VtVu(B")
     (8 . "$B9,(B")
     (13 . "$B44(B"))
    ("R52"
     (3 . "$BVv(B")
     (4 . "$B88(B")
     (9 . "$BM)(B")
     (12 . "$B4v(B")
     (15 . "$B5&(B"))
    ("R53"
     (3 . "$BVx(B")
     (5 . "$B9-D#$(D<B(B")
     (6 . "$B>1(B")
     (7 . "$B=x>2H_$(D<C<D(B")
     (8 . "$B9.DlE9I\Jy(B")
     (9 . "$BEYVy$(D<E<F<G(B")
     (10 . "$B8K:BDm$(D<H<I<J(B")
     (11 . "$B0C9/=nKcMG$(D<K<L(B")
     (12 . "$BGQO-VzV{$(D<M<N<O(B")
     (13 . "$BNwV|$(D<P<Q<R(B")
     (14 . "$B3GV}V~W!$(D<S<T<U<V<W(B")
     (15 . "$B>3I@W"W#W$W%W&W']`$(D<X<Y(B")
     (16 . "$BW(W)$(D<Z(B")
     (18 . "$BK{$(D<[(B")
     (19 . "$BW*(B")
     (20 . "$BW-(B")
     (21 . "$BW+sM(B")
     (25 . "$BW,(B"))
    ("R54"
     (3 . "$BW.(B")
     (7 . "$BDn(B")
     (8 . "$B1dW/(B")
     (9 . "$B2v7zG6(B"))
    ("R55"
     (3 . "$BW0(B")
     (5 . "$BJ[(B")
     (6 . "$(D<\(B")
     (7 . "$BW1(B")
     (8 . "$(D<](B")
     (9 . "$(D<^<_(B")
     (10 . "$BW2(B")
     (15 . "$BJ@(B"))
    ("R56"
     (3 . "$BW5(B")
     (4 . "$BP!(B")
     (5 . "$BP1(B")
     (6 . "$B<0$(D<`(B")
     (12 . "$BW6(B")
     (14 . "$BFP(B"))
    ("R57"
     (3 . "$B5](B")
     (4 . "$B0zD$W7(B")
     (5 . "$B90(B")
     (6 . "$BCP$(D<a<b(B")
     (7 . "$BDo$(D<c<d(B")
     (8 . "$B89LoW8$(D<e<f<g<h(B")
     (9 . "$B8LW9W?$(D<i<j<k(B")
     (10 . "$B<e$(D<l<m(B")
     (11 . "$B6/D%W:$(D<n(B")
     (12 . "$B4!CFI+$(D<o<p<q(B")
     (13 . "$BW;$(D<r(B")
     (14 . "$(D<s<t(B")
     (15 . "$BW<$(D<u(B")
     (16 . "$B60(B")
     (17 . "$BW=(B")
     (18 . "$(D<v(B")
     (22 . "$BW>(B"))
    ("R58"
     (3 . "$BW@$(D<w(B")
     (8 . "$(D<x(B")
     (9 . "$BWA(B")
     (11 . "$BWB(B")
     (12 . "$(D<y(B")
     (13 . "$BWC(B")
     (16 . "$BW4$(D<z(B")
     (18 . "$BW3(B")
     (26 . "$(D<{(B"))
    ("R59"
     (3 . "$BWD(B")
     (7 . "$B7A$(D<|<}(B")
     (9 . "$BI'(B")
     (10 . "$(D<~(B")
     (11 . "$B:LD&I7(B")
     (12 . "$B?\WE(B")
     (14 . "$B>4$(D=!(B")
     (15 . "$B1F(B")
     (22 . "$(D="(B"))
    ("R60"
     (3 . "$BWF(B")
     (6 . "$(D=#=$(B")
     (7 . "$BLrWG$(D=%=&(B")
     (8 . "$B1}7B@,H`WHWIWJ$(D='=((B")
     (9 . "$B8eBTN'WKWLWN$(D=)=*(B")
     (10 . "$B=>=yELWM$(D=+(B")
     (11 . "$BF@WOWPWQWR$(D=,=-=.=/(B")
     (12 . "$B8f=[I|WS$(D=0=1=2(B")
     (13 . "$BHyWT$(D=3=4=5(B")
     (14 . "$BD'FA$(D=6(B")
     (15 . "$BE0$(D=7(B")
     (16 . "$BWU(B")
     (17 . "$B5+(B"))
    ("R61"
     (3 . "$(D=8(B")
     (4 . "$B?4(B")
     (5 . "$(D=9=;(B")
     (6 . "$BK;WV$(D=:=<=@=A(B")
     (7 . "$B1~2w4w;VG&K:WWWXWYWZX-$(D===>=?=C=E=G=I=J=K=L=M=N=O=P=Q(B")
     (8 . "$B2x619z@-CiG0I]NgW[W]W^W`WaWbWeWfWgWhWiWj$(D=B=D=F=H=R=S=T=U=V=X=Y=[=\=](B")
     (9 . "$B1e2y2z3f5^91:(;WBUE\W_WcWdWmWoWpWqWrWtWuWvWwWx$(D=W=Z=^=_=`=a=b=c=d=f=g=h=j(B")
     (10 . "$B1Y2862637C8g=zB)CQDpG:NxWkWlWnWsWyWzW{W}W~X!X"X#X$X%X&X'$(D=e=i=k=m=o=q=r=s=t=v=w=x(B")
     (11 . "$B0-0T459{;4>p@KEiFWM*W|X)X+X,X.X/X0X1$(D=l=n=p=u=y=z={=|=}=~>!>">#>%>'>(>*>+>,>->.>/(B")
     (12 . "$B92<fAZBFHaL{OGW\X(X*X3X5X7X8X9X:X;X<X=X?$(D>$>&>)>0>1>2>3>4>5>6>7>9>:>;><>=>>>?>@>A>D>E>F(B")
     (13 . "$B0&0U34466r;|=%?5A[X2X4X6X>XAXCXDXFXHXIXK$(D>8>B>C>G>H>I>J>K>L>M>N>P>Q>R(B")
     (14 . "$B47A~BVJiK}X@XBXEXGXJXLXMXNXPXRXSXTXUXVXXXY$(D>O>S>T>U>V>X>[>\>^(B")
     (15 . "$B0V7D7EF4J0M+M]N8XOXQXWX\X]X^X_XbXc$(D>W>Y>Z>]>`>a>b>d>e>g>k>l(B")
     (16 . "$B212{487F7{NyXZX[X`XaXdXeXhXjXkXn$(D>_>c>f>h>i>j>m>n>p>q>r>s>t(B")
     (17 . "$B:)XfXiXlXo$(D>o>v>w>x>z>{>|>}(B")
     (18 . "$BD(XpXs$(D>u>y>~?"(B")
     (19 . "$BXgXq$(D?!?#(B")
     (20 . "$B7|Xr(B")
     (21 . "$BXuXvXw(B")
     (22 . "$BXt(B")
     (23 . "$BXx$(D?$?%?&(B")
     (24 . "$(D?'(B"))
    ("R62"
     (4 . "$BXy(B")
     (5 . "$BJjXz(B")
     (6 . "$B=?@.X{X|(B")
     (7 . "$B2f2|$(D?((B")
     (8 . "$B0?X}$(D?)(B")
     (11 . "$B@LlC$(D?*(B")
     (12 . "$B7aY!(B")
     (13 . "$B@oY"$(D?+?,?-(B")
     (14 . "$BY#$(D?.?/?0(B")
     (15 . "$B5:Y$(B")
     (16 . "$BY%(B")
     (17 . "$BY&(B")
     (18 . "$BBWY'(B"))
    ("R63"
     (4 . "$B8M(B")
     (5 . "$(D?1(B")
     (7 . "$BLa(B")
     (8 . "$B=jK<$(D?2(B")
     (9 . "$BY($(D?3?4(B")
     (10 . "$B@p$(D?5?6(B")
     (11 . "$Bn=(B")
     (12 . "$BHb(B"))
    ("R64"
     (3 . "$B:M$(D?7(B")
     (4 . "$B<jY)(B")
     (5 . "$BBGJ'$(D?8?9?:?;?<(B")
     (6 . "$B07BqY*Y+Y,Y-Y.$(D?=?>??(B")
     (7 . "$B5;93>6@^BrEjGDH4HcI^J1M^Y/Y0Y1Y2Y3Y4Y5Y7Y8$(D?@?A?B?C?D?E?F?G?H(B")
     (8 . "$B2!2}3H5q5r94>7@[BsC4CjDqGRGoHdJzKuY6Y9Y:Y;Y>Y@YBYCYDYEYFYGZ-$(D?I?J?K?L?M?N?O?P?Q?R?S?T?U(B")
     (9 . "$B0D3g649i;";X;}=&?!D)Y<YAYHYIYJYKYLYNYO$(D?V?X?Y?Z?[?\?]?^?_?a?b?c(B")
     (10 . "$B0'5s7};+?6A\A^B*D=DrHTJaYMYPYQYRYT$(D?W?`?d?e?f?g?h?i?j?k?l?m?n?o?p?q?r?s?t?u?v?w(B")
     (11 . "$B1f3]5E7!7G7~95:C:N<N<x>9?d?x@\A<A]A_C5FhG1GSIAJ{N+YUYVYWYXYYY[Y\Y]Y^Y_Y`$(D?x?y?z?{?|?}?~@!@"@#@$@%@&@'@(@)@+@,@-@.@/@0@1@2@3@4(B")
     (12 . "$B0.1g494x>8B7DsEkM,MHMIYZYaYbYcYdYeYfYgYhYi$(D@*@5@7@8@9@:@;@<@=@>@?@@@A@B@C@D@E@F@G(B")
     (13 . "$B7H:E:q@]B;HBYSYjYlYmYnYoYqYrYs$(D@6@H@I@J@K@L@M@N@O@P@Q@R@S@T@U@V@W@X@Y(B")
     (14 . "$B@"DOE&LNYkYtYvYw$(D@Z@[@\@]@^@_@`@a@b@c@d@e@f@g@h@i@j@k(B")
     (15 . "$B3I7b;#;5@qE1F5G2GEIoKPK`YuYyYzY{Y|Y}$(D@l@m@n@o@p@q@r@s@t@u@v@w@x@y@z@{(B")
     (16 . "$BA`MJY?Y~Z!Z"Z#Z$Z%Z'$(D@|@}@~A!A"A$A%A'A(A)A*(B")
     (17 . "$B5<;$E'Z&Z(Z)Z+Z,Z.Z/$(DA#A&A+A-A/A0(B")
     (18 . "$B>qZ1Z2Z3Z4Z6Z9$(DA,A.A1A2A3A4A5A6A7A8A9(B")
     (19 . "$BZ5$(DA:(B")
     (20 . "$BZ7$(DA;A<A=A>(B")
     (21 . "$BYpZ8$(DA?(B")
     (22 . "$BZ:$(DA@AAABAC(B")
     (23 . "$BYxZ;Z<$(DAD(B")
     (24 . "$BZ0(B")
     (25 . "$(DAE(B"))
    ("R65"
     (4 . "$B;Y(B")
     (9 . "$(DAF(B"))
    ("R66"
     (4 . "$BZ=Z>(B")
     (6 . "$BZ?Z@(B")
     (7 . "$BZA$(DAGAH(B")
     (8 . "$BJ|$(DAI(B")
     (9 . "$B8N@/$(DAJ(B")
     (10 . "$BIRZC$(DAKALAM(B")
     (11 . "$B5_65GTZDZEZFZG$(DANAO(B")
     (12 . "$B4:7I;6FXZHZI$(DAPAQAR(B")
     (13 . "$B?t$(DAS(B")
     (14 . "$BZJ(B")
     (15 . "$BE(I_ZK$(DAT(B")
     (16 . "$B@0$(DAU(B")
     (17 . "$BZL]B$(DAV(B")
     (18 . "$BZM(B")
     (20 . "$(DAW(B")
     (23 . "$BZN(B"))
    ("R67"
     (4 . "$BJ8(B")
     (7 . "$BU](B")
     (10 . "$(DAX(B")
     (12 . "$BHCHeIL(B")
     (13 . "$(DAY(B")
     (16 . "$(DAZ(B"))
    ("R68"
     (4 . "$BEM(B")
     (7 . "$(DA[(B")
     (10 . "$BNA(B")
     (11 . "$B<PZO(B")
     (12 . "$(DA\(B")
     (13 . "$BZP(B")
     (14 . "$(DA](B")
     (17 . "$(DA^(B"))
    ("R69"
     (4 . "$B6T(B")
     (5 . "$B@M(B")
     (8 . "$(DA_(B")
     (9 . "$BZQ(B")
     (11 . "$B;BCG(B")
     (12 . "$B;[$(DA`(B")
     (13 . "$B?7(B")
     (16 . "$(DAaAb(B")
     (17 . "$(DAc(B")
     (18 . "$BZR(B"))
    ("R70"
     (4 . "$BJ}(B")
     (8 . "$B1w(B")
     (9 . "$B;\$(DAd(B")
     (10 . "$BN9ZSZTZUZV$(DAe(B")
     (11 . "$B@{B2ZW$(DAfAgAh(B")
     (12 . "$(DAi(B")
     (13 . "$BZX(B")
     (14 . "$B4z$(DAjAk(B")
     (16 . "$BZZ(B")
     (17 . "$(DAl(B")
     (18 . "$BZY(B")
     (20 . "$(DAm(B"))
    ("R71"
     (4 . "$BZ[(B")
     (5 . "$BZ\(B")
     (10 . "$B4{(B"))
    ("R72"
     (4 . "$BF|(B")
     (5 . "$BC6(B")
     (6 . "$B00;]=\Aa(B")
     (7 . "$BZ]$(DAnAoApAq(B")
     (8 . "$B0W2"97:*:+>:>;@NL@Z_Z`$(DArAsAtAuAvAwAxAyAzA{A|A}(B")
     (9 . "$B1G:r=U><@'@1CkKfZcZdZeZf[&$(DA~B!B"B#B$B%B&B'B(B)B*B+B,B-B.B/B0(B")
     (10 . "$B3"98;/;~?8ZgZhZiZj$(DB1B2B3B4B5B6B7(B")
     (11 . "$B:|ZkZlZmZnZoZpZq$(DB8B9B:B;B<B=B>B?(B")
     (12 . "$B6G7J=k>=@2CRHUIaZrZs$(DB@BABBBCBDBEBFBGBHBIBJBKBL(B")
     (13 . "$B0E2KCHZtZuZvZwZx$(DBMBNBOBPBQBR(B")
     (14 . "$BD*JkNqZy$(DBSBTBUBVBWBX(B")
     (15 . "$B;CK=$(DBYBZB[B\B]B^B_B`Ba(B")
     (16 . "$BF^ZzZ{Z|Z}Z~[!["$(DBbBc(B")
     (17 . "$B[#$(DBdBeBf(B")
     (18 . "$B=lMK[$$(DBgBh(B")
     (19 . "$BGx[%(B")
     (20 . "$B['$(DBi(B")
     (21 . "$B[((B")
     (23 . "$(DBjBk(B")
     (24 . "$(DBl(B"))
    ("R73"
     (4 . "$B[)(B")
     (6 . "$B6J(B")
     (7 . "$B99[*(B")
     (9 . "$B[+(B")
     (10 . "$B=q$(DBm(B")
     (11 . "$BAbRX(B")
     (12 . "$B:GBX(B")
     (13 . "$BPr(B")
     (14 . "$(DBn(B")
     (20 . "$(DBo(B"))
    ("R74"
     (4 . "$B7n(B")
     (6 . "$BM-(B")
     (8 . "$BI~J~(B")
     (9 . "$B[,$(DBp(B")
     (10 . "$BD?O/$(DBq(B")
     (11 . "$BK>[-(B")
     (12 . "$B4|D+[.$(DBrBs(B")
     (13 . "$(DBt(B")
     (14 . "$(DBu(B")
     (18 . "$B[/(B")
     (20 . "$B[0(B")
     (21 . "$B[1(B"))
    ("R75"
     (4 . "$BLZ(B")
     (5 . "$B;%K\KvL$[2(B")
     (6 . "$B4y5`<kKQ[3[4[5[6[7$(DBvBw(B")
     (7 . "$B0I:`<]>r>s?yB+B<ENL]M{[8[9[:[;[<[=$(DBxByBzB{B|B}B~C!(B")
     (8 . "$B5O9:;^>>?u@OElGGGUHDHzKgKmNSOHOPZ^Zb[>[?[@[A[B[C[D[E[F[G$(DC"C#C$C%C&C'C(C)C*C+C,C-C.C/C0(B")
     (9 . "$B1I2M3A4;8O:::t=@@wBHClDNDSFJGpI"JAK?KoLxM.[H[I[J[K[L[M[N[O[P[Q[R[S[T[U[V[W$(DC1C2C3C4C5C6C7C8C9C:C;C<C=C>C?C@CACBCCCDCECFCGCH(B")
     (10 . "$B0F3J3K3t3|4<5K6M7*7,7K7e9;:,:O:y;7<F@4@r@sEmG_I0Kq[Y[Z[[[][^[_[a[b[c$(DCICJCKCLCMCNCOCPCQCRCSCTCUCVCWCXCYCZC[C\C]C^C_(B")
     (11 . "$B04233#3a3q5t8h9<:->?DtEnHuIKM|NB[\[`[d[e[f[g[h[i[j[k[l[n[o[p[q[r[t[u$(DC`CaCbCcCdCeCfCgChCiCjCkClCmCnCoCpCqCrCsCtCuCvCwCxCyCz(B")
     (12 . "$B0X4=4}8!?"?9?z@3C*DGEoK@L:LI[s[v[w[x[y[z[{[|[}[~\!\"\#\%\&\'\(\)\*\+\,\-\.\/\0\1\2$(DC{C|C}C~D!D"D#D$D%D&D'D(D)D*D+D,D-D.D/D0D1D2D3D4D5D6D7D8D9D:D;D<(B")
     (13 . "$B3Z4~6H6K:g=]BJDHDXFNFjFoG`IvMLO0O1\$\3\4\5\6\7\8\9\:\;\<\=\>\?\@\A\B\C\D$(DD=D>D?D@DADBDCDDDEDFDGDHDIDJDKDLDMDNDODPDQDRDSDTDU(B")
     (14 . "$B1]353r9=?:AdKjLOMM\E\F\G\H\I\J\K\L\N\O\P\Q\R\S\T\U\V\W\X\Y\ct"$(DDVDWDXDYDZD[D\D]D^D_D`DaDbDcDdDeDfDgDhDi(B")
     (15 . "$B2#3_8">@AeCtDPI8\Z\[\\\]\_\`\a\b\d\e\f\g\h\i\k\l\n\s\x$(DDjDkDlDmDnDoDpDqDrDsDtDuDvDwDxDyDzD{D|D}(B")
     (16 . "$B5!5L66<y>AC.FK\m\o\p\q\r\t\u\v\w$(DD~E!E"E#E$E%E&E'E(E)E*E+E,E-E.E/E0E1E2E3E4E5(B")
     (17 . "$B3`8iCI[X\y\z\{\|\}\~]!],$(DE6E7E8E9E:E;E<E=E>E?E@EAEBEC(B")
     (18 . "$B6{[m\j]#]$]%]&]']($(DEDEEEFEGEHEIEJEKELEM(B")
     (19 . "$BO&])]*]+]-$(DENEOEPEQERESETEU(B")
     (20 . "$BH'Ms].$(DEVEWEXEYEZ(B")
     (21 . "$B]/]0]2$(DE[E\E]E^(B")
     (22 . "$B\^$(DE_E`Ea(B")
     (23 . "$B]3$(DEbEcEd(B")
     (25 . "$B]4$(DEeEf(B")
     (26 . "$B15(B")
     (28 . "$(DEg(B")
     (29 . "$B]6(B"))
    ("R76"
     (4 . "$B7g(B")
     (6 . "$B<!(B")
     (7 . "$(DEh(B")
     (8 . "$B2$6U(B")
     (9 . "$(DEi(B")
     (10 . "$(DEjEkElEm(B")
     (11 . "$BM_]7]8$(DEn(B")
     (12 . "$B4>5=6V]:$(DEoEp(B")
     (13 . "$B]<]=$(DEq(B")
     (14 . "$B2N]>$(DErEs(B")
     (15 . "$B4?C7]?$(DEt(B")
     (16 . "$B]@]A$(DEuEv(B")
     (17 . "$(DEw(B")
     (18 . "$B]C(B")
     (19 . "$(DEx(B")
     (22 . "$B]D(B"))
    ("R77"
     (4 . "$B;_(B")
     (5 . "$B@5(B")
     (6 . "$B:!(B")
     (8 . "$BIpJb$(DEyEz(B")
     (12 . "$(DE{(B")
     (13 . "$B:P(B")
     (14 . "$BNr$(DE|(B")
     (15 . "$(DE}(B")
     (18 . "$B]E(B"))
    ("R78"
     (4 . "$B]F(B")
     (6 . "$B;`(B")
     (8 . "$B]G]H$(DE~F!(B")
     (9 . "$BKX]I]J$(DF"F#(B")
     (10 . "$B;D<l=^(B")
     (11 . "$B]K(B")
     (12 . "$B?#]L]M$(DF$F%(B")
     (13 . "$(DF&(B")
     (14 . "$B]N$(DF'(B")
     (15 . "$B]O$(DF(F)(B")
     (16 . "$B]P]Q$(DF*(B")
     (17 . "$(DF+F,F-F.(B")
     (18 . "$B]R(B")
     (19 . "$B]T$(DF/(B")
     (21 . "$B]S(B"))
    ("R79"
     (4 . "$B]U(B")
     (8 . "$B2%(B")
     (9 . "$BCJ(B")
     (10 . "$B;&]V(B")
     (11 . "$B3L$(DF0F1(B")
     (12 . "$B]W$(DF2(B")
     (13 . "$BEBTL$(DF3(B")
     (14 . "$(DF4F5(B")
     (15 . "$B5#]X(B")
     (17 . "$BmX(B")
     (18 . "$(DF6(B"))
    ("R80"
     (4 . "$B]Y$(DF7(B")
     (5 . "$BJl(B")
     (6 . "$BKh(B")
     (8 . "$BFG(B")
     (11 . "$Bj^(B")
     (14 . "$B]Z(B"))
    ("R81"
     (4 . "$BHf(B")
     (9 . "$(DF8(B")
     (12 . "$BH|(B")
     (17 . "$(DF9(B"))
    ("R82"
     (4 . "$BLS(B")
     (8 . "$B][(B")
     (9 . "$(DF:(B")
     (10 . "$(DF;F<F=(B")
     (11 . "$B]\]]$(DF>(B")
     (12 . "$B]^]_$(DF?(B")
     (13 . "$(DF@FA(B")
     (15 . "$(DFBFC(B")
     (16 . "$(DFDFE(B")
     (17 . "$B]a$(DFF(B")
     (22 . "$(DFG(B")
     (26 . "$(DFH(B"))
    ("R83"
     (4 . "$B;a(B")
     (5 . "$BL1$(DFI(B")
     (6 . "$(DFJ(B")
     (8 . "$B]b(B"))
    ("R84"
     (4 . "$B]c(B")
     (6 . "$B5$(B")
     (7 . "$(DFK(B")
     (8 . "$B]d(B")
     (9 . "$(DFL(B")
     (10 . "$B]e]f$(DFMFNFO(B")
     (12 . "$(DFPFQ(B")
     (13 . "$(DFR(B"))
    ("R85"
     (3 . "$(DFS(B")
     (4 . "$B?e$(DFTFU(B")
     (5 . "$B=ADuHE$(DFVFW(B")
     (6 . "$B1x4@9><.CSFrHF]h]i$(DFXFYFZF[F\F]F^F_F`(B")
     (7 . "$B2-5%5a5b7h:;BABtD@FYKWM`]g]j]k]l]m]n]o]p]q]r]s]t^"$(DFaFbFcFdFeFfFgFhFiFjFkFlFmFnFoFpFqFr(B")
     (8 . "$B1K1h2O5c677#<#>BCmE%GHGqHgJ(K!K"KwL}]u]v]w]x]y]z]{]|]}]~^!^#^$^%$(DFsFtFuFvFwFxFyFzF{F|F}F~G!G"G#G$G%G&G'G(G)G*(B")
     (9 . "$B1L3$3h9?='>t@t@u@vDEF6GIMNMl^&^(^)^*^+^,^-^.^/^0$(DG+G,G-G.G/G0G1G2G3G4G5G6G7G9G:G;G<(B")
     (10 . "$B1:3=9@<r>C?;BYEsFBIMIbM0MaN.N^O2^1^2^3^4^5^6^7^8^:$(DG8G=G>G?G@GAGBGCGDGEGFGGGHGIGJGKGLGM(B")
     (11 . "$B0|1U363i7L:.:Q=B=J=_=m>D?<@6C8E:EqMdNCNT^;^<^=^>^?^@^A^B^C^D^E^F^G^H^I^J^K^L^M^N$(DGNGOGPGQGRGSGTGUGVGWGXGYGZG[G\G]G^G_G`GaGbGcGdGeGgGh(B")
     (12 . "$B0/12298:8P9A<"<>>EB,C9EOErJ%K~L+M/OQRE^O^P^Q^R^S^T^U^V^W^X^Y^Z^[^\^]^^^_^a^b^c$(DGfGiGjGkGlGmGnGoGpGqGrGsGtGuGvGwGxGyGzG{G|G}G~H!H"H#H$H%H&H'(B")
     (13 . "$B0n3j4A8;9B=`BZBlE.GyLGMON/Nz^d^e^f^g^h^i^j^k^l^m^o^p^q^r$(DH(H)H*H+H,H-H.H/H0H1H2H3H4H5H6H7H8H:(B")
     (14 . "$B1i4C5y9w<?A2AfDRE)I:L!O3^`^t^v^w^x^z^{^|^}^~_!_"_#$(DH9H;H<H=H>H?H@HAHBHCHDHEHFHGHHHIHKHLHMHNHOHPHQHR(B")
     (15 . "$B3c4B7i=a@!@xD,DYH.^n^s^y_$_%_&_'_(_)_*_,_-_._/_0_1_3_L$(DHJHSHTHUHVHWHXHYHZH[H\H]H^H_H`HaHbHdHeHfHgHhHiHjHkHlHm(B")
     (16 . "$B7cByECG;_2_4_5_6_7_8_9_:$(DHcHnHoHpHqHrHsHtHuHvHwHxHyHzH{H|H}H~I!I"I#I$I%(B")
     (17 . "$B9c9jBuG(^9_;_<_=_>_?_@_A_Boi$(DI&I'(B")
     (18 . "$BCuMt_C_D_E_F_G_H_I$(DI(I)I*I+I,I-I.I0I1(B")
     (19 . "$B@%BmFTIN_+_J_K_M_N$(DI/(B")
     (20 . "$B_O_P_Q_R$(DI2I3I4I5I6(B")
     (21 . "$B^u$(DI7I8I9I:I;I<(B")
     (22 . "$BFg_S$(DI=I>(B")
     (24 . "$(DI?I@(B")
     (25 . "$B_T(B")
     (26 . "$(DIAIC(B")
     (27 . "$(DIB(B"))
    ("R86"
     (4 . "$B2P$(DID(B")
     (6 . "$B3%Et$(DIE(B")
     (7 . "$B5d:R<^$(DIFIGIH(B")
     (8 . "$B1j?fO'_U_V$(DIIIJIKILIMINIOIPIQ(B")
     (9 . "$BC:E@_W_Y_Z_[_\$(DIRISITIUIVIW(B")
     (10 . "$BNu_]_^___`$(DIXIYIZI[I\I]I^I_I`(B")
     (11 . "$B1k_X_b$(DIaIbIcIdIeIfIgIhIi(B")
     (12 . "$B<Q>F>GA3J2L5_c_d$(DIjIkIlImInIoIpIq(B")
     (13 . "$B1l>HGaHQN{_e_f_h_i_j_k_l$(DIrIsItIuIvIwIxIyIzI{I|I}I~J!(B")
     (14 . "$B7'@zMP_g_m_o_pt&$(DJ"J#J$J%J&J'(B")
     (15 . "$B1m=OG._q_r$(DJ(J)J*J+J,J-J.J/(B")
     (16 . "$BEuG3_s_t_u_v_w_x_y$(DJ0J1J2J3J4J5J6J7J8J9J:J;(B")
     (17 . "$B;8?$AgNURYS[_z_{_|_}(B")
     (18 . "$B_n_~`!`"$(DJ<J=J>(B")
     (19 . "$BGz`#$(DJ?J@JA(B")
     (20 . "$B`$$(DJBJC(B")
     (21 . "$B`%$(DJD(B")
     (22 . "$(DJEJF(B")
     (25 . "$(DJG(B")
     (29 . "$B`&(B"))
    ("R87"
     (4 . "$BD^$(DJH(B")
     (6 . "$BAh(B")
     (8 . "$B:S`'`((B")
     (9 . "$B0Y`)$(DJI(B")
     (12 . "$B`*(B")
     (13 . "$B=X(B")
     (14 . "$(DJJ(B")
     (17 . "$B<_(B"))
    ("R88"
     (4 . "$BIc(B")
     (8 . "$BI`$(DJK(B")
     (10 . "$(DJL(B")
     (12 . "$BLl(B"))
    ("R89"
     (4 . "$B`+(B")
     (9 . "$B`,(B")
     (14 . "$B<$(B"))
    ("R90"
     (4 . "$B`-(B")
     (6 . "$BAT(B")
     (7 . "$B>u(B")
     (8 . "$B`.(B")
     (9 . "$(DJM(B")
     (10 . "$(DJN(B")
     (13 . "$(DJO(B")
     (15 . "$(DJP(B")
     (17 . "$B`/(B"))
    ("R91"
     (4 . "$BJR(B")
     (8 . "$BHG(B")
     (12 . "$BGW`0(B")
     (13 . "$BD-$(DJQJRJS(B")
     (14 . "$(DJT(B")
     (15 . "$(DJUJV(B")
     (19 . "$B`1(B"))
    ("R92"
     (4 . "$B2g(B")
     (8 . "$B<Y(B")
     (12 . "$(DJW(B"))
    ("R93"
     (4 . "$B5m$(DJX(B")
     (6 . "$BLF$(DJY(B")
     (7 . "$B24$(DJZ(B")
     (8 . "$BJ*KR$(DJ[J\J](B")
     (9 . "$B@7`2$(DJ^J_J`(B")
     (10 . "$BFC$(DJaJb(B")
     (11 . "$B`3`5$(DJcJdJe(B")
     (12 . "$B`4`6$(DJfJg(B")
     (13 . "$(DJhJi(B")
     (14 . "$B`7`8$(DJj(B")
     (15 . "$(DJk(B")
     (17 . "$B5>(B")
     (19 . "$B`9(B")
     (20 . "$B`:$(DJl(B"))
    ("R94"
     (3 . "$(DJm(B")
     (4 . "$B8$(B")
     (5 . "$BHH$(DJn(B")
     (6 . "$B`<$(DJoJp(B")
     (7 . "$B68`;`=`>`?$(DJqJrJs(B")
     (8 . "$B6i8Q9}A@`@`A$(DJtJuJvJwJx(B")
     (9 . "$B69<mFH`B`C`D$(DJyJz(B")
     (10 . "$BC,GbO5`E`F$(DJ{J|J}J~K!K"(B")
     (11 . "$BCvG-LTND`G`H`I`J`K`L$(DK#K$K%K'K)K*K+K,(B")
     (12 . "$BM1`M`N`O`P$(DK&K(K-K.K/K0K1K2K3K4(B")
     (13 . "$B1n8%;b`Q$(DK5K6K7(B")
     (14 . "$B9v`S$(DK8K9K:K<(B")
     (15 . "$B`R`U$(DK;K>K?K@KA(B")
     (16 . "$B3M=C`V`W$(DK=KBKCKDKEKF(B")
     (17 . "$B`X$(DKGKHKI(B")
     (18 . "$B`Z$(DKJ(B")
     (19 . "$B`Y`\$(DKK(B")
     (20 . "$B`[$(DKL(B")
     (22 . "$(DKM(B")
     (23 . "$(DKNKO(B"))
    ("R95"
     (5 . "$B8<(B")
     (9 . "$(DKP(B")
     (10 . "$(DKQ(B")
     (11 . "$BN((B"))
    ("R96"
     (4 . "$B2&?Q(B")
     (5 . "$B6L(B")
     (6 . "$(DKRKS(B")
     (7 . "$B6jO.$(DKTKUKVKW(B")
     (8 . "$B4a$(DKXKYKZK[K\K]K^K_K`Ka(B")
     (9 . "$B2Q;9DANh`]`^`_```a$(DKbKcKdKeKfKgKhKiKjKkKlKm(B")
     (10 . "$B7><nHI`b`c`d`~$(DKnKoKpKqKrKsKtKuKvKw(B")
     (11 . "$B5e8=BvM}N0`f`i$(DKxKyKzK{K|K}K~L!L"L#L$L%L&L'(B")
     (12 . "$B1M6WGJNV`h`j`k$(DL(L)L*L+L,L-L.L/L0L1L2L3L4L5L6(B")
     (13 . "$B8j?p`l`m`n`o`p`q`v$(DL7L8L9L:L;L<L=L>L?L@LA(B")
     (14 . "$B:<M~N\`g`s`t`ut$$(DLBLCLDLELFLGLHLILJ(B")
     (15 . "$B`r`w`x$(DLKLLLMLNLOLPLQLR(B")
     (16 . "$B`e`y$(DLSLTLULVLWLXLYLZL[L\(B")
     (17 . "$B4D$(DL]L^L_L`LaLbLcLdLeLf(B")
     (18 . "$B`z$(DLgLhLi(B")
     (19 . "$B<%`{$(DLjLk(B")
     (20 . "$B`|$(DLlLm(B")
     (21 . "$B`}$(DLn(B")
     (22 . "$(DLo(B")
     (23 . "$(DLp(B")
     (24 . "$(DLq(B"))
    ("R97"
     (5 . "$B1;(B")
     (10 . "$(DLrLs(B")
     (11 . "$Ba!(B")
     (16 . "$BI;(B")
     (19 . "$Ba"(B")
     (22 . "$(DLt(B"))
    ("R98"
     (5 . "$B4$(B")
     (7 . "$Ba#(B")
     (8 . "$Ba$$(DLu(B")
     (9 . "$Ba%a&a'a($(DLvLwLx(B")
     (10 . "$(DLy(B")
     (11 . "$BISa)a*(B")
     (12 . "$(DLzL{L|(B")
     (13 . "$(DL}(B")
     (14 . "$Ba+a,a-(B")
     (15 . "$Ba0$(DL~(B")
     (16 . "$B9ya.a/(B")
     (17 . "$(DM!(B")
     (18 . "$Ba1a2(B")
     (19 . "$(DM"(B")
     (25 . "$(DM#(B"))
    ("R99"
     (5 . "$B4E(B")
     (9 . "$B?S(B"))
    ("R100"
     (5 . "$B@8(B")
     (9 . "$(DM$(B")
     (10 . "$(DM%(B")
     (11 . "$B;:(B")
     (12 . "$B1ya4$(DM&(B")
     (14 . "$(DM'(B"))
    ("R101"
     (5 . "$BMQ$(DM((B")
     (6 . "$(DM)(B")
     (7 . "$BJca5(B")
     (12 . "$(DM*(B"))
    ("R102"
     (5 . "$B9C?=EDM3(B")
     (6 . "$(DM+(B")
     (7 . "$BCKD.R4a6$(DM,(B")
     (8 . "$B2ha7$(DM-M.M/M0M1(B")
     (9 . "$B0Z3&H*H{ZBa8a9a:a<$(DM2M3M4M5M6(B")
     (10 . "$B@&C\H+HJN1a;$(DM7M8M9(B")
     (11 . "$B0[7MI-N,a>a?a@$(DM:(B")
     (12 . "$B>vHVaAaBaG$(DM;M<(B")
     (13 . "$BFmaC$(DM=M>(B")
     (14 . "$(DM?M@MA(B")
     (15 . "$(DMB(B")
     (16 . "$B<2aJ(B")
     (18 . "$(DMCMD(B")
     (19 . "$BaEaF(B")
     (22 . "$BaHaI(B"))
    ("R103"
     (5 . "$BI%(B")
     (11 . "$BCA(B")
     (12 . "$BAAAB(B")
     (13 . "$BA?(B")
     (15 . "$(DME(B"))
    ("R104"
     (5 . "$(DMF(B")
     (7 . "$BaK$(DMGMH(B")
     (8 . "$BaLaM$(DMIMJ(B")
     (9 . "$B1VaNaO$(DMKML(B")
     (10 . "$B<@>I?>HhIBaPaQaRaTaUaVaW$(DMMMNMOMPMQMRMS(B")
     (11 . "$B:/<&aSaXaYaZ$(DMTMUMV(B")
     (12 . "$BDKEwN!a[a\a]$(DMWMXMYMZM[M\M](B")
     (13 . "$BCTa^a_a`aaabacadae$(DM^M_M`MaMbMcMdMeMf(B")
     (14 . "$Bafagah$(DMgMhMiMjMkMlMmMnMo(B")
     (15 . "$BAiaiajakalaman$(DMpMqMrMsMtMuMvMwMx(B")
     (16 . "$Baoapaq$(DMyMzM{M|M}M~N!N"N#(B")
     (17 . "$B4bNEarasat$(DN$N%N&N'N(N)N*(B")
     (18 . "$BJJL~auav$(DN+N,(B")
     (19 . "$Baw$(DN-(B")
     (20 . "$Bax$(DN.N/(B")
     (21 . "$Bayaza{a|(B")
     (22 . "$Ba}$(DN0N1(B")
     (23 . "$Ba~$(DN2(B")
     (24 . "$Bb!$(DN3(B")
     (30 . "$(DN4(B"))
    ("R105"
     (5 . "$Bb"(B")
     (9 . "$BH/b#(B")
     (12 . "$BEPb$(B"))
    ("R106"
     (5 . "$BGr(B")
     (6 . "$BI4(B")
     (7 . "$Bb%b&$(DN5(B")
     (8 . "$BE*(B")
     (9 . "$B3'9Db'$(DN6(B")
     (10 . "$Bb($(DN7N8(B")
     (11 . "$B;)b)(B")
     (12 . "$Bb*b+$(DN9(B")
     (13 . "$Bb,(B")
     (15 . "$Bb-$(DN:N;N<(B")
     (16 . "$(DN=N>(B")
     (17 . "$(DN?N@NANB(B")
     (18 . "$(DNCNDNE(B")
     (20 . "$(DNF(B")
     (23 . "$(DNG(B"))
    ("R107"
     (5 . "$BHi(B")
     (10 . "$Bb.(B")
     (12 . "$Bb/(B")
     (14 . "$B?|b0b1(B")
     (15 . "$Bb2(B")
     (18 . "$(DNH(B"))
    ("R108"
     (5 . "$B;.(B")
     (7 . "$(DNI(B")
     (9 . "$B1NGVK_$(DNJ(B")
     (10 . "$B1Wb4$(DNKNLNMNN(B")
     (11 . "$B@9Epb5$(DNO(B")
     (12 . "$B]9$(DNP(B")
     (13 . "$BLAb7$(DNQ(B")
     (14 . "$Bb8(B")
     (15 . "$B4FHW(B")
     (16 . "$Bb9b:$(DNR(B")
     (17 . "$Bb;$(DNS(B")
     (18 . "$(DNT(B"))
    ("R109"
     (5 . "$BL\(B")
     (8 . "$BD>LUZa$(DNUNV(B")
     (9 . "$B4G8)=b>JAjKAb=b>b?b@$(DNWNXNYNZN[N\(B")
     (10 . "$B??L2bAbBbCbF$(DN]N^N_N`NaNbNcNdNeNf(B")
     (11 . "$B4cD/bDbEbGbH$(DNgNhNiNjNkNlNmNnNo(B")
     (12 . "$BbI$(DNpNqNrNsNtNuNv(B")
     (13 . "$B?gFDKSbJbKbLbMbN$(DNwNxNyNzN{N|N}N~O!O"O#O$(B")
     (14 . "$BbObPbQ$(DO%O&O'O(O)O*O+O,(B")
     (15 . "$BbRbSbT$(DO-(B")
     (16 . "$BbUbV$(DO.O/O0O1O2O3O4(B")
     (17 . "$BF7JMNFbWbXbY$(DO5O6O7O8O9O:(B")
     (18 . "$B=VbZb[b\b]$(DO;(B")
     (19 . "$Bb^$(DO<O=O>(B")
     (21 . "$(DO?(B")
     (24 . "$(DO@(B")
     (25 . "$(DOA(B")
     (26 . "$Bba(B"))
    ("R110"
     (5 . "$BL7(B")
     (9 . "$Bbb(B")
     (12 . "$(DOBOC(B")
     (13 . "$(DOD(B"))
    ("R111"
     (5 . "$BLp(B")
     (7 . "$Bbc(B")
     (8 . "$BCN$(DOE(B")
     (9 . "$BGj$(DOF(B")
     (10 . "$B6k(B")
     (11 . "$(DOG(B")
     (12 . "$BC;$(DOH(B")
     (13 . "$Bbd(B")
     (17 . "$B6:$(DOI(B")
     (19 . "$(DOJ(B"))
    ("R112"
     (5 . "$B@P(B")
     (7 . "$(DOK(B")
     (8 . "$Bbe$(DOLOM(B")
     (9 . "$B8&:=:Ubfbg$(DONOOOPOQOROS(B")
     (10 . "$B5N9\EVEWGKK$bi$(DOTOUOVOWOXOYOZO[O\(B")
     (11 . "$B:Vbk$(DO]O^O_O`OaObOc(B")
     (12 . "$B8'9E>KH#N2bm$(DOdOeOfOgOhOiOjOkOl(B")
     (13 . "$B10378k:lDvORblbnbobpbq$(DOmOnOoOpOqOrOs(B")
     (14 . "$B<'@YHjJKbrbsbtbu$(DOtOuOvOwOxOyOzO{O|O}O~(B")
     (15 . "$B3NHXbvbwbxbzb{b|b}$(DP!P"P#P$P%P&P'P(P)P*P+P,P-(B")
     (16 . "$BKabyb~c!c"$(DP.P/P0P1P2P3(B")
     (17 . "$B0k>Lc#c$$(DP4P5P6P7P8P9P:P;(B")
     (18 . "$BACc%c&c'$(DP<P=P>(B")
     (19 . "$Bc($(DP?P@PAPBPCPD(B")
     (20 . "$Bbhbjc)c*$(DPEPF(B")
     (21 . "$(DPGPH(B")
     (22 . "$(DPIPJ(B"))
    ("R113"
     (4 . "$(DPK(B")
     (5 . "$B<(Ni(B")
     (6 . "$(DPL(B")
     (7 . "$B77<R$(DPM(B")
     (8 . "$B5'5@;cc+$(DPNPOPPPQPR(B")
     (9 . "$B=K?@ADG*M4c1$(DPSPTPUPVPWPX(B")
     (10 . "$B>Mc,c-c.c/c0$(DPYPZP[(B")
     (11 . "$B:WI<$(DP\P]P^(B")
     (12 . "$BExO=$(DP_P`(B")
     (13 . "$B2R6XA5DwJ!c2c3cI$(DPaPbPcPdPePfPgPh(B")
     (14 . "$Bc4$(DPiPk(B")
     (15 . "$Bc5$(DPj(B")
     (16 . "$B5z$(DPlPmPn(B")
     (17 . "$Bc6c8$(DPo(B")
     (18 . "$BG)c9$(DPp(B")
     (21 . "$(DPq(B")
     (22 . "$Bc:(B"))
    ("R114"
     (5 . "$(DPr(B")
     (9 . "$Bc;c<(B")
     (11 . "$(DPs(B"))
    ("R115"
     (5 . "$B2S(B")
     (7 . "$B;d=(FE$(DPt(B")
     (8 . "$BOBc=$(DPuPvPwPx(B")
     (9 . "$B2J=)ICc>$(DPyPzP{(B")
     (10 . "$B>N?AAECaGiHkc?c@cAcB$(DP|P}P~Q!Q"Q#Q$Q%Q&(B")
     (11 . "$B0\$(DQ'Q(Q)(B")
     (12 . "$B5)@GDxcCcD$(DQ*Q+Q,Q-Q.Q/(B")
     (13 . "$BCUI#L-NGcEcFcG$(DQ0Q1Q2Q3Q4(B")
     (14 . "$B0p9r<ocJ$(DQ5Q6Q7Q8Q9(B")
     (15 . "$B2T9FJfcKcLcMcN$(DQ:Q;Q<Q=Q>Q?(B")
     (16 . "$B0,1O2:7N@Q$(DQ@QAQBQC(B")
     (17 . "$BKTcOcP$(DQDQEQFQGQHQI(B")
     (18 . "$B3O>wcQcR$(DQJQKQLQM(B")
     (19 . "$BcS(B")
     (20 . "$(DQN(B")
     (21 . "$BcT(B")
     (22 . "$BcU(B"))
    ("R116"
     (5 . "$B7j(B")
     (6 . "$(DQO(B")
     (7 . "$B5f(B")
     (8 . "$B6uFMcV$(DQP(B")
     (9 . "$B@`@|cW$(DQQQRQS(B")
     (10 . "$B:ucX$(DQTQUQVQWQX(B")
     (11 . "$BAkCbcZ$(DQYQZ(B")
     (12 . "$BcYc[c\$(DQ[(B")
     (13 . "$B7"$(DQ\Q](B")
     (14 . "$B7&c]$(DQ^(B")
     (15 . "$B5gMRc_cc$(DQ_Q`(B")
     (16 . "$B1.c`$(DQaQbQc(B")
     (17 . "$B3v(B")
     (18 . "$Bcacb(B")
     (19 . "$(DQd(B")
     (20 . "$Bce(B")
     (21 . "$Bc^$(DQe(B")
     (22 . "$Bcf(B"))
    ("R117"
     (5 . "$BN)(B")
     (7 . "$Bcg$(DQf(B")
     (8 . "$B>*ch$(DQg(B")
     (9 . "$BTtcicj$(DQh(B")
     (10 . "$Bckclcm$(DQi(B")
     (11 . "$B>Ocn(B")
     (12 . "$B=WF8cocp(B")
     (13 . "$(DQjQkQl(B")
     (14 . "$BC(C<cqcr$(DQm(B")
     (16 . "$BpP$(DQn(B")
     (17 . "$(DQo(B")
     (20 . "$B6%(B")
     (22 . "$BQ?(B"))
    ("R118"
     (6 . "$BC](B")
     (8 . "$B<3$(DQp(B")
     (9 . "$B4Hcs$(DQqQr(B")
     (10 . "$B5h>Pctcucvd$$(DQsQt(B")
     (11 . "$B3^:{?ZBhE+Idcwcxcyczc{c|c}$(DQuQvQwQxQyQzQ{Q|Q}Q~R!R"R#(B")
     (12 . "$B6Z:vC^EyEzE{H&H5I.c~d"d#d%d&d8$(DR$R%R&R'R(R)(B")
     (13 . "$B@ad!d'd(d)d*d+d,d-d.$(DR*R+R,R-R.R/R0R1R2R3(B")
     (14 . "$B2U4I;;GsJOL'd/d0d1d2d3d4d5d6d7d9d=$(DR4R5R6R7R8R9R:R;(B")
     (15 . "$B@}H"H$HOJSd:d;d<d>d?$(DR<R=R>R?R@RARBRCRDRERFRGRHRIRJRK(B")
     (16 . "$B<DC[FFO6d@dAdBdDdE$(DRLRMRNRORPRQRRRS(B")
     (17 . "$BRUdCdGdHdIdJdKdLdMdN$(DRTRURVRWRXRYRZR[R\R]R^R_R`RaRbRcRdReRf(B")
     (18 . "$B4JC=dOdPdQdR$(DRgRhRiRjRkRlRm(B")
     (19 . "$BHvJmN|dSdTdUdZ$(DRnRoRpRqRr(B")
     (20 . "$B;<@RdVdY$(DRsRtRu(B")
     (21 . "$BdWdXd[d_$(DRvRwRx(B")
     (22 . "$BdFd\d]$(DRyRzR{R|R}R~S!(B")
     (23 . "$Bd^d`$(DS"S#(B")
     (25 . "$Bda$(DS$S%S&(B")
     (26 . "$(DS'(B")
     (32 . "$(DS((B"))
    ("R119"
     (6 . "$BJF(B")
     (8 . "$Bdb(B")
     (9 . "$B6NLb$(DS)S*S+(B")
     (10 . "$B?hJ4L0dcdd$(DS,S-S.S/(B")
     (11 . "$BAFG4GtN3(B")
     (12 . "$B>Qdedfdgdhdidj$(DS0S1(B")
     (13 . "$Bdkdldmdn$(DS2S3(B")
     (14 . "$B@:dodpdq$(DS4S5S6S7S8S9(B")
     (15 . "$B8RA8drds$(DS:S;S<S=S>(B")
     (16 . "$BE|dtdu$(DS?S@SASBSC(B")
     (17 . "$B9GAlJ5dvdw$(DSDSESFSG(B")
     (18 . "$BNH(B")
     (19 . "$(DSHSI(B")
     (20 . "$Bdy(B")
     (21 . "$Bdz(B")
     (22 . "$Bd{(B")
     (23 . "$(DSJ(B"))
    ("R120"
     (6 . "$B;e(B")
     (7 . "$B7Od}(B")
     (9 . "$B5*5i5j9HLsd~e!$(DSKSLSMSN(B")
     (10 . "$B9I:w;f<S=cAGG<I3J6KBLfe"e#e$$(DSOSPSQSRSSSTSUSVSW(B")
     (11 . "$B7P8>:0:Y=*>R?BAHD]N_e%e&e'e(e)e*e+$(DSXSYSZS[S\S]S^S_S`Sa(B")
     (12 . "$B0<3(5k7k9J;g@dE}Mme,e-e.e/e0e1e2e3$(DSbScSdSeSfSgShSiSjSkSlSm(B")
     (13 . "$B7Q8(B3e4e5e6e7e8e9$(DSnSoSpSqSrSsStSuSvSwSxSySzS{S|S}(B")
     (14 . "$B0=0]9K<z=oAmAnC>DVHlLJLVNPN}e:e;e<e=e>e?e@eBeCeEeFeGen$(DS~T!T"T#T$T%T&T'T(T)T*T+T,T-T.T/T0(B")
     (15 . "$B1o4K6[@~DyFlJTLKeDeHeIeJeKeLeMeNeO$(DT1T2T3T4T5T6T7T8T9T:T;T<T=T>(B")
     (16 . "$B0^<J=DG{HKK%ePeQeReSeUeVeWeX$(DT?T@TATBTCTDTETF(B")
     (17 . "$B=+=L@SA!eAeTeYeZe[e\e]e^e_e`ea$(DTGTHTITJTKTLTMTNTOTPTQ(B")
     (18 . "$B?%A6Kzebecedeeefeg$(DTRTSTTTUTVTWTXTY(B")
     (19 . "$B7+7Reheiej$(DTZT[T\T]T^(B")
     (20 . "$Bekelemeoepeq$(DT`(B")
     (21 . "$BE;eresetevez$(DT_TaTbTcTd(B")
     (22 . "$Beue|$(DTe(B")
     (23 . "$Bewey$(DTf(B")
     (24 . "$Bex(B")
     (25 . "$Be{$(DTgTh(B")
     (27 . "$(DTi(B")
     (29 . "$(DTj(B"))
    ("R121"
     (6 . "$B4L(B")
     (9 . "$Be}(B")
     (10 . "$Be~$(DTkTl(B")
     (11 . "$(DTm(B")
     (12 . "$(DTnTo(B")
     (16 . "$(DTp(B")
     (17 . "$Bf!$(DTq(B")
     (18 . "$(DTr(B")
     (20 . "$Bf"(B")
     (21 . "$Bf#(B")
     (22 . "$Bf$$(DTs(B")
     (24 . "$Bf%(B"))
    ("R122"
     (5 . "$(DTtTu(B")
     (9 . "$Bf)(B")
     (10 . "$Bf*f+$(DTvTwTxTy(B")
     (11 . "$(DTz(B")
     (12 . "$(DT{T|T}(B")
     (13 . "$B7S:a=pCVf,f-f.if$(DT~(B")
     (14 . "$BH3$(DU!(B")
     (15 . "$BHmf/(B")
     (16 . "$BGMXm(B")
     (17 . "$(DU"U$(B")
     (18 . "$Bf0$(DU#(B")
     (19 . "$BMef1f2$(DU%(B")
     (22 . "$Bf4(B")
     (24 . "$Bf3(B"))
    ("R123"
     (6 . "$BMS(B")
     (8 . "$Bf5(B")
     (9 . "$BH~$(DU&U'U(U)U*(B")
     (10 . "$Bf6$(DU+U,(B")
     (11 . "$Bf7f8f9$(DU-(B")
     (12 . "$BCe$(DU.U/(B")
     (13 . "$B5A72A"f:$(DU0U1(B")
     (15 . "$Bf;f>$(DU2(B")
     (16 . "$Bf<(B")
     (18 . "$(DU3(B")
     (19 . "$Bf=f?f@(B")
     (20 . "$BfA(B")
     (21 . "$(DU4(B"))
    ("R124"
     (6 . "$B1)(B")
     (9 . "$(DU5(B")
     (10 . "$B2'fBfC$(DU6U7(B")
     (11 . "$B=,MbfD$(DU8U9U:(B")
     (12 . "$BfF(B")
     (13 . "$(DU;(B")
     (14 . "$B?i$(DU<U=(B")
     (15 . "$B4efH$(DU>U?U@(B")
     (16 . "$B4M$(DUAUB(B")
     (17 . "$BMcfJ$(DUC(B")
     (18 . "$BK]$(DUD(B")
     (19 . "$(DUEUF(B")
     (20 . "$(DUG(B")
     (25 . "$Bd|(B"))
    ("R125"
     (6 . "$B9MO7(B")
     (8 . "$B<T(B")
     (9 . "$(DUH(B")
     (10 . "$BfMfN$(DUJ(B")
     (11 . "$(DUI(B")
     (12 . "$BfO(B"))
    ("R126"
     (6 . "$B<)(B")
     (9 . "$BBQ$(DUKULUMUN(B"))
    ("R127"
     (6 . "$BfP(B")
     (8 . "$(DUO(B")
     (9 . "$(DUPUQ(B")
     (10 . "$B9LLWfQfR(B")
     (11 . "$BfS$(DURUSUT(B")
     (12 . "$(DUU(B")
     (13 . "$BfT(B")
     (14 . "$(DUV(B")
     (15 . "$(DUW(B")
     (16 . "$BfU(B")
     (17 . "$(DUX(B")
     (18 . "$(DUY(B")
     (21 . "$(DUZ(B"))
    ("R128"
     (6 . "$B<*(B")
     (7 . "$(DU[(B")
     (8 . "$(DU\(B")
     (9 . "$BLm$(DU](B")
     (10 . "$BC?fVfW$(DU^U_U`UaUb(B")
     (11 . "$BfXfY$(DUc(B")
     (12 . "$BfZ$(DUd(B")
     (13 . "$B@;f[(B")
     (14 . "$BAof\f]f^(B")
     (15 . "$Bf_$(DUeUf(B")
     (16 . "$(DUg(B")
     (17 . "$BD0N~f`fafb$(DUh(B")
     (18 . "$B?&fc$(DUi(B")
     (20 . "$Bfd(B")
     (22 . "$Bfe(B"))
    ("R129"
     (6 . "$Bff(B")
     (10 . "$(DUj(B")
     (11 . "$B=M(B")
     (13 . "$Bfgfi(B")
     (14 . "$BH%$(DUk(B"))
    ("R130"
     (6 . "$BFyH)O>$(DUl(B")
     (7 . "$B4N>SI*fjfkfl$(DUmUn(B")
     (8 . "$B0i8*8T9N9O:h;hHnKCfmfnfo$(DUoUpUqUrUs(B")
     (9 . "$B0_8UB[C@GXGYK&QIfpfqfrfsftfufvfw$(DUtUuUvUwUyUzU{U|(B")
     (10 . "$B6;6<:s;i@H@TF9G=L.OFfxfyg&$(DU}U~V!V"V#V$V%V&V(V)(B")
     (11 . "$B5SC&G>fzf|f}$(DUxV*V+V,V-V.V/V0V1V2V3V4(B")
     (12 . "$B9PD1OSf~g"g#g$g%$(DV'V5V6V7V8V9V:V;V<(B")
     (13 . "$B9x<p?UA#B\D2J"g'g(g)g*g+g5$(DV=V>V?V@VAVBVCVD(B")
     (14 . "$B9QIeKlg,g-g.g/g0$(DVEVGVHVIVJVK(B")
     (15 . "$BI(Ifg1g2g3g4g6$(DVLVMVNVOVP(B")
     (16 . "$BA7KDg7g8g9$(DVFVQVRVS(B")
     (17 . "$B22G?g:g;g<g=g>g?g@gE$(DVTVVVWVX(B")
     (18 . "$BgAgB$(DVYVZ(B")
     (19 . "$BB!K2gD$(DVUV[V\(B")
     (20 . "$BgCgF$(DV](B")
     (21 . "$(DV^(B")
     (22 . "$(DV_(B")
     (23 . "$BgG(B")
     (25 . "$BgH$(DV`(B"))
    ("R131"
     (7 . "$B?C(B")
     (9 . "$B2i$(DVa(B")
     (15 . "$BgI(B")
     (18 . "$BNW(B"))
    ("R132"
     (6 . "$B<+(B")
     (7 . "$(DVb(B")
     (9 . "$B=-(B")
     (10 . "$(DVc(B")
     (12 . "$(DVd(B")
     (15 . "$(DVe(B")
     (16 . "$(DVf(B"))
    ("R133"
     (6 . "$B;j(B")
     (10 . "$BCW(B")
     (12 . "$(DVgVhVi(B")
     (13 . "$(DVj(B")
     (14 . "$BgJ(B")
     (16 . "$BgK(B"))
    ("R134"
     (6 . "$B11(B")
     (8 . "$(DVk(B")
     (9 . "$BgLgM$(DVl(B")
     (10 . "$(DVm(B")
     (12 . "$(DVn(B")
     (13 . "$BgP(B")
     (16 . "$B6=(B")
     (18 . "$BgQ(B"))
    ("R135"
     (6 . "$B@e(B")
     (8 . "$BQigR$(DVo(B")
     (10 . "$BgS(B")
     (11 . "$BE<(B")
     (12 . "$BP0(B")
     (14 . "$(DVpVq(B")
     (15 . "$BgT(B")
     (18 . "$(DVr(B")
     (19 . "$(DVs(B"))
    ("R136"
     (7 . "$BA$(B")
     (13 . "$(DVt(B")
     (15 . "$BIq(B"))
    ("R137"
     (6 . "$B=.(B")
     (9 . "$(DVuVv(B")
     (10 . "$B9RHLgUgVgd$(DVw(B")
     (11 . "$B8?A%BIGugWgX$(DVxVyVz(B")
     (13 . "$BDzgY$(DV{V|V}V~(B")
     (14 . "$(DW!(B")
     (15 . "$(DW"W#W$(B")
     (16 . "$BgZg[$(DW%W&(B")
     (17 . "$Bg\g](B")
     (18 . "$Bg^$(DW'(B")
     (19 . "$Bg_g`$(DW((B")
     (20 . "$Bga$(DW)(B")
     (21 . "$B4Ogb(B")
     (22 . "$Bgc(B")
     (24 . "$(DW*(B"))
    ("R138"
     (6 . "$B:1(B")
     (7 . "$BNI(B")
     (17 . "$Bge(B"))
    ("R139"
     (6 . "$B?'(B")
     (11 . "$(DW+(B")
     (19 . "$B1p(B")
     (24 . "$Bgf(B"))
    ("R140"
     (5 . "$Bgh$(DW,W-W.W/W0(B")
     (6 . "$B0r<Ggggigj$(DW1W2W3W4W5W6W7W8W9(B")
     (7 . "$B022V3)4#6\7]?DGNIgK'gkglgn$(DW:W;W<W=W>W?W@WAWBWCWDWEWFWGWHWIWJWKWLWMWN(B")
     (8 . "$B1Q1q2W2X2j3}6l7T<cB]CwFQIDLPNjgogpgqgrgsgtgugwgxgygzg{g|g}g~$(DWOWPWQWRWSWTWUWVWWWXWYWZW[W\W]W^W_W`WaWb(B")
     (9 . "$B0+0q1A7U9SApAqB{Cch!h"h#h%h&h'h(h)h*h+h,h-$(DWcWdWeWfWgWhWiWjWkWlWmWnWoWpWqWrWsWtWuWvWwWxWyWzW{W|W}(B")
     (10 . "$B2.2Y2Z4PG|Migmgvh$h.h/h0h1h2h3h4h5h6h7h8h9h:h;h<h=h>hO$(DW~X!X"X#X$X%X&X'X(X)X*X+X,X-X.X/X0X1X2X3(B")
     (11 . "$B0`2[5F6]8V:Z>T?{CxEQF:I)JnK(h?h@hAhBhChDhEhFhGhHhIhJhKhLhMhN$(DX4X5X6X7X8X9X:X;X<X=X>X?X@XAXBXCXDXEXFXGXHXIXJXKXL(B")
     (12 . "$B0*013k3~ArF!G#G,GkIrIxMUMnN*hRhWhXhYh[h\h]h^h_h`hahbhd$(DXMXNXOXPXQXRXSXTXUXVXWXXXYXZX[X\X]X^X_X`XaXbXcXdXeXfXgXhXi(B")
     (13 . "$B383w<,=/>U>xAsC_IGL,LXMVhPhShThUhZhchehfhghhhihjhkhlhmhnhohp$(DXjXkXlXmXnXoXpXqXrXsXtXuXvXwXxXyXzX{X|X}X~Y!(B")
     (14 . "$B0~16<CDUJNK)L"hqhrhshthuhwhxhy$(DY"Y#Y$Y%Y&Y'Y(Y)Y*Y+Y,Y-Y.Y/Y0Y1Y2Y3Y4Y5Y6Y7Y8Y9Y:Y;Y<Y=Y>Y?(B")
     (15 . "$B6><I>VB"F"HYIsJCOOhQhvhzi#i$$(DY@YAYBYCYDYEYFYGYHYIYJYKYLYMYNYOYPYQ(B")
     (16 . "$B1r70?EA&FeGvIyLtLyhVh{h|h}h~i!i%i&i'i(i)i*i+i,i-i/i0i1i2i3j1$(DYRYSYTYUYVYWYXYYYZY[Y\Y]Y^Y_Y`YaYbYcYdYeYf(B")
     (17 . "$B;'=rONi4i7i8$(DYgYhYiYjYkYlYmYnYoYpYqYrYsYt(B")
     (18 . "$B=sF#HMMui.i6i9i:i;i<$(DYuYvYwYxYyYzY{Y|(B")
     (19 . "$BAIAtMvi"i=i>i?i@iAiBiCiD$(DY}Y~Z!Z"Z#Z$Z%Z&Z'Z((B")
     (20 . "$B]"]1b<iEiFq^$(DZ)Z*Z+Z,Z-Z.Z/Z0(B")
     (21 . "$(DZ1(B")
     (22 . "$BiG$(DZ2Z3Z4Z5Z6(B")
     (24 . "$(DZ7Z8(B"))
    ("R141"
     (6 . "$BiH(B")
     (7 . "$(DZF(B")
     (8 . "$B8W(B")
     (9 . "$B5T(B")
     (10 . "$BiJ$(DZ9Z:(B")
     (11 . "$B5uQ]$(DZ;Z<Z=Z>(B")
     (12 . "$(DZ?(B")
     (13 . "$B6sN:iK(B")
     (14 . "$(DZ@ZA(B")
     (15 . "$(DZB(B")
     (16 . "$(DZCZD(B")
     (19 . "$(DZE(B"))
    ("R142"
     (6 . "$BCn(B")
     (8 . "$BiM$(DZGZH(B")
     (9 . "$B0:Fz$(DZIZJZK(B")
     (10 . "$B2c;=GBiNiOiPiQiRiS$(DZLZMZNZOZPZQZRZSZTZU(B")
     (11 . "$B3B7V<XiTiUiViWiXiYi[$(DZVZWZXZYZZZ[Z\Z]Z^Z_Z`ZaZb(B")
     (12 . "$B3?H:HZIHi\i]i^i_i`iaib$(DZcZdZeZfZgZhZiZjZkZlZm(B")
     (13 . "$B2kK*icidieigihiiijikilim$(DZnZoZpZqZrZsZtZuZvZwZxZy(B")
     (14 . "$B?*CXO9inioipiqirisit$(DZzZ{Z|Z}Z~[!["[#[$[%[&['[([)[*[+[,[-(B")
     (15 . "$B2\@fD3Ghiuiviwixiyizi{i|i}i~j!j"j#$(D[.[/[0[1[2[3[4[5[6[7(B")
     (16 . "$BB}M;Mfj%j&j'$(D[8[9[:[;[<[=[>[?[@[A[B[C[D[E[F[G[H[I[J[K(B")
     (17 . "$Bj(j)j*j+j,j-j.j/j0j2j3$(D[L[M[N[O[P[Q[R[S[T[U[V(B")
     (18 . "$Bj4j5j6j=$(D[W[X[Y[Z[[[\[][^[_[`[a[b[c[d(B")
     (19 . "$B3*5Bj$j7j8j9j:j;j<$(D[e[f[g[h[i[j[k[l[m(B")
     (20 . "$Bj>j?j@$(D[n[o[p[q[r[s(B")
     (21 . "$BiZjAjB$(D[t[u[v[w[x(B")
     (22 . "$(D[y(B")
     (23 . "$BjC$(D[z[{[|[}(B")
     (24 . "$BjDjE$(D[~\!(B")
     (25 . "$BjG(B")
     (26 . "$(D\"(B"))
    ("R143"
     (6 . "$B7l(B")
     (9 . "$BjI$(D\#(B")
     (10 . "$BjH$(D\$(B")
     (11 . "$(D\%(B")
     (12 . "$B=0$(D\&\'(B")
     (21 . "$(D\((B")
     (24 . "$(D\)(B"))
    ("R144"
     (6 . "$B9T(B")
     (9 . "$B^'$(D\*(B")
     (11 . "$B=QjJ$(D\+(B")
     (12 . "$B39$(D\,\-(B")
     (13 . "$BjK$(D\.(B")
     (15 . "$B>W$(D\/\0(B")
     (16 . "$B1R9UjL$(D\1\2(B")
     (24 . "$BjM(B"))
    ("R145"
     (5 . "$(D\3(B")
     (6 . "$B0a(B")
     (8 . "$BI=jN$(D\4\5(B")
     (9 . "$B6^CojRjSjUjV$(D\6\7\8(B")
     (10 . "$B?jB5HojOjPjWjXjYjZj[j\$(D\9\:\;\<\=\?\@(B")
     (11 . "$B0A768SB^jQjTj]j_j`jajb$(D\>\A\B\C\D(B")
     (12 . "$B:[AuJdM5N#Nvje$(D\F\G\H\I\J\L\N(B")
     (13 . "$B3l:@?~MgN"jcjdjfjhjijkjljm$(D\E\K\M\O\P\Q\R\T(B")
     (14 . "$B>X@=J#jgjnjojpj|$(D\S\V\W\Y\Z\[\\\]\^\_(B")
     (15 . "$BK+jrjsjtju$(D\U\X\`\a\c\f(B")
     (16 . "$Bjvjyjz$(D\b\d\e\g\h\j\k\l(B")
     (17 . "$Bjqjwjxj{p7$(D\i\m\n\o\p\q(B")
     (18 . "$B2(6_j}$(D\r\s\t\u\v\w(B")
     (19 . "$Bj~k!$(D\x(B")
     (20 . "$Bk"k#k$$(D\y\z(B")
     (21 . "$Bk%$(D\{(B")
     (22 . "$Bk&k'$(D\|(B")
     (23 . "$(D\}(B")
     (24 . "$(D\~]!]"(B")
     (26 . "$(D]#(B"))
    ("R146"
     (6 . "$B@>k((B")
     (9 . "$BMW(B")
     (12 . "$B0@k)(B")
     (13 . "$BlK(B")
     (18 . "$BJ$(B")
     (19 . "$BGFk*$(D]$(B")
     (25 . "$Bk+(B"))
    ("R147"
     (7 . "$B8+(B")
     (10 . "$(D]%(B")
     (11 . "$B5,;kk,$(D]&]'(B")
     (12 . "$B3PGAk-$(D]((B")
     (13 . "$(D])]*(B")
     (14 . "$Bk.$(D]+],(B")
     (15 . "$(D]-(B")
     (16 . "$B?Fk/k0(B")
     (17 . "$BMwk1k2(B")
     (18 . "$B4Qk3$(D].(B")
     (19 . "$(D]/]0]1]2(B")
     (20 . "$Bk4(B")
     (21 . "$(D]3(B")
     (22 . "$Bk5k6(B")
     (25 . "$Bk7(B"))
    ("R148"
     (7 . "$B3Q(B")
     (9 . "$(D]4(B")
     (11 . "$(D]5]6]7]8(B")
     (12 . "$Bk8k:(B")
     (13 . "$B2r?(k9k;$(D]9(B")
     (14 . "$(D]:];(B")
     (15 . "$(D]<(B")
     (16 . "$(D]=(B")
     (17 . "$(D]>(B")
     (18 . "$Bk<(B")
     (19 . "$(D]?]@(B")
     (20 . "$Bk=(B")
     (22 . "$(D]A(B")
     (25 . "$(D]B(B"))
    ("R149"
     (7 . "$B8@(B")
     (9 . "$B7WD{k>$(D]C]D]E(B")
     (10 . "$B5-71?VBwF$k?k@kA$(D]F]G]H]I]J]K(B")
     (11 . "$B5v7m>Y@_K,LukBkCkD$(D]L]M]N]O]P]Q]R(B")
     (12 . "$B1S:>;l>Z>[?GAJBBCpI>kEkFkGkHkIkJ$(D]S]T]U]V]W]X]Y]Z][]\]]]^]_]`]a]b]c(B")
     (13 . "$B3:5M7X8X;m;n>\@?A'M@OCOMkKkLkMkNkOkPkQ$(D]d]e]f]g]h]i]j]k]l]m]n]o]p]q(B")
     (14 . "$B8l8m;o@@@bFIG'M6kRkSkTkUkVkWkX$(D]r]s]t]u]v]w]x]y]z]{(B")
     (15 . "$B1Z2]5C=t?[@ABzC/CBCLD4HpNJO@kYkZk[k\k]$(D]|]}]~^!^"^#^$^%^&^'^(^)^*^+^,^-^.(B")
     (16 . "$B0b4R8A;pD5D|FfKEM!MXk^k_k`kakbkckdkekfkgkk$(D^/^0^1^2^3^4^5^6^7(B")
     (17 . "$B6`8,9V<UF%khkikjklkmknko$(D^8^9^:^;^<^=^>^?(B")
     (18 . "$BI5kpkrksktku$(D^@^A^B^C(B")
     (19 . "$B7Y<1Ihkvkwkxkykzk{k|k}$(D^D^E^F^G^H^I^J^K^L^M(B")
     (20 . "$B5D8n>yk~l!l"l#l%$(D^N^O^P^Q(B")
     (21 . "$Bl$$(D^R^S^T^U(B")
     (22 . "$B;>l&$(D^V^W^X^Y(B")
     (23 . "$B=2l'l($(D^Z^[^\(B")
     (24 . "$Bl)l*l+$(D^]^^(B")
     (25 . "$Bl,(B")
     (26 . "$Bl-(B")
     (27 . "$(D^_^`(B")
     (29 . "$(D^a(B"))
    ("R150"
     (7 . "$BC+(B")
     (10 . "$(D^b(B")
     (11 . "$Bl.$(D^c(B")
     (14 . "$(D^d(B")
     (15 . "$(D^e(B")
     (17 . "$Bl/l0(B")
     (23 . "$(D^f(B"))
    ("R151"
     (7 . "$BF&(B")
     (10 . "$Bl1$(D^g(B")
     (11 . "$(D^h(B")
     (13 . "$BK-$(D^i(B")
     (15 . "$Bl2(B")
     (16 . "$Bl3(B")
     (17 . "$(D^j(B")
     (18 . "$Bl4(B")
     (20 . "$(D^k(B")
     (27 . "$(D^l(B")
     (28 . "$(D^m(B"))
    ("R152"
     (7 . "$Bl5(B")
     (10 . "$(D^n(B")
     (11 . "$BFZ$(D^o^p^q^r(B")
     (12 . "$B>](B")
     (13 . "$Bl6$(D^s^t^u(B")
     (14 . "$B9k$(D^v^w(B")
     (16 . "$Bl7$(D^x(B")
     (17 . "$(D^y(B")
     (18 . "$(D^z(B")
     (20 . "$(D^{(B"))
    ("R153"
     (7 . "$Bl8(B")
     (10 . "$BI?l9$(D^|(B")
     (11 . "$BlA$(D^}(B")
     (12 . "$Bl:(B")
     (13 . "$Bl;l<l=$(D^~_!(B")
     (14 . "$BKFl>$(D_"(B")
     (15 . "$Bl?(B")
     (16 . "$(D_#_$_%(B")
     (17 . "$Bl@(B")
     (18 . "$BlB$(D_&(B")
     (25 . "$(D_'(B")
     (27 . "$(D_((B"))
    ("R154"
     (6 . "$BFu(B")
     (7 . "$B3-(B")
     (9 . "$BDgIi(B")
     (10 . "$B9W:b$(D_)(B")
     (11 . "$B2_4S@UHNIOlDlElIlJ(B")
     (12 . "$B2l5.B_CyE=GcHqKGLclFlHlL$(D_*_+(B")
     (13 . "$B;qA(B1DBO(OElGl\$(D_,_-_._/(B")
     (14 . "$BFx$(D_0_1_2(B")
     (15 . "$B;?;r<A>^GeIPIjlMlNlO$(D_3_4_5_6_7(B")
     (16 . "$B8-ERMj$(D_8_9_:_;(B")
     (17 . "$B9XlQlR$(D_<_=_>(B")
     (18 . "$BB#lSlT$(D_?_@_A(B")
     (19 . "$BlUlV$(D_B(B")
     (20 . "$BlX(B")
     (21 . "$BlYl]$(D_C(B")
     (22 . "$Bl[l^$(D_D(B")
     (24 . "$(D_E(B"))
    ("R155"
     (7 . "$B@V(B")
     (11 . "$B<O$(D_F(B")
     (12 . "$Bl_(B")
     (13 . "$(D_G(B")
     (14 . "$B3R(B")
     (15 . "$(D_H(B")
     (16 . "$Bl`$(D_I(B"))
    ("R156"
     (7 . "$BAvla(B")
     (9 . "$BIk(B")
     (10 . "$B5/lb(B")
     (12 . "$B1[D6lc$(D_J_K_L_M(B")
     (13 . "$(D_N_O_P(B")
     (14 . "$Bld$(D_Q(B")
     (15 . "$B<q$(D_R_S_T(B")
     (16 . "$(D_U(B")
     (17 . "$B?v(B")
     (19 . "$(D_V_W(B")
     (20 . "$(D_X(B")
     (26 . "$(D_Y(B"))
    ("R157"
     (7 . "$BB-(B")
     (10 . "$(D_Z_[(B")
     (11 . "$Blelflg$(D_\_]_^(B")
     (12 . "$B5wlhliljlklllm$(D___`_a_b_c_d_e_f_g_h_i(B")
     (13 . "$B8Y@WA)D7O)lnlolplq$(D_j_k_l_m_n_o_p_q_r(B")
     (14 . "$BMYlrlsltlu$(D_s_t_u_v_w_x(B")
     (15 . "$BF'lvlwlxlym)$(D_y_z_{_|_}_~`!`"`#(B")
     (16 . "$BD}lzl{l|l}$(D`$`%`&`'`(`)`*`+`,(B")
     (17 . "$Bl~m"m#m$m%$(D`-`.`/`0(B")
     (18 . "$B@Xm&m'm(m*m+$(D`1`2`3`4`5`6`7(B")
     (19 . "$B=3m,m-m.$(D`8`9`:`;`<`=`>`?`@(B")
     (20 . "$Bm/m0m1m2$(D`A`B`C(B")
     (21 . "$BLvm3m4(B")
     (22 . "$Bm5m6m7$(D`D`E`F(B")
     (23 . "$Bm8$(D`G`H(B")
     (24 . "$(D`I`J(B")
     (25 . "$Bm:$(D`K(B")
     (26 . "$(D`L(B")
     (27 . "$Bm9$(D`M(B"))
    ("R158"
     (7 . "$B?H(B")
     (10 . "$Bm;(B")
     (11 . "$B6m$(D`N`O(B")
     (12 . "$Bm<$(D`P(B")
     (13 . "$Bm>(B")
     (14 . "$(D`Q(B")
     (15 . "$(D`R`S(B")
     (16 . "$Bm?(B")
     (18 . "$(D`T`U(B")
     (19 . "$Bm@$(D`V`W(B")
     (20 . "$Bm=(B")
     (21 . "$(D`X(B")
     (24 . "$BmA(B"))
    ("R159"
     (7 . "$B<V(B")
     (8 . "$BmB(B")
     (9 . "$B5073(B")
     (10 . "$B8.$(D`Y`Z`[(B")
     (11 . "$BE>FpmCmD$(D`\`]`^(B")
     (12 . "$B7Z<4mEmFmG$(D`_```a`b`c(B")
     (13 . "$B3S:\mHmImJmR$(D`d`e`f`g`h(B")
     (14 . "$BJemKmLmN$(D`i`j(B")
     (15 . "$B51GZNXmMmOmPmQmS$(D`k`l`m`n`o`p`q`r`s`t`u(B")
     (16 . "$B=4M"mTmUmV$(D`v`w`x`y`z`{`|(B")
     (17 . "$B3mmWmY$(D`}`~a!(B")
     (18 . "$BmZm[m\$(Da"(B")
     (19 . "$BE2m]$(Da#a$a%a&a'(B")
     (20 . "$Bm^$(Da(a)(B")
     (21 . "$B9lm_$(Da*a+(B")
     (22 . "$Bm`(B")
     (23 . "$Bmamb(B")
     (27 . "$(Da,(B"))
    ("R160"
     (7 . "$B?I(B")
     (12 . "$(Da-(B")
     (13 . "$B<-md$(Da.(B")
     (14 . "$Bme$(Da/(B")
     (15 . "$(Da0(B")
     (16 . "$BQ~R!$(Da1a2(B")
     (19 . "$Bmf(B")
     (21 . "$Bmg(B"))
    ("R161"
     (7 . "$BC$(B")
     (10 . "$B?+(B")
     (13 . "$BG@(B"))
    ("R162"
     (3 . "$(Da3a4(B")
     (5 . "$B9~DTJUmh$(Da5(B")
     (6 . "$B1*?WC)Kx$(Da6a7a8a9(B")
     (7 . "$B6a7^JV$(Da:a;a<a=a>a?a@(B")
     (8 . "$B2`=RE3FvGwmiml$(DaAaBaCaDaEaF(B")
     (9 . "$B5UAwB`DIF(LBmjmkmm$(DaGaHaIaJaKaLaM(B")
     (10 . "$B0)?`@BB$B.C`DLD~ESF)GgO"mompmqmrm~$(DaNaO(B")
     (11 . "$B0o=5?JBamsmtmumvmwmxmymzn%$(DaPaQaRaSaTaUaVaWaXaY(B")
     (12 . "$B1?2a6x?kC#CYF;F[I/JWM7MZm{m|m}n!$(DaZa[a\a](B")
     (13 . "$B0c1s8/ALB=O!n"n#n$n&n'n($(Da^a_a`(B")
     (14 . "$B<WAxE,n)n*t#$(Daaabacad(B")
     (15 . "$B0d=eA*A+NKn+n,$(Daeaf(B")
     (16 . "$B4THrn-n.n/$(Dag(B")
     (17 . "$Bn0n1n2n3$(Dah(B")
     (18 . "$Bcdmnn5$(Daiaj(B")
     (19 . "$Bn4(B")
     (22 . "$(Dakal(B")
     (23 . "$Bn6(B"))
    ("R163"
     (6 . "$(Damanaoapaq(B")
     (7 . "$BFaK.M8n7$(Darasatau(B")
     (8 . "$BE!n8n9n:$(Davawaxayaz(B")
     (9 . "$B0j9YO:$(Da{a|a}a~b!b"b#b$(B")
     (10 . "$B74n;n<n>$(Db%b&b'b(b)b*b+b,b-(B")
     (11 . "$B3T6?ETItM9$(Db.b/b0b1b2(B")
     (12 . "$Bn?$(Db3b4b5b6b7b8b9(B")
     (13 . "$Bn@$(Db:b;b<b=b>(B")
     (14 . "$BnA$(Db?b@bAbBbCbDbEbF(B")
     (15 . "$BE"nB$(DbGbHbIbJbK(B")
     (16 . "$BnC$(DbLbMbN(B")
     (17 . "$(DbO(B")
     (18 . "$(DbPbQbR(B")
     (20 . "$(DbS(B")
     (22 . "$(DbTbU(B"))
    ("R164"
     (7 . "$BFS(B")
     (9 . "$BnD(B")
     (10 . "$B<`CqG[$(DbV(B")
     (11 . "$B?lnEnF$(DbWbXbYbZb[(B")
     (12 . "$B?]nGnHnf$(Db\b](B")
     (13 . "$B=7MonI$(Db^b_(B")
     (14 . "$B9Z9s;@nJnK$(Db`babbbc(B")
     (15 . "$B=fnLnMnN$(Dbdbebfbgbh(B")
     (16 . "$B8o@CBi$(Dbibjbkblbm(B")
     (17 . "$B=9>_nO$(Dbnbobp(B")
     (18 . "$BnPnQnR$(Dbqbrbs(B")
     (19 . "$BH0$(Dbtbubvbw(B")
     (20 . "$B>znSnT$(Dbxbybz(B")
     (21 . "$BnU$(Db{(B")
     (23 . "$(Db|(B")
     (24 . "$BnV$(Db}b~(B")
     (25 . "$BnW$(Dc!(B")
     (26 . "$(Dc"(B")
     (27 . "$(Dc#(B"))
    ("R165"
     (7 . "$BHP(B")
     (11 . "$B<=<a(B")
     (12 . "$BnX(B")
     (13 . "$B1t(B")
     (20 . "$BnY(B"))
    ("R166"
     (7 . "$BN$(B")
     (9 . "$B=E(B")
     (11 . "$BLn(B")
     (12 . "$BNL(B")
     (18 . "$BnZ(B"))
    ("R167"
     (8 . "$B6b(B")
     (9 . "$(Dc$c%(B")
     (10 . "$B3x?KE#n[n\n]n^$(Dc&c'c(c)(B")
     (11 . "$B6|D`KUn_n`na$(Dc*c+c,c-c.c/c0c1c2c3c4c5c6f#(B")
     (12 . "$B3CF_nbncndnengoO$(Dc7c8c9c:c;c<c=c>c?c@cAcBcCcDcEcFcGcHcIcJcKcL(B")
     (13 . "$B8Z9[>`E4H-Nknhninjnknlnmnonpnqnv$(DcMcNcOcPcQcRcScTcUcVcWcXcYcZc[c\c]c^c_c`cacbcccdcecfcgchcicjckclcmcn(B")
     (14 . "$B6d=F={A,A-D8F<KHLCnnnrnsntnu$(Dcocpcqcrcsctcucvcwcxcyczc{c|c}c~d!d"d#d$d%d&d'd(d)(B")
     (15 . "$B1TCrIFJ_K/nwnxnynz$(Dd*d+d,d-d.d/d0d1d2d3d4d5d6d7d8d9d:d;d<d=d>d?d@dAdBdCdDdEdFdGdHdIdJdKdLdMdNdO(B")
     (16 . "$B5x6S9]:x;,<b>{?m?nIEO#O?n{n|n}n~o!o"o#o$o%o&o'$(DdPdQdRdSdTdUdVdWdXdYdZd[d\d]d^d_d`dadbdcdddedfdgdhdi(B")
     (17 . "$B7-80>aCCDJDWEUFio(o)o*o+o,$(Ddjdkdldmdndodpdqdrdsdtdudvdwdxdydzd{d|d}d~e!e"e#e$e%e&(B")
     (18 . "$B3;3y:?AyDCo-o.o/o0o1$(De'e(e)e*e+e,e-e.e/e0e1e2e3e4e5e6e7e8e9e:e;(B")
     (19 . "$B6@E-o2o3o4o5o6o7o8o9o:o;$(De<e=e>e?e@eAeBeCeDeEeFeGeHeIeJeKeLeM(B")
     (20 . "$B>bF*o<o=o>o?o@oAoE$(DeNeOePeQeReSeTeUeVeWeXeYeZe[e\e]e^e_(B")
     (21 . "$BBxLzoBoCoDoF$(De`eaebecedeeefegeh(B")
     (22 . "$BoGoHoI$(Deiejekelem(B")
     (23 . "$B4UoJoKoLoMoT$(Deneoepeqeres(B")
     (24 . "$BoN$(Deteu(B")
     (25 . "$BoP$(Devewexeyez(B")
     (26 . "$BoQoR(B")
     (27 . "$BoSoUoV(B")
     (28 . "$BoWoX(B")
     (29 . "$(De{e|(B"))
    ("R168"
     (8 . "$BD9$(De}(B")
     (11 . "$(De~(B")
     (13 . "$Bfh(B")
     (22 . "$(Df!(B"))
    ("R169"
     (8 . "$BLg(B")
     (9 . "$BoY(B")
     (10 . "$BA.$(Df"(B")
     (11 . "$BJDLdoZo[(B")
     (12 . "$B1<3+4V4WLeo\o]$(Df$f%f&(B")
     (13 . "$Bo^o_o`$(Df'f(f)(B")
     (14 . "$B3U4X9^H6J9oaob$(Df*f+f,(B")
     (15 . "$B1\oc$(Df-f.f/(B")
     (16 . "$Bodoeofog$(Df0f1f2f3(B")
     (17 . "$B0Gohojokol$(Df4f5f6f7(B")
     (18 . "$BF.omonoo$(Df8f9f:f;f<f=(B")
     (19 . "$Bop$(Df>(B")
     (20 . "$Boq$(Df?f@fA(B")
     (21 . "$Boros$(DfBfC(B"))
    ("R170"
     (3 . "$(DfD(B")
     (5 . "$(DfE(B")
     (6 . "$Bot$(DfFfG(B")
     (7 . "$B:eKIouovow$(DfHfIfJfKfL(B")
     (8 . "$B0$AKBKIlImox$(DfMfNfOfPfQfRfS(B")
     (9 . "$B8Boyozo{$(DfTfU(B")
     (10 . "$B1!4Y9_=|?XJEo~$(DfVfWfXfY(B")
     (11 . "$B1"81DDF+GfN&N4NMo|o}p!p"p#$(DfZf[(B")
     (12 . "$B3,6y7(?oBbM[p$p%$(Df\f]f^f_f`fafbfcfd(B")
     (13 . "$B3V7dg!p&$(Dfefffg(B")
     (14 . "$B1#:]>cp'p(p)$(Dfhfi(B")
     (15 . "$(Dfjfk(B")
     (16 . "$BNYp*$(Dflfm(B")
     (17 . "$Bp+p,$(Dfnfo(B")
     (18 . "$Bp-p.$(Dfp(B")
     (20 . "$Bp/(B"))
    ("R171"
     (8 . "$Bp0(B")
     (16 . "$BNl(B")
     (17 . "$Bp1(B"))
    ("R172"
     (8 . "$Bp2(B")
     (10 . "$B@IH;$(Dfq(B")
     (11 . "$B?}Ue(B")
     (12 . "$B8[=8M:p4(B")
     (13 . "$B2mp3p5p6$(Dfr(B")
     (14 . "$B;(;s$(Dfs(B")
     (16 . "$Bp:$(Dft(B")
     (18 . "$B?wFqN%RVp8$(Dfufvfwfxfy(B"))
    ("R173"
     (8 . "$B1+(B")
     (11 . "$B<6@c$(Dfz(B")
     (12 . "$B1@J7$(Df{f|(B")
     (13 . "$BEEMkNmp;$(Df}(B")
     (14 . "$B<{(B")
     (15 . "$B?LNnp<p=p>$(Df~g!g"g#(B")
     (16 . "$Bp9p?p@pApBpC(B")
     (17 . "$B2bAzpD$(Dg$g%g&g'(B")
     (18 . "$BpE$(Dg(g)(B")
     (19 . "$BL8pF$(Dg*(B")
     (20 . "$BpG$(Dg+(B")
     (21 . "$BO*pH$(Dg,(B")
     (22 . "$BpIpJ(B")
     (23 . "$(Dg-(B")
     (24 . "$BpKpLpMpN$(Dg.(B")
     (25 . "$BpO(B")
     (26 . "$(Dg/g0g1(B"))
    ("R174"
     (8 . "$B@D(B")
     (13 . "$BLw$(Dg2(B")
     (14 . "$B@E$(Dg3g4(B")
     (15 . "$(Dg5(B")
     (16 . "$(Dg6(B"))
    ("R175"
     (8 . "$BHs(B")
     (14 . "$BfGjj(B")
     (15 . "$BpQ(B")
     (19 . "$BsS(B"))
    ("R176"
     (9 . "$BLL$(Dg7(B")
     (14 . "$BpR(B")
     (16 . "$BpS(B")
     (21 . "$(Dg8(B")
     (23 . "$BpT(B"))
    ("R177"
     (9 . "$B3W(B")
     (11 . "$(Dg9(B")
     (12 . "$B?YpVpW$(Dg:(B")
     (13 . "$B7$pX$(Dg;g<g=g>(B")
     (14 . "$B3spYpZp[p\p]$(Dg?g@gAgB(B")
     (15 . "$B0Hp^p_p`$(DgC(B")
     (16 . "$B>d$(DgDgEgFgG(B")
     (17 . "$B5Gpa$(DgHgIgJ(B")
     (18 . "$BJ\kqpbpcpd$(DgKgLgM(B")
     (19 . "$Bpepf$(DgNgOgPgQ(B")
     (20 . "$(DgRgSgT(B")
     (21 . "$(DgUgVgW(B")
     (22 . "$Bpg$(DgX(B")
     (23 . "$(DgYgZ(B")
     (24 . "$Bphpi$(Dg[(B")
     (26 . "$(Dg\(B")
     (30 . "$(Dg](B"))
    ("R178"
     (9 . "$Bpj(B")
     (12 . "$(Dg^(B")
     (14 . "$(Dg_g`(B")
     (15 . "$(Dgagb(B")
     (17 . "$B4Z$(Dgc(B")
     (18 . "$(Dgdgegf(B")
     (19 . "$Bpk$(Dgggh(B")
     (20 . "$(Dgigj(B")
     (21 . "$(Dgk(B")
     (24 . "$(Dgl(B"))
    ("R179"
     (9 . "$Bpl(B")
     (15 . "$(Dgm(B")
     (17 . "$(Dgn(B")
     (19 . "$Bpn(B"))
    ("R180"
     (9 . "$B2;(B")
     (11 . "$Bpo(B")
     (13 . "$Bpq$(Dgo(B")
     (14 . "$Bpp$(Dgp(B")
     (16 . "$(Dgq(B")
     (18 . "$(Dgr(B")
     (19 . "$B1$(B")
     (20 . "$B6A(B"))
    ("R181"
     (9 . "$BJG(B")
     (11 . "$BD:(B")
     (12 . "$B9`$(Dgs(B")
     (13 . "$B4hF\HRMBps$(Dgtgugvgw(B")
     (14 . "$B7[NN$(Dgxgy(B")
     (15 . "$BKK$(Dgzg{g|g}g~h!(B")
     (16 . "$B1P3\F,ptpx$(Dh"h#h$h%h&h'h((B")
     (17 . "$BIQpy$(Dh)h*h+h,(B")
     (18 . "$B3[4i82BjN`pzp{$(Dh-h.h/(B")
     (19 . "$B4jE?$(Dh0h1h2h3(B")
     (20 . "$(Dh4h5(B")
     (21 . "$B8\$(Dh6h7hF(B")
     (22 . "$Bp|$(Dh8(B")
     (23 . "$Bp}$(Dh9(B")
     (24 . "$Bp~(B")
     (25 . "$Bq!(B")
     (27 . "$Bq"q#(B"))
    ("R182"
     (9 . "$BIw(B")
     (13 . "$(Dh:(B")
     (14 . "$Bq%q&$(Dh;h<h=(B")
     (16 . "$(Dh>(B")
     (17 . "$Bq'$(Dh?(B")
     (18 . "$(Dh@hA(B")
     (19 . "$(DhBhC(B")
     (20 . "$Bq(q)$(DhDhE(B")
     (21 . "$Bq*(B")
     (27 . "$(DhG(B"))
    ("R183"
     (9 . "$BHt(B")
     (21 . "$BfL(B"))
    ("R184"
     (9 . "$B?)(B")
     (10 . "$B52(B")
     (11 . "$(DhHhI(B")
     (12 . "$B0{HS$(DhJhKhL(B")
     (13 . "$B0;;t>~K0R,];q+q,$(DhM(B")
     (14 . "$B1BL_$(DhNhO(B")
     (15 . "$B2nM\q-q.$(DhPhQhR(B")
     (16 . "$B4[;Aq/q0q1$(DhShThUhV(B")
     (17 . "$Bq2q3q4q5q6$(DhWhXhYhZh[h\h](B")
     (18 . "$Bq7q8$(Dh^h_h`hahb(B")
     (19 . "$Bq9q:q;$(Dhchdhehfhghhhi(B")
     (20 . "$Bq<q=$(Dhjhkhl(B")
     (21 . "$Bq>q?q@qAqB$(Dhmhn(B")
     (22 . "$B6BqC$(Dhohphq(B")
     (23 . "$(Dhrhs(B")
     (26 . "$(Dhthu(B")
     (28 . "$(Dhv(B"))
    ("R185"
     (9 . "$B<s(B")
     (11 . "$BqD(B")
     (17 . "$BqE(B"))
    ("R186"
     (9 . "$B9a(B")
     (14 . "$(Dhwhx(B")
     (16 . "$(Dhy(B")
     (18 . "$BqF(B")
     (19 . "$(Dhz(B")
     (20 . "$B3>(B"))
    ("R187"
     (10 . "$BGO(B")
     (12 . "$BqGqH(B")
     (13 . "$BCZFk$(Dh{h|h}h~(B")
     (14 . "$B1X6nBLG}qI$(Di!i"i#i$i%(B")
     (15 . "$B2o6o6pCsqJqKqLqMqN$(Di&i'i(i)i*i+i,(B")
     (16 . "$BqOqPqQqRqX$(Di-i.i/i0i1(B")
     (17 . "$B=YqSqTqU$(Di2i3i4i5i6i7i8(B")
     (18 . "$B5383A{qVqW$(Di9i:i;i<i=(B")
     (19 . "$BBMqY$(Di>i?i@iAiBiCiD(B")
     (20 . "$BF-qZq[$(DiEiFiGiHiIiJ(B")
     (21 . "$Bq\q]q_q`$(DiKiLiM(B")
     (22 . "$B6Cqaqb$(DiNiOiPiQiRiS(B")
     (23 . "$Bqcqd$(DiT(B")
     (24 . "$Bqe$(DiU(B")
     (26 . "$Bqf(B")
     (27 . "$Bqgqh(B")
     (28 . "$Bqi(B")
     (29 . "$Bqk(B")
     (30 . "$Bqj(B"))
    ("R188"
     (10 . "$B9|(B")
     (13 . "$Bql$(DiViWiX(B")
     (14 . "$Bqm$(DiY(B")
     (15 . "$(DiZi[i\i](B")
     (16 . "$B3<qn$(Di^i_(B")
     (17 . "$(Di`(B")
     (18 . "$Bqo$(Diaib(B")
     (19 . "$B?q$(Dic(B")
     (20 . "$(Didie(B")
     (21 . "$Bqp$(Dif(B")
     (22 . "$(Dig(B")
     (23 . "$Bqqqrqs$(Dih(B")
     (24 . "$(Dii(B")
     (25 . "$(Dij(B")
     (26 . "$(Dik(B"))
    ("R189"
     (10 . "$B9b(B")
     (15 . "$(Dil(B")
     (18 . "$(Dim(B")
     (23 . "$Bqt(B"))
    ("R190"
     (10 . "$Bqu(B")
     (12 . "$(Din(B")
     (13 . "$Bqv(B")
     (14 . "$BH1qwqx$(Dioipiqir(B")
     (15 . "$Bqyqzq{q|q}$(Disitiu(B")
     (16 . "$BI&q~r!$(Diviwix(B")
     (17 . "$(Diyizi{i|i}(B")
     (18 . "$Br"$(Di~j!j"j#(B")
     (19 . "$(Dj$j%j&j'j((B")
     (20 . "$(Dj)j*(B")
     (21 . "$Br#$(Dj+j,(B")
     (22 . "$Br$$(Dj-j.(B")
     (23 . "$Br%$(Dj/(B")
     (24 . "$Br&(B")
     (25 . "$Br'(B"))
    ("R191"
     (10 . "$Br((B")
     (14 . "$(Dj0(B")
     (15 . "$Br)(B")
     (16 . "$Br*(B")
     (18 . "$Br+(B")
     (20 . "$Br,(B")
     (22 . "$(Dj1(B")
     (24 . "$(Dj2(B")
     (26 . "$Br-(B"))
    ("R192"
     (10 . "$Br.(B")
     (29 . "$B]5(B"))
    ("R193"
     (10 . "$Br/(B")
     (16 . "$(Dj3(B")
     (17 . "$(Dj4(B")
     (18 . "$(Dj5(B")
     (19 . "$(Dj6(B")
     (21 . "$(Dj7j8(B")
     (22 . "$Bdx(B"))
    ("R194"
     (10 . "$B54(B")
     (13 . "$(Dj9(B")
     (14 . "$B3!:2(B")
     (15 . "$BL%r0r1(B")
     (17 . "$(Dj:(B")
     (18 . "$Br2r3r4$(Dj;j<(B")
     (21 . "$BKbr5$(Dj=(B")
     (23 . "$(Dj>(B")
     (24 . "$(Dj?(B"))
    ("R195"
     (11 . "$B5{(B")
     (13 . "$(Dj@jA(B")
     (14 . "$(DjB(B")
     (15 . "$BO%r7$(DjCjDjEjFjGjHjIjJjKjLjMjNjOjP(B")
     (16 . "$B0>J+r8r9r:r;r<$(DjQjRjSjTjUjVjWjXjYjZj[j\j](B")
     (17 . "$B:z;-A/Knr=r>r?r@$(Dj^j_j`jajbjcjdjejfjg(B")
     (18 . "$B8qrArBrCrDrErFrG$(Djhjijjjkjljmjnjojpjqjr(B")
     (19 . "$B037_;*BdrHrIrJrKrLrNrOrP$(Djsjtjujvjwjxjyjzj{j|(B")
     (20 . "$B3bOLrQrRrSrTrUrVrWrXrYrZr\$(Dj}j~k!k"k#k$k%k&k'k(k)k*k+k,k-(B")
     (21 . "$B0sIIr[r]r^r_r`$(Dk.k/k0k1k2k3k4k5k6(B")
     (22 . "$B17C-rMrarbrcrd$(Dk7k8k9k:k;k<k=k>k?(B")
     (23 . "$B3oKpre$(Dk@kAkBkCkDkEkFkGkHkI(B")
     (24 . "$BNZrfrg$(DkJkKkLkMkNkOkPkQ(B")
     (25 . "$(DkRkSkT(B")
     (26 . "$Brh$(DkUkV(B")
     (27 . "$Bri$(DkW(B")
     (33 . "$(DkX(B"))
    ("R196"
     (9 . "$Brk(B")
     (11 . "$BD;(B")
     (12 . "$(DkY(B")
     (13 . "$BH7rjrlro(B")
     (14 . "$(DkZ(B")
     (15 . "$B2*F>rmrnrprq$(Dk[k\k]k^(B")
     (16 . "$B1u2)3{rrrsrurvrxry$(Dk_k`kakbkckd(B")
     (17 . "$Brwrzr{r|r}r~$(Dkekfkgkhkikjkkklkmknkokp(B")
     (18 . "$B1-9ts!s"s#s$s%s&$(Dkqkrksktkukvkw(B")
     (19 . "$B7\L9s's(s)s+s,$(Dkxkykzk{k|k}k~l!l"l#l$l%l&l'l((B")
     (20 . "$Bs*s-s.s/$(Dl)l*l+l,l-l.l/l0(B")
     (21 . "$BDarts0s1s2s3s4s5s6s7s8$(Dl1l2l3l4l5l6l7l8l9l:l;(B")
     (22 . "$Bs9s:$(Dl<l=l>l?l@lAlBlC(B")
     (23 . "$BOIs;s<s=s>$(DlDlElFlGlHlIlJlK(B")
     (24 . "$B:mBks?$(DlLlMlNlO(B")
     (25 . "$(DlPlQlRlS(B")
     (27 . "$(DlTlU(B")
     (28 . "$Bs@$(DlV(B")
     (29 . "$BsA$(DlW(B")
     (30 . "$BsB$(DlX(B"))
    ("R197"
     (11 . "$BsC(B")
     (19 . "$B84(B")
     (20 . "$BsD(B")
     (21 . "$(DlYlZ(B")
     (24 . "$(Dl[(B")
     (25 . "$BsE(B"))
    ("R198"
     (11 . "$B</(B")
     (13 . "$BsF$(Dl\l](B")
     (15 . "$(Dl^l_(B")
     (16 . "$BsG$(Dl`la(B")
     (17 . "$BsH$(Dlb(B")
     (18 . "$BsI$(Dlc(B")
     (19 . "$BNoO<sJsKsL$(Dld(B")
     (20 . "$(Dlelf(B")
     (22 . "$(Dlg(B")
     (24 . "$BN[(B")
     (33 . "$(Dlh(B"))
    ("R199"
     (7 . "$BG~(B")
     (11 . "$BsNsPsQ(B")
     (12 . "$BsR(B")
     (15 . "$B9msO$(Dli(B")
     (16 . "$BLM$(Dljlk(B")
     (17 . "$(Dlllm(B")
     (19 . "$(Dlnlo(B")
     (20 . "$(Dlp(B"))
    ("R200"
     (14 . "$BVw(B"))
    ("R201"
     (11 . "$B2+(B")
     (16 . "$(Dlq(B")
     (17 . "$(Dlr(B")
     (18 . "$(Dls(B")
     (25 . "$BsT(B"))
    ("R202"
     (12 . "$B5P(B")
     (15 . "$BsU(B")
     (17 . "$BsV(B")
     (23 . "$BsW(B"))
    ("R203"
     (11 . "$B9u(B")
     (15 . "$BL[(B")
     (16 . "$BBc`TsX$(Dlt(B")
     (17 . "$BsYsZs[(B")
     (18 . "$Bs\$(Dlu(B")
     (20 . "$Bs]s^$(Dlvlw(B")
     (21 . "$Bs_$(Dlxly(B")
     (22 . "$(Dlzl{l|(B")
     (23 . "$Bs`$(Dl}(B")
     (25 . "$(Dl~(B")
     (26 . "$Bsa(B")
     (27 . "$Bsb(B")
     (28 . "$(Dm!(B"))
    ("R204"
     (12 . "$Bsc(B")
     (17 . "$Bsd(B")
     (19 . "$Bse(B"))
    ("R205"
     (13 . "$Bsf(B")
     (17 . "$(Dm"(B")
     (18 . "$(Dm#(B")
     (19 . "$(Dm$(B")
     (24 . "$Bsg(B")
     (25 . "$Bsh$(Dm%(B"))
    ("R206"
     (13 . "$BE$(B")
     (15 . "$(Dm&m'm((B")
     (16 . "$(Dm)(B"))
    ("R207"
     (13 . "$B8]$(Dm*(B")
     (14 . "$Bsi(B")
     (18 . "$Bsj(B")
     (19 . "$(Dm+m,(B")
     (21 . "$(Dm-m.m/(B")
     (25 . "$(Dm0(B"))
    ("R208"
     (8 . "$Bsk(B")
     (13 . "$BAM(B")
     (17 . "$(Dm1(B")
     (18 . "$Bsl$(Dm2m3m4(B")
     (20 . "$(Dm5(B")
     (21 . "$(Dm6(B")
     (22 . "$(Dm7m8(B")
     (23 . "$(Dm9m:(B")
     (28 . "$(Dm;(B"))
    ("R209"
     (14 . "$BI!(B")
     (16 . "$(Dm<m=(B")
     (17 . "$Bsm$(Dm>(B")
     (19 . "$(Dm?(B")
     (23 . "$(Dm@mA(B")
     (24 . "$(DmBmCmD(B"))
    ("R210"
     (8 . "$B@F(B")
     (11 . "$B:X(B")
     (14 . "$Bi5sn(B")
     (17 . "$Bc7(B")
     (21 . "$BlZ(B")
     (23 . "$Bpm(B"))
    ("R211"
     (12 . "$B;u(B")
     (15 . "$Bso(B")
     (16 . "$(DmE(B")
     (17 . "$BNpsp(B")
     (18 . "$(DmF(B")
     (19 . "$(DmGmHmI(B")
     (20 . "$Bsqsrssst$(DmJmKmL(B")
     (21 . "$Bsusv$(DmMmN(B")
     (22 . "$Bswsx(B")
     (23 . "$(DmOmPmQmRmS(B")
     (24 . "$Bsyszs{$(DmTmU(B")
     (25 . "$(DmV(B")
     (28 . "$(DmW(B"))
    ("R212"
     (10 . "$BN5(B")
     (16 . "$BN6(B")
     (19 . "$(DmXmY(B")
     (20 . "$(DmZ(B")
     (21 . "$(Dm[(B")
     (22 . "$B=1O8$(Dm\(B")
     (32 . "$(Dm](B")
     (33 . "$(Dm^(B"))
    ("R213"
     (11 . "$B55(B")
     (18 . "$Bs}(B")
     (28 . "$(Dm_(B"))
    ("R214"
     (17 . "$Bs~(B")
     (21 . "$(Dm`(B")
     (22 . "$(Dma(B")
     (25 . "$(Dmb(B")
     (26 . "$(Dmc(B"))
))
    

(defvar strokes-table-jis
  '[0					; ignore
   "$B0l$(D0)0/00$BP&P($(D04$B25P-(B" ; 1
   "$(D0!0"0#$B<7Cz$(D01$BG5P)$(D05$B6eN;FsP5?MQ9F~H,QDQLQRQ\Qa$(D3031$BEaNOR1R8R9R>==KNRG(B\
$BRLRSKt(B" ; 2
   "$(D0$$B2<;0>e>fK|M?$(D0*$B4]G7$(D02$B5W5Z8pLi$(D0=$BP2K4P$Q:$(D2n3)$BK^?OQc$(D3X$B<[$(D46$B@i:58}SxEZ(B\
$B;NTiTjM<$(D8k$BBg=w$(D:=$B;RUSU_@#>.$(D:m$BUwUyV%;3@nV_9)8JL&Va6R43VvVxW.W0W55]$(D<w$BW@WD(B\
$BWF$(D=8?7$B:M$(DFSJma3a4fD(B" ; 3
   "$(D0%$B1/ITP"$(D0+0,0-$BCfRAC0K3$(D06$BM=$(D0>$B0f1>8^8_P6$(D0C0D$B2=2p5X:#=:?NJ)P:P;P<P=P>(B\
$(D2e$B0t85Fb8xO;QB$(D2p2q$B1_$(D2t$B>i6'$(D32$B4"@ZJ,$(D3{$B8{FwL^Lh6hI$8a>#F{R@RF$(D4>4C$BLq$(D4S4T$BAP(B\
$BH?M'$(D7-$BB@E7IWToTp9&>/L`<\UzFVV&GC$(D<$$B88P!0zD$W7?4Xy8M<jY);YZ=Z>J8EM6TJ}Z[(B\
$BF|[)7nLZ7g;_]F]U$(DF7$B]YHfLS;a]c$(DFTFU$B?e$(DID$B2P$(DJH$BD^Ic`+`-JR2g$(DJX$B5m8$2&?Q$(DPK$Bmh(B" ; 4
   "$B3n5V@$J:P#5l:}=PP%RB<gI,I9P'1J8CFcJ&$(D0?0E0F0G0H0I0J$B0J;E;F@gB>BeIUNa(B\
$BP?P@PAPB7;$(D2r$BQEQFQG<L$(D2x$BE_$(D3*$BB|$(D3/$B1zFL4)Qd2C8yJqR2KL$(D4%4&4'$BAY$(D47$BH>RC$(D4;$B@j$(D4?$B1,(B\
$BRHRI$(D4D4E4U$B5n$(D4Y$B<}$(D4a4b4c$B1&2D3p6g8E9f;J;K<8>$BfB~C!RZR[R\R]$(D6r6s$B;M<|$(D7.7/70(B\
$(D71$B05T)=h30$(D8l8m8n$B1{<:Tq$(D9#9$$BE[UT$(D:G:H$BU`Uu?,Ft$(D;#;$$BV'5p9*:8;TI[J?MD$(D<B$B9-D#J[(B\
$BP190$(D=9=;$BJjXz$(D?1?8?9?:?;?<$BBGJ'@MZ\C6;%K\KvL$[2@5Jl$(DFI$BL1$(DFVFW$B=ADuHE$(DJn$BHH8<6L(B\
$B1;4$4E@8$(DM($BMQ9C?=EDM3I%$(DMF$Bb"GrHi;.L\L7Lp@P<(Ni$(DPr$B2S7jN)$(DTtTuW,W-W.W/W0$Bgh$(D\3(B\
$(Da5$B9~DTJU$(DfE(B" ; 5
   "$(D0&$B:F>gN>OJ1H=#$(D03$B0P$(D0708$BOK0g8rKr$(D0K0L0M0N0O0P0Q0R0S0T0U0V0W0X0Y0Z0[0\(B\
$B0K2>2q4k4l5Y6D7o8`A4CgEAG$H2IzPCPDPg$(D2f$B6$8w=<@h6&$(D2s$Bf&C{QSQTQUQV=HFdQ^$(D33(B\
$(D34353637$B7:NsQeQf$(D3Y3Z3[3\$BNt$(D3|$BR3$(D4($B6)>"$(D48$BRD0u4m$(D4V$BL6$(D4Z4d4e$B1%3F5H5I5[6+8~9!(B\
$B9gD_EGF1L>MyR^$(D6t6u6v$B0x2sCD$(D7273747576777879$B7=:_COT*T+$(D8_$BB?Tl$(D8o8p$BTr$(D9%9&9'(B\
$B9%G!H^LQU!U"$(D:>$B;zB8$(D:I$B0B1'<iBp;{$(D:j$B@mEv$(D:n$B?T$(D;";%;&;';($BV(=d$(D<!<%$BHAG/VtVu>1$(D<\(B\
$(D<`$B<0$(D<a<b$BCP$(D=#=$=:=<=@=A$BK;WV=?@.X{X|$(D?=?>??$B07BqY*Y+Y,Y-Y.Z?Z@00;]=\Aa6JM-(B\
$(DBvBw$B4y5`<kKQ[3[4[5[6[7<!:!;`Kh$(DFJ$B5$$(DFXFYFZF[F\F]F^F_F`$B1x4@9><.CSFrHF]h]i(B\
$(DIE$B3%EtAhAT$(DJY$BLF$(DJoJp$B`<$(DKRKSM)M+$BI4$(DPLQO$BC]JF;e4LMS1)9MO7<)fP<*ff$(DUl$BFyH)O><+;j(B\
$B11@e=.:1?'$(DW1W2W3W4W5W6W7W8W9$B0r<GgggigjiHCn7l9T0a@>k(Fu$(Da6a7a8a9$B1*?WC)Kx(B\
$(DamanaoapaqfFfG$Bot(B" ; 6
   "$(D0'0($BV`6zEFiIMpP/0!5|$(D0]0^0_0`0a0b0c0d0e0f0g0h0i0j0k0l0m0n0o0p0q$B0L2?(B\
$B2@:4:n;G;w=;?-BNC"DQDcGlH<M$M>MhNbPEPFPGPHPIPJ$(D2g$B9n;yQ<J<QH$(D2u$Bf'$(D2y2z$B:cLj(B\
$BNdQW$(D38$B=iH=JLMxQgQh$(D3]3^$B9e=uEXNeO+R"R#$(D4)$B0eR:$(D4<4@$B5QB(Mq$(D4F4[4f4g4h4i4j4k4l(B\
$(D4m4n4o4p4q4r4s$B4^6c7/8b8c9p?aDhF]H]J-JrKJO$R_R`RaRbRcRdReRfRgRh$(D6w6x6y6z(B\
$(D6{6|6}6~$B0O:$?^Sy$(D7:7;7<7=7>7?7@$B6Q9#:A:dK7T,T-T.T/0m@<GdTc$(D8`8a8q$BTs$(D9(9)9*(B\
$(D9+9,9-9.9/90$B58BEG%K8L/MEU#U$U&U+$(D:?$B9';ZUUUV$(D:J:K:L:M$B409(<5AWO4$(D:h$B<wBP$(D:o:p(B\
$(D:q$BUx6IG"HxU{$(D;);*;+;,;-$B4tV)V*V+V,$(D;}$B962~Vb$(D<&$B4uVc$(D<C<D$B=x>2H_DnW1$(D<c<d$BDo$(D<|<}(B\
$B7A$(D=%=&$BLrWG$(D===>=?=C=E=G=I=J=K=L=M=N=O=P=Q$B1~2w4w;VG&K:WWWXWYWZX-$(D?($B2f2|La(B\
$(D?@?A?B?C?D?E?F?G?H$B5;93>6@^BrEjGDH4HcI^J1M^Y/Y0Y1Y2Y3Y4Y5Y7Y8$(DAGAH$BZAU]$(DA[(B\
$(DAnAoApAq$BZ]99[*$(DBxByBzB{B|B}B~C!$B0I:`<]>r>s?yB+B<ENL]M{[8[9[:[;[<[=$(DEhFKFa(B\
$(DFbFcFdFeFfFgFhFiFjFkFlFmFnFoFpFqFr$B2-5%5a5b7h:;BABtD@FYKWM`]g]j]k]l]m]n(B\
$B]o]p]q]r]s]t^"$(DIFIGIH$B5d:R<^>u$(DJZ$B24$(DJqJrJs$B68`;`=`>`?$(DKTKUKVKW$B6jO.a#Jca5$(DM,$BCK(B\
$BD.R4a6$(DMGMH$BaK$(DN5$Bb%b&$(DNI$Bbc$(DOKPM$B77<Rc+$(DPt$B;d=(FE5f$(DQf$Bcg7Od}$(DU[UmUn$B4N>SI*fjfkfl?C(B\
$(DVb$BA$NI$(DW:W;W<W=W>W?W@WAWBWCWDWEWFWGWHWIWJWKWLWMWN$B022V3)4#6\7]?DGNIgK'gk(B\
$Bglgn$(DZF$B8+3Q8@C+F&l5l83-@VAvlaB-?H<V?IC$$(Da:a;a<a=a>a?a@$B6a7^JVmi$(Darasatau$BFa(B\
$BK.M8n7FSHPN$$(DfHfIfJfKfL$B:eKIouovowG~(B" ; 7
   "$BJBb32L>5P*$(D090:$BF};v$(D0@$B:3P3P45}5~$(D0r0s0t0u0v0w0x0y0z0{0|0}0~1!1"1#1$1%(B\
$(D1&1'1(1)1*1+1,1-1.1/1011$B0M2A2B4&6!6"8s;H;x<KInJ;KyNcPKPLPMPNPOPPPQPRPS(B\
$BPTPU$(D2h2i2j$BLHQ;Q=Q@6qB6E5f($(D2{2|2}$BQX$(D3+$BQ_H!$(D393:3;3<3=$B7t9o:~;I@)E~QjQk$(D3_3`(B\
$(D3a3b3c3d$B3/8zR$R%$(D3}3~4!43$B6(B4Bn$(D4=$B75$(D4A$BRK$(D4G4H4W$B;2$(D4\$B<h<u=G$(D4t4u4v4w4x4y4z4{(B\
$(D4|4}4~5!5"5#5$5%5&5'5(5)5*$B8F:p<v<~L#L?RiRjRkRlRmRnRpRqRrRsRtRuRv$(D7!7"$B8G(B\
$B9qSz$(D7A7B7C7D7E7F7G7H7I7J7K7L7M7N7O7P7Q7R7S7T7U$B6F:%?bC3DZT0T3T4T5$(D8^8b8g(B\
$BLk$(D8r8s$B1b4qF`JtK[$(D9192939495969798999:9;9<9=9>9?$B090Q8H:J;O;P@+EJKeU%U'U((B\
$B3X5(LRUW$(D:N:O:P$B084159<B=!ChDjEfJu>05o6~FOU|$(D;.;/;0;1;2;3;4;5;6;7;8$B2,3Y4_(B\
$B4dA;BRL(V-V.V/V0V1V2V3$(D<'<(<)<*$BD!VdVeVfVg9,9.DlE9I\Jy1dW/$(D<]<e<f<g<h$B89Lo(B\
$BW8$(D<x='=($B1}7B@,H`WHWIWJ$(D=B=D=F=H=R=S=T=U=V=X=Y=[=\=]$B2x619z@-CiG0I]NgW[W](B\
$BW^W`WaWbWeWfWgWhWiWj$(D?)$B0?X}$(D?2$B=jK<$(D?I?J?K?L?M?N?O?P?Q?R?S?T?U$B2!2}3H5q5r94(B\
$B>7@[BsC4CjDqGRGoHdJzKuY6Y9Y:Y;Y>Y@YBYCYDYEYFYGZ-$(DAI$BJ|$(DA_$B1w$(DArAsAtAuAvAwAx(B\
$(DAyAzA{A|A}$B0W2"97:*:+>:>;@NL@Z_Z`I~J~$(DC"C#C$C%C&C'C(C)C*C+C,C-C.C/C0$B5O9:(B\
$B;^>>?u@OElGGGUHDHzKgKmNSOHOPZ^Zb[>[?[@[A[B[C[D[E[F[G2$6U$(DEyEz$BIpJb$(DE~F!$B]G(B\
$B]H2%FG][]b]d$(DFsFtFuFvFwFxFyFzF{F|F}F~G!G"G#G$G%G&G'G(G)G*$B1K1h2O5c677#<#(B\
$B>BCmE%GHGqHgJ(K!K"KwL}]u]v]w]x]y]z]{]|]}]~^!^#^$^%$(DIIIJIKILIMINIOIPIQ$B1j(B\
$B?fO'_U_V:S`'`($(DJK$BI``.HG<Y$(DJ[J\J]$BJ*KR$(DJtJuJvJwJx$B6i8Q9}A@`@`A$(DKXKYKZK[K\K]K^(B\
$(DK_K`Ka$B4a$(DLu$Ba$$(DM-M.M/M0M1$B2ha7$(DMIMJ$BaLaME*$(DNUNV$BD>LUZa$(DOE$BCN$(DOLOM$Bbe$(DPNPOPPPQPR$B5'5@(B\
$B;c$(DPuPvPwPx$BOBc=$(DQP$B6uFMcV$(DQg$B>*ch$(DQp$B<3dbf5<T$(DUOU\UoUpUqUrUs$B0i8*8T9N9O:h;hHnKC(B\
$Bfmfnfo$(DVkVo$BQigR$(DWOWPWQWRWSWTWUWVWWWXWYWZW[W\W]W^W_W`WaWb$B1Q1q2W2X2j3}6l7T(B\
$B<cB]CwFQIDLPNjgogpgqgrgsgtgugwgxgygzg{g|g}g~8W$(DZGZH$BiM$(D\4\5$BI=jNmB$(DaAaBaCaD(B\
$(DaEaF$B2`=RE3FvGwmjmkmlmm$(Davawaxayaz$BE!n8n9n:6b$(De}$BD9Lg$(DfMfNfOfPfQfRfS$B0$AKBKIl(B\
$BImoxp0p21+@DHssk@F(B" ; 8
   "$BOD0}>hH}$(D0;0A$BDbN<P7Tu$(D12131415161718191:1;1<1=1>1?1@1A1B1C1D1E$B2d788t(B\
$B=S?.?/B%B/JXJ]KsN7PWPXPYPZP[P\P]P^P_P`$(D2k$BQA=64'$(D2~$BQb$(D3>3?$B:oA0B'DfQlQmQnQo(B\
$(D3e3f3g3h$BD<KVM&R&R5$(D4*4+4,44$BFnH\27RJ$(D4I$B8|NRRM$(D4]4^$B=vH@$(D5+5,5-5.5/5051525354(B\
$(D55565758595:5;5<$B0%0v31:H:iC1IJRoRwRxRyRzR{R|R}R~S!S"S#S$S%S&S>S{S|$(D7V7W(B\
$(D7X7Y7Z7[7\7]7^7_7`7a7b7c7d$B3@7?9$>kT2T6T7T8T9T:T;7)JQ$(D8t8u$B7@AUTvTw$(D9@9A9B(B\
$(D9C9D9E9F9G9H9I9J9K9L9M$B0#0(0R0y184/;QLEU)U*U,U-$(D:@$B8IUX$(D:Q:R$B5R<<@kM(@lIu$(D:r(B\
$B20;SU}V"$(D;9;:;;;<;=$B6.F=V4V5$(D<"<#$B4,9+$(D<+$B?cDkM)$(D<E<F<G$BEYVy2v7zG6$(D<^<_<i<j<k$B8L(B\
$BW9W?WAI'$(D=)=*$B8eBTN'WKWLWN$(D=W=Z=^=_=`=a=b=c=d=f=g=h=j$B1e2y2z3f5^91:(;WBUE\(B\
$BW_WcWdWmWoWpWqWrWtWuWvWwWx$(D?3?4$BY($(D?V?X?Y?Z?[?\?]?^?_?a?b?c$B0D3g649i;";X;}(B\
$B=&?!D)Y<YAYHYIYJYKYLYNYO$(DAFAJ$B8N@/ZQ$(DAd$B;\$(DA~B!B"B#B$B%B&B'B(B)B*B+B,B-B.B/(B\
$(DB0$B1G:r=U><@'@1CkKfZcZdZeZf[&[+$(DBp$B[,$(DC1C2C3C4C5C6C7C8C9C:C;C<C=C>C?C@CACB(B\
$(DCCCDCECFCGCH$B1I2M3A4;8O:::t=@@wBHClDNDSFJGpI"JAK?KoLxM.[H[I[J[K[L[M[N[O(B\
$B[P[Q[R[S[T[U[V[W$(DEiF"F#$BKX]I]JCJ$(DF8F:FLG+G,G-G.G/G0G1G2G3G4G5G6G7G9G:G;G<(B\
$B1L3$3h9?='>t@t@u@vDEF6GIMNMl^&^(^)^*^+^,^-^.^/^0$(DIRISITIUIVIW$BC:E@_W_Y_Z(B\
$B_[_\$(DJI$B0Y`)`,$(DJMJ^J_J`$B@7`2$(DJyJz$B69<mFH`B`C`D$(DKPKbKcKdKeKfKgKhKiKjKkKlKm$B2Q;9(B\
$BDANh`]`^`_```a$(DLvLwLx$Ba%a&a'a(?S$(DM$M2M3M4M5M6$B0Z3&H*H{ZBa8a9a:a<$(DMKML$B1VaNaO(B\
$BH/b#$(DN6$B3'9Db'$(DNJ$B1NGVK_$(DNWNXNYNZN[N\$B4G8)=b>JAjKAb=b>b?b@bb$(DOF$BGj$(DONOOOPOQOROS(B\
$B8&:=:Ubfbg$(DPSPTPUPVPWPX$B=K?@ADG*M4c,c-c/c0c1c;c<$(DPyPzP{$B2J=)ICc>$(DQQQRQS$B@`@|(B\
$BcW$(DQh$BTtcicj$(DQqQr$B4Hcs$(DS)S*S+$B6NLb$(DSKSLSMSN$B5*5i5j9HLsd~e!e}f)$(DU&U'U(U)U*$BH~$(DU5UH(B\
$(DUKULUMUN$BBQ$(DUPUQU]$BLm$(DUtUuUvUwUyUzU{U|$B0_8UB[C@GXGYK&QIfpfqfrfsftfufvfw$(DVa$B2i(B\
$B=-$(DVl$BgLgM$(DVuVvWcWdWeWfWgWhWiWjWkWlWmWnWoWpWqWrWsWtWuWvWwWxWyWzW{W|W}$B0+0q(B\
$B1A7U9SApAqB{Cch!h"h#h%h&h'h(h)h*h+h,h-5T$(DZIZJZK$B0:Fz$(D\#$BjI$(D\*$B^'$(D\6\7\8$B6^CojR(B\
$BjSjUjVMW$(D]4]C]D]E$B7WD{k>DgIiIk5073$(DaGaHaIaJaKaLaM$B5UAwB`DIF(LBmompmqmrm~$(Da{(B\
$(Da|a}a~b!b"b#b$$B0j9YO:nD=E$(Dc$c%$BoY$(DfTfU$B8Boyozo{$(Dg7$BLL3Wpjpl2;JGIwHt?)<s9ark(B" ;9
   "$(D0.$B1(P+P8$(D1F1G1H1I1J1K1L1M1N1O1P1Q1R1S1T1U1V1W1X1Y1Z1[1\1]1^$B266f7p7q(B\
$B8D8u8v<Z=$ARCME]GPG\I6JoJpNQOAPaPbPcPdPePfPhPiPjPkPlPmPnPoY=E^7sQJ$(D2v2w(B\
$BL=QMQNQO$(D3!$B=Z@(C|E`N?QYQZ$(D3@3A3B3C3D3E3F3G3H$B5"7u9d:^GmK6QpQq$(D3i3j3k$BJYR'$(D4-(B\
$BF?H[$(D4J$B86$(D4_$BRW$(D5=5>5?5@5A5B5C5D5E5F5G5H5I5J5K5L5M$B0"0w14:6>%?0BoE/EbKiS'S((B\
$BS)S*S+S,S-S.S/$(D7#7$$BJ`S}$(D7e7f7g7h7i7j7k$BKdT1T<T=T>T?T@TB2FEeTxTya=$(D9N9O9P9Q(B\
$(D9R9S9T9U9V9W9X9Y9Z9[$B8d?1I1L<U.U/U0U1U2U3B9$(D:S:T:U:V:W:X:Y:Z$B1c2H325\:K>,(B\
$BMFUaUb<M>-Uq6}E8U~V!$(D;>;?;@;A;B$B2e=TEgJvJwV6V7V8V9V;:9$(D<,<-<.$B;U@JBS$(D<H<I<J(B\
$B8K:BDmW2$(D<l<m$B<e$(D<~=+$B=>=yELWM$(D=e=i=k=m=o=q=r=s=t=v=w=x$B1Y2862637C8g=zB)CQDp(B\
$BG:NxWkWlWnWsWyWzW{W}W~X!X"X#X$X%X&X'$(D?5?6$B@p$(D?W?`?d?e?f?g?h?i?j?k?l?m?n?o(B\
$(D?p?q?r?s?t?u?v?w$B0'5s7};+?6A\A^B*D=DrHTJaYMYPYQYRYT$(DAKALAM$BIRZC$(DAX$BNA$(DAe$BN9ZS(B\
$BZTZUZV4{$(DB1B2B3B4B5B6B7$B3"98;/;~?8ZgZhZiZj$(DBm$B=q$(DBq$BD?O/$(DCICJCKCLCMCNCOCPCQCR(B\
$(DCSCTCUCVCWCXCYCZC[C\C]C^C_$B0F3J3K3t3|4<5K6M7*7,7K7e9;:,:O:y;7<F@4@r@sEm(B\
$BG_I0Kq[Y[Z[[[\[][^[_[a[b[c$(DEjEkElEm$B;D<l=^;&]V$(DF;F<F=FMFNFO$B]e]f$(DG8G=G>G?G@(B\
$(DGAGBGCGDGEGFGGGHGIGJGKGLGM$B1:3=9@<r>C?;BYEsFBIMIbM0MaN.N^O2^1^2^3^4^5^6(B\
$B^7^8^:$(DIXIYIZI[I\I]I^I_I`$BNu_]_^___`$(DJLJNJaJb$BFC$(DJ{J|J}J~K!K"$BC,GbO5`E`F$(DKQKn(B\
$(DKoKpKqKrKsKtKuKvKw$B7><nHI`b`c`d`~$(DLrLsLyM%M7M8M9$B@&C\H+HJN1a;$(DMMMNMOMPMQMR(B\
$(DMS$B<@>I?>HhIBaPaQaRaTaUaVaW$(DN7N8$Bb(b.$(DNKNLNMNN$B1Wb4$(DN]N^N_N`NaNbNcNdNeNf$B??L2(B\
$BbAbBbCbF6k$(DOTOUOVOWOXOYOZO[O\$B5N9\EVEWGKK$bi$(DPYPZP[$B>Mc.$(DP|P}P~Q!Q"Q#Q$Q%Q&(B\
$B>N?AAECaGiHkc?c@cAcB$(DQTQUQVQWQX$B:ucX$(DQi$Bckclcm$(DQsQt$B5h>Pctcucvd$$(DS,S-S.S/$B?hJ4(B\
$BL0dcdd$(DSOSPSQSRSSSTSUSVSW$B9I:w;f<S=cAGG<I3J6KBLfe"e#e$$(DTkTl$Be~$(DTvTwTxTy$Bf*f+(B\
$(DU+U,$Bf6$(DU6U7$B2'fBfC$(DUJ$BfMfN9LLWfQfR$(DU^U_U`UaUb$BC?fVfW$(DUjU}U~V!V"V#V$V%V&V(V)$B6;(B\
$B6<:s;i@H@TF9G=L.OFfxfyg&$(DVc$BCW$(DVm$BgS$(DVw$B9RHLgUgVgd$(DW~X!X"X#X$X%X&X'X(X)X*X+X,(B\
$(DX-X.X/X0X1X2X3$B2.2Y2Z4PG|Migmgvh$h.h/h0h1h2h3h4h5h6h7h8h9h:h;h<h=h>hO$(DZ9(B\
$(DZ:$BiJ$(DZLZMZNZOZPZQZRZSZTZU$B2c;=GBiNiOiPiQiRiS$(D\$$BjH$(D\9\:\;\<\=\?\@$B?jB5HojOjP(B\
$BjWjXjYjZj[j\$(D]%]F]G]H]I]J]K$B5-71?VBwF$k?k@kA$(D^b^g$Bl1$(D^n^|$BI?l9$(D_)$B9W:b5/lb$(D_Z_[(B\
$Bm;$(D`Y`Z`[$B8.?+$(DaNaO$B0)?`@BB$B.C`DLD~ESF)GgO"msmtmumvmwmxmymzn%$(Db%b&b'b(b)b*(B\
$(Db+b,b-$B74n;n<n>$(DbV$B<`CqG[$(Dc&c'c(c)$B3x?KE#n[n\n]n^$(Df"$BA.$(DfVfWfXfY$B1!4Y9_=|?XJEo~(B\
$(Dfq$B@IH;GO9|9bqur(r.r/54N5(B" ; 10
   "$BX~_a3uAV$(D0<$B4%8#K#$(D1_1`1a1b1c1d1e1f1g1h1i1j1k1l1m1n1o1p1q1r1s1t1u1v$B56(B\
$B6v7r<EB&DdDeJPPpPqPsPtPuPvPwPxPyb6f{A>gNQK$(D3"3#$BIZQ`$(D3I3J3K$B>jI{QrQ{$(D3l3m$B4*(B\
$BF0L3R(pUR6R7$(D4$$B:"$(D4.4/45$BR?$(D494B4K$BRNRT$(D5N5O5P5Q5R5S5T5U5V5W5X5Y5Z5[5\5]5^5_(B\
$(D5`5a5b5c5d$B3e7<>&>'BCM#S0S1S2S3S4S5S6S7S8S9S:S;$(D7%7&$BS~T!T"$(D7l7m7n7o7p7q7r(B\
$(D7s7t7u7v7w7x7y7z7{7|7}7~8!8"$B0h4p:k<9>}BOD[F2G8G]IVKYTATCTDTm$(D8v8w8x8y8z(B\
$(D9\9]9^9_9`9a9b9c9d9e9f$B:'>+GLIXJZO,U4U5U6U7U8U9U:$(D:A:B$BUY$(D:[:\$B4s<d=IFRL)Uc(B\
$BUd0SUrUs$(D:w:x:y;C;D;E;F;G;H;I;J$B33:j?rJxV<V=V>V@VAVBVCVDVEVFVGAc$(D</<0$B>oD"(B\
$BVhVi$(D<K<L$B0C9/=nKcMG$(D<n$B6/D%W:WB:LD&I7$(D=,=-=.=/$BF@WOWPWQWR$(D=l=n=p=u=y=z={=|=}(B\
$(D=~>!>">#>%>'>(>*>+>,>->.>/$B0-0T459{;4>p@KEiFWM*W|X)X+X,X.X/X0X1$(D?*$B@LlCn=(B\
$(D?x?y?z?{?|?}?~@!@"@#@$@%@&@'@(@)@+@,@-@.@/@0@1@2@3@4$B1f3]5E7!7G7~95:C:N(B\
$B<N<x>9?d?x@\A<A]A_C5FhG1GSIAJ{N+YUYVYWYXYYY[Y\Y]Y^Y_Y`$(DANAO$B5_65GTZDZEZF(B\
$BZG<PZO;BCG$(DAfAgAh$B@{B2ZW$(DB8B9B:B;B<B=B>B?$B:|ZkZlZmZnZoZpZqAbRXK>[-$(DC`CaCbCc(B\
$(DCdCeCfCgChCiCjCkClCmCnCoCpCqCrCsCtCuCvCwCxCyCz$B04233#3a3q5t8h9<:->?DtEn(B\
$BHuIKM|NB[`[d[e[f[g[h[i[j[k[l[n[o[p[q[r[t[u$(DEn$BM_]7]8]K$(DF0F1$B3Lj^$(DF>$B]\]]$(DGNGO(B\
$(DGPGQGRGSGTGUGVGWGXGYGZG[G\G]G^G_G`GaGbGcGdGeGgGh$B0|1U363i7L:.:Q=B=J=_=m(B\
$B>D?<@6C8E:EqMdNCNT^;^<^=^>^?^@^A^B^C^D^E^F^G^H^I^J^K^L^M^N$(DIaIbIcIdIeIf(B\
$(DIgIhIi$B1k_X_b$(DJcJdJe$B`3`5$(DK#K$K%K'K)K*K+K,$BCvG-LTND`G`H`I`J`K`LN($(DKxKyKzK{K|(B\
$(DK}K~L!L"L#L$L%L&L'$B5e8=BvM}N0`f`ia!ISa)a*;:$(DM:$B0[7MI-N,a>a?a@CA$(DMTMUMV$B:/<&(B\
$BaSaXaYaZ;)b)$(DNO$B@9Epb5$(DNgNhNiNjNkNlNmNnNo$B4cD/bDbEbGbH$(DOGO]O^O_O`OaObOc$B:Vbk(B\
$(DP\P]P^$B:WI<$(DPsQ'Q(Q)$B0\$(DQYQZ$BAkCbcZ>Ocn$(DQuQvQwQxQyQzQ{Q|Q}Q~R!R"R#$B3^:{?ZBhE+(B\
$BIdcwcxcyczc{c|c}AFG4GtN3$(DSXSYSZS[S\S]S^S_S`Sa$B7P8>:0:Y=*>R?BAHD]N_e%e&e'(B\
$Be(e)e*e+$(DTmTzU-$Bf7f8f9$(DU8U9U:$B=,MbfD$(DUIURUSUT$BfS$(DUc$BfXfY=M$(DUxV*V+V,V-V.V/V0V1V2(B\
$(DV3V4$B5SC&G>fzf|f}E<$(DVxVyVz$B8?A%BIGugWgX$(DW+X4X5X6X7X8X9X:X;X<X=X>X?X@XAXBXC(B\
$(DXDXEXFXGXHXIXJXKXL$B0`2[5F6]8V:Z>T?{CxEQF:I)JnK(h?h@hAhBhChDhEhFhGhHhIhJ(B\
$BhKhLhMhN$(DZ;Z<Z=Z>$B5uQ]$(DZVZWZXZYZZZ[Z\Z]Z^Z_Z`ZaZb$B3B7V<XiTiUiViWiXiYi[$(D\%\+(B\
$B=QjJ$(D\>\A\B\C\D$B0A768SB^jQjTj]j_j`jajb$(D]&]'$B5,;kk,$(D]5]6]7]8]L]M]N]O]P]Q]R$B5v(B\
$B7m>Y@_K,LukBkCkD$(D^c$Bl.$(D^h^o^p^q^r$BFZ$(D^}$BlA2_4S@UHNIOlDlElIlJ$(D_F$B<O$(D_\_]_^$Blelflg(B\
$(D`N`O$B6m$(D`\`]`^$BE>FpmCmD$(DaPaQaRaSaTaUaVaWaXaY$B0o=5?JBam{m|m}n!$(Db.b/b0b1b2$B3T6?(B\
$BETItM9$(DbWbXbYbZb[$B?lnEnF<=<aLn$(Dc*c+c,c-c.c/c0c1c2c3c4c5c6f#$B6|D`KUn_n`na$(De~(B\
$BJDLdoZo[$(DfZf[$B1"81DDF+GfN&N4NMo|o}p!p"p#?}Ue$(Dfz$B<6@c$(Dg9$BpoD:$(DhHhI$B52qD5{D;sC</(B\
$BsNsPsQ2+9u:X55(B" ; 11
   "$Bq$$(D1w1x1y1z1{1|1}1~2!2"2#2$2%2&2'2(2)2*2+$B0N;1HwK5PzP{P|fE$(D2l$BA=C'$(D3$3%(B\
$(D3&3,$B3.3dAOQsQtQu$(D3n3o$B6P>!JgR)$(D4"$BGnmc6*$(D4L$B4g?_RORP$(D4X5e5f5g5h5i5j5k5l5m5n5o(B\
$(D5p5q5r5s5t$B4-4n5J6,6t7v9"A1ASC}S<S=S?S@SASBSCSDSESFSGSHSISJ$(D7'$B7wT#$(D8#8$8%(B\
$(D8&8'8(8)8*8+8,$B1a4.7x:f>lBDDMDiEHEcJ=JsN]TETFTHTNTft!TdTe$(D8h8{8|$B1|TzT{$(D9g(B\
$(D9h9i9j9k9l9m9n9o9p9q9r9s9t9u9v$BG^I2L;U;V#$(D:]:^$B4(6wIYUfUg$(D:i$B?RB:$(D:k$B1D$(D:s$B=":T(B\
$B<HB0EK$(D;K;L;M;N;O;P;Q;R;S;T;U;V$BMrV?VHVIVJVK=g$(D<1$BI}K9VjVkVlVs4v$(D<M<N<O$BGQO-(B\
$BVzV{W6$(D<o<p<q$B4!CFI+$(D<y$B?\WE$(D=0=1=2$B8f=[I|WS$(D>$>&>)>0>1>2>3>4>5>6>7>9>:>;><>=(B\
$(D>>>?>@>A>D>E>F$B92<fAZBFHaL{OGW\X(X*X3X5X7X8X9X:X;X<X=X?7aY!Hb$(D@*@5@7@8@9(B\
$(D@:@;@<@=@>@?@@@A@B@C@D@E@F@G$B0.1g494x>8B7DsEkM,MHMIYZYaYbYcYdYeYfYgYhYi(B\
$(DAPAQAR$B4:7I;6FXZHZIHCHeIL$(DA\A`$B;[$(DAiB@BABBBCBDBEBFBGBHBIBJBKBL$B6G7J=k>=@2CR(B\
$BHUIaZrZs:GBX$(DBrBs$B4|D+[.$(DC{C|C}C~D!D"D#D$D%D&D'D(D)D*D+D,D-D.D/D0D1D2D3D4(B\
$(DD5D6D7D8D9D:D;D<$B0X4=4}8!?"?9?z@3C*DGEoK@L:LI[s[v[w[x[y[z[{[|[}[~\!\"\#(B\
$B\%\&\'\(\)\*\+\,\-\.\/\0\1\2$(DEoEp$B4>5=6V]:$(DE{F$F%$B?#]L]M$(DF2$B]WH|$(DF?$B]^]_$(DFPFQGf(B\
$(DGiGjGkGlGmGnGoGpGqGrGsGtGuGvGwGxGyGzG{G|G}G~H!H"H#H$H%H&H'$B0/12298:8P9A(B\
$B<"<>>EB,C9EOErJ%K~L+M/OQRE^O^P^Q^R^S^T^U^V^W^X^Y^Z^[^\^]^^^_^a^b^c$(DIjIk(B\
$(DIlImInIoIpIq$B<Q>F>GA3J2L5_c_d`*LlGW`0$(DJWJfJg$B`4`6$(DK&K(K-K.K/K0K1K2K3K4$BM1`M(B\
$B`N`O`P$(DL(L)L*L+L,L-L.L/L0L1L2L3L4L5L6$B1M6WGJNV`h`j`k$(DLzL{L|M&$B1ya4$(DM*M;M<$B>v(B\
$BHVaAaBaGAAAB$(DMWMXMYMZM[M\M]$BDKEwN!a[a\a]EPb$$(DN9$Bb*b+b/$(DNP$B]9$(DNpNqNrNsNtNuNv$BbI(B\
$(DOBOCOH$BC;$(DOdOeOfOgOhOiOjOkOl$B8'9E>KH#N2bm$(DP_P`$BExO=c2c3$(DQ*Q+Q,Q-Q.Q/$B5)@GDxcC(B\
$BcD$(DQ[$BcYc[c\=WF8cocp$(DR$R%R&R'R(R)$B6Z:vC^EyEzE{H&H5I.c~d"d#d%d&d8$(DS0S1$B>Qdedf(B\
$Bdgdhdidj$(DSbScSdSeSfSgShSiSjSkSlSm$B0<3(5k7k9J;g@dE}Mme,e-e.e/e0e1e2e3$(DTnTo(B\
$(DT{T|T}U.U/$BCefFfO$(DUUUd$BfZ$(DV'V5V6V7V8V9V:V;V<$B9PD1OSf~g"g#g$g%$(DVdVgVhViVn$BP0$(DXM(B\
$(DXNXOXPXQXRXSXTXUXVXWXXXYXZX[X\X]X^X_X`XaXbXcXdXeXfXgXhXi$B0*013k3~ArF!G#(B\
$BG,GkIrIxMUMnN*hRhWhXhYh[h\h]h^h_h`hahbhd$(DZ?ZcZdZeZfZgZhZiZjZkZlZm$B3?H:HZ(B\
$BIHi\i]i^i_i`iaib$(D\&\'$B=0$(D\,\-$B39$(D\F\G\H\I\J\L\N$B:[AuJdM5N#Nvje0@k)$(D]($B3PGAk-k8(B\
$Bk:$(D]S]T]U]V]W]X]Y]Z][]\]]]^]_]`]a]b]c$B1S:>;l>Z>[?GAJBBCpI>kEkFkGkHkIkJ>](B\
$Bl:$(D_*_+$B2l5.B_CyE=GcHqKGLclFlHlLl_$(D_J_K_L_M$B1[D6lc$(D___`_a_b_c_d_e_f_g_h_i$B5w(B\
$Blhliljlklllm$(D`P$Bm<$(D`_```a`b`c$B7Z<4mEmFmG$(Da-aZa[a\a]$B1?2a6x?kC#CYF;F[I/JWM7MZ(B\
$Bn"n#n$n&n'n($(Db3b4b5b6b7b8b9$Bn?$(Db\b]$B?]nGnHnfnXNL$(Dc7c8c9c:c;c<c=c>c?c@cAcBcC(B\
$(DcDcEcFcGcHcIcJcKcL$B3CF_nbncndnengoO$(Df$f%f&$B1<3+4V4WLeo\o]$(Df\f]f^f_f`fafbfc(B\
$(Dfd$B3,6y7(?oBbM[p$p%8[=8M:p4$(Df{f|$B1@J7$(Dg:$B?YpVpW$(Dg^gs$B9`$(DhJhKhL$BqGqH$(DinkY$BsR5Psc;u(B" ; 12

   "$BP,P9cH$(D2,2-2.2/20212223242526$B6O6Y797f:D=}ANF/L|MCP}P~Q!Q"Q#Q$@yM2UZ(B\
$BgO$(D3L$BQvQw$(D3p3q3r$B4+@*R*R+R-$(D4#$BprR;$(D4M4N4O$B19$(D4`5u5v5w5x5y5z5{5|5}5~6!6"6#6$6%(B\
$(D6&6'6($B2^;LC2SKSLSMSNSOSPSQ$(D7(7)$B1`T$T'$(D8-8.8/8081828384858687$B1v2t:IA:E6EI(B\
$BEdH9JhTITJTKTMTg$(D8i$BL4>)T|$(D9w9x9y9z9{9|9}9~:!:":#:$$B2G7y<;U<U=U>U?U@UL$(D:_:`(B\
$(D:a:b:c$B42?2$(D:l$BUva3aD$(D:t;W;X;Y;Z$B:7?sVLVMVN$(D<2<3<4$BKZKkVm44$(D<P<Q<R$BNwV|$(D<r$BW;WC$(D=3(B\
$(D=4=5$BHyWT$(D>8>B>C>G>H>I>J>K>L>M>N>P>Q>R$B0&0U34466r;|=%?5A[X2X4X6X>XAXCXDXF(B\
$BXHXIXK$(D?+?,?-$B@oY"$(D@6@H@I@J@K@L@M@N@O@P@Q@R@S@T@U@V@W@X@Y$B7H:E:q@]B;HBYSYj(B\
$BYlYmYnYoYqYrYs$(DAS$B?t$(DAY$BZP?7ZX$(DBMBNBOBPBQBR$B0E2KCHZtZuZvZwZxPr$(DBtD=D>D?D@DADB(B\
$(DDCDDDEDFDGDHDIDJDKDLDMDNDODPDQDRDSDTDU$B3Z4~6H6K:g=]BJDHDXFNFjFoG`IvMLO0(B\
$BO1\$\3\4\5\6\7\8\9\:\;\<\=\>\?\@\A\B\C\D$(DEq$B]<]=:P$(DF&F3$BEBTL$(DF@FAFRH(H)H*H+(B\
$(DH,H-H.H/H0H1H2H3H4H5H6H7H8H:$B0n3j4A8;9B=`BZBlE.GyLGMON/Nz^d^e^f^g^h^i^j(B\
$B^k^l^m^o^p^q^r$(DIrIsItIuIvIwIxIyIzI{I|I}I~J!$B1l>HGaHQN{_e_f_h_i_j_k_l=X$(DJO(B\
$(DJQJRJS$BD-$(DJhJiK5K6K7$B1n8%;b`Q$(DL7L8L9L:L;L<L=L>L?L@LA$B8j?p`l`m`n`o`p`q`v$(DL}M=(B\
$(DM>$BFmaCA?$(DM^M_M`MaMbMcMdMeMf$BCTa^a_a`aaabacadaeb,$(DNQ$BLAb7$(DNwNxNyNzN{N|N}N~O!(B\
$(DO"O#O$$B?gFDKSbJbKbLbMbN$(DOD$Bbd$(DOmOnOoOpOqOrOs$B10378k:lDvORblbnbobpbq$(DPaPbPcPd(B\
$(DPePfPgPh$B2R6XA5DwJ!c4cI$(DQ0Q1Q2Q3Q4$BCUI#L-NGcEcFcG$(DQ\Q]$B7"$(DQjQkQlR*R+R,R-R.R/(B\
$(DR0R1R2R3$B@ad!d'd(d)d*d+d,d-d.$(DS2S3$Bdkdldmdn$(DSnSoSpSqSrSsStSuSvSwSxSySzS{S|(B\
$(DS}$B7Q8(B3e4e5e6e7e8e9$(DT~$B7S:a=pCVf,f-f.if$(DU0U1$B5A72A"f:$(DU;$BfT@;f[fgfi$(DV=V>V?V@(B\
$(DVAVBVCVD$B9x<p?UA#B\D2J"g'g(g)g*g+g5$(DVj$BgP$(DVtV{V|V}V~$BDzgY$(DXjXkXlXmXnXoXpXqXr(B\
$(DXsXtXuXvXwXxXyXzX{X|X}X~Y!$B383w<,=/>U>xAsC_IGL,LXMVhPhShThUhZhchehfhghh(B\
$Bhihjhkhlhmhnhohp6sN:iK$(DZnZoZpZqZrZsZtZuZvZwZxZy$B2kK*icidieigihiiijikilim(B\
$(D\.$BjK$(D\E\K\M\O\P\Q\R\T$B3l:@?~MgN"jcjdjfjhjijkjljmlK$(D])]*]9$B2r?(k9k;$(D]d]e]f]g(B\
$(D]h]i]j]k]l]m]n]o]p]q$B3:5M7X8X;m;n>\@?A'M@OCOMkKkLkMkNkOkPkQ$(D^i$BK-$(D^s^t^u$Bl6(B\
$(D^~_!$Bl;l<l=$(D_,_-_._/$B;qA(B1DBO(OElGl\$(D_G_N_O_P_j_k_l_m_n_o_p_q_r$B8Y@WA)D7O)(B\
$Blnlolplqm>$(D`d`e`f`g`h$B3S:\mHmImJmR$(Da.$B<-mdG@$(Da^a_a`$B0c1s8/ALB=O!n)n*t#$(Db:b;b<(B\
$(Db=b>$Bn@$(Db^b_$B=7MonI1t$(DcMcNcOcPcQcRcScTcUcVcWcXcYcZc[c\c]c^c_c`cacbcccdcecf(B\
$(Dcgchcicjckclcmcn$B8Z9[>`E4H-Nknhninjnknlnmnonpnqnvfh$(Df'f(f)$Bo^o_o`$(Dfefffg$B3V(B\
$B7dg!p&$(Dfr$B2mp3p5p6$(Df}$BEEMkNmp;$(Dg2$BLw$(Dg;g<g=g>$B7$pX$(Dgo$Bpq$(Dgtgugvgw$B4hF\HRMBps$(Dh:hM$B0{(B\
$BHSR,];q+q,$(Dh{h|h}h~$BCZFk$(DiViWiX$Bqlqv$(Dj9j@jA$BH7rjrlro$(Dl\l]$BsFsfE$$(Dm*$B8]AM(B" ; 13
   "$(D2728292:2;2<2=2>2?2@2A2B2C2D2E$B6#A|KMN=Q%Q&Q'Q(Q)Q*Q>$(D2o$BQP$(D3'3-3.$BK1$(D3M(B\
$(D3N$B3D$(D3s3t3u$B5?$(D4041$BR<061^RQRR$(D6)6*6+6,6-6.6/60616263$B2EA9LDSRSSSTSUSVSWSXT%(B\
$BT&$(D88898:8;8<8=8>8?8@8A8B8C8D8E8F$B6-=N?PA}KOTGTOTPThTk$(D8j$BTn$(D8}$BC%T}T~$(D:%:&:'(B\
$(D:(:):*$BCdUAUBUCUDUEU[$(D:d$B2I;!G+L*UhUiUjUkUl\MUt>($(D:z:{$BAX$(D;[;\;];^;_;`;a;b;c(B\
$(D;d;e;f;g$BEhV:VOVPVQ$(D<5<6<7<8<9$BVnVo$(D<S<T<U<V<W$B3GV}V~W!FP$(D<s<t=!$B>4$(D=6$BD'FA$(D>O>S(B\
$(D>T>U>V>X>[>\>^$B47A~BVJiK}X@XBXEXGXJXLXMXNXPXRXSXTXUXVXXXY$(D?.?/?0$BY#$(D@Z@[@\(B\
$(D@]@^@_@`@a@b@c@d@e@f@g@h@i@j@k$B@"DOE&LNYkYtYvYwZJ$(DA]AjAk$B4z$(DBSBTBUBVBWBX$BD*(B\
$BJkNqZy$(DBnBuDVDWDXDYDZD[D\D]D^D_D`DaDbDcDdDeDfDgDhDi$B1]353r9=?:AdKjLOMM\E(B\
$B\F\G\H\I\J\K\L\N\O\P\Q\R\S\T\U\V\W\X\Y\ct"$(DErEs$B2N]>$(DE|$BNr$(DF'$B]N$(DF4F5$B]Z$(DH9H;H<(B\
$(DH=H>H?H@HAHBHCHDHEHFHGHHHIHKHLHMHNHOHPHQHR$B1i4C5y9w<?A2AfDRE)I:L!O3^`^t(B\
$B^v^w^x^z^{^|^}^~_!_"_#$(DJ"J#J$J%J&J'$B7'@zMP_g_m_o_p$(DJJ$B<$$(DJTJj$B`7`8$(DK8K9K:K<$B9v(B\
$B`S$(DLBLCLDLELFLGLHLILJ$B:<M~N\`g`s`t`ut$a+a,a-$(DM'M?M@MAMgMhMiMjMkMlMmMnMo$Baf(B\
$Bagah?|b0b1b8$(DO%O&O'O(O)O*O+O,$BbObPbQ$(DOtOuOvOwOxOyOzO{O|O}O~$B<'@YHjJKbrbsbt(B\
$Bbu$(DPiPk$Bc5$(DQ5Q6Q7Q8Q9$B0p9r<ocJ$(DQ^$B7&c]$(DQm$BC(C<cqcr$(DR4R5R6R7R8R9R:R;$B2U4I;;GsJOL'(B\
$Bd/d0d1d2d3d4d5d6d7d9d=$(DS4S5S6S7S8S9$B@:dodpdq$(DS~T!T"T#T$T%T&T'T(T)T*T+T,T-(B\
$(DT.T/T0$B0=0]9K<z=oAmAnC>DVHlLJLVNPN}e:e;e<e=e>e?e@eBeCeEeFeGen$(DU!$BH3$(DU<U=$B?i(B\
$(DUV$BAof\f]f^$(DUk$BH%$(DVEVGVHVIVJVK$B9QIeKlg,g-g.g/g0gJ$(DVpVqW!Y"Y#Y$Y%Y&Y'Y(Y)Y*Y+(B\
$(DY,Y-Y.Y/Y0Y1Y2Y3Y4Y5Y6Y7Y8Y9Y:Y;Y<Y=Y>Y?$B0~16<CDUJNK)L"hqhrhshthuhwhxhy(B\
$(DZ@ZAZzZ{Z|Z}Z~[!["[#[$[%[&['[([)[*[+[,[-$BCXO9inioipiqirisit$(D\S\V\W\Y\Z\[(B\
$(D\\\]\^\_$B>X@=J#jgjnjojpj|$(D]+],$Bk.$(D]:];]r]s]t]u]v]w]x]y]z]{$B8l8m;o@@@bFIG'M6(B\
$BkRkSkTkUkVkWkX$(D^d^v^w$B9k$(D_"$BKFl>$(D_0_1_2$BFx3R$(D_Q$Bld$(D_s_t_u_v_w_x$BMYlrlsltlu$(D`Q`i`j(B\
$BJemKmLmN$(Da/$Bme$(Daaabacad$B<WAxE,n+n,$(Db?b@bAbBbCbDbEbF$BnA$(Db`babbbc$B9Z9s;@nJnK$(Dcocp(B\
$(Dcqcrcsctcucvcwcxcyczc{c|c}c~d!d"d#d$d%d&d'd(d)$B6d=F={A,A-D8F<KHLCnnnrns(B\
$Bntnu$(Df*f+f,$B3U4X9^H6J9oaob$(Dfhfi$B1#:]>cp'p(p)$(Dfs$B;(;s<{$(Dg3g4$B@EfGjjpR$(Dg?g@gAgB$B3s(B\
$BpYpZp[p\p]$(Dg_g`gp$Bpp$(Dgxgy$B7[NN$(Dh;h<h=$Bq%q&$(DhNhO$B0;;t>~K0$(Dhwhxi!i"i#i$i%$B1X6nBLG}(B\
$BqI$(DiY$Bqm$(Dioipiqir$BH1qwqx$(Dj0$B3!:2$(DjBkZ$BVwsiI!i5sn(B" ; 14
   "$BfI$(D2F2G2H2I2J2K2L2M2N2O2P$B2/57JHJ^Q+Q,Q-Q.Q/Q[$(D3O3P$B7`N-QxQ|$(D3v3w$B7.pupv(B\
$BR=$(D4P6465666768696:6;6<6=6>6?6@6A6B6C6D6E6F6G$B131=3z4o>|J.SYSZS\S]S^S_$(D7*(B\
$(D8G8H8I8J8K8L8M8N$BDFJ/TQTRTSTWTX$(D8~:+:,:-:.:/:0$B4rUFUGUHUI?3N@UmF3$(D:u:|$BMz$(D;h(B\
$(D;i;j;k;l;m;n;o$BVRVSVW$(D;~<:$BH(J>VpVqVr5&$(D<X<Y$B>3I@W"W#W$W%W&W']`J@$(D<u$BW<1F$(D=7$BE0(B\
$(D>W>Y>Z>]>`>a>b>d>e>g>k>l$B0V7D7EF4J0M+M]N8NyXOXQXWX\X]X^X_XbXc5:Y$$(D@l@m@n(B\
$(D@o@p@q@r@s@t@u@v@w@x@y@z@{$B3I7b;#;5@qE1F5G2GEIoKPK`YuYyYzY{Y|Y}$(DAT$BE(I_ZK(B\
$(DBYBZB[B\B]B^B_B`Ba$B;CK=$(DDjDkDlDmDnDoDpDqDrDsDtDuDvDwDxDyDzD{D|D}$B2#3_8">@(B\
$BAeCtDPI8\Z\[\\\]\_\`\a\b\d\e\f\g\h\i\k\l\n\s\x$(DEt$B4?C7]?$(DE}F(F)$B]O5#]X$(DFBFC(B\
$(DHJHSHTHUHVHWHXHYHZH[H\H]H^H_H`HaHbHdHeHfHgHhHiHjHkHlHm$B3c4B7i=a@!@xD,DY(B\
$BH.^n^s^y_$_%_&_'_(_)_*_,_-_._/_0_1_3_L$(DJ(J)J*J+J,J-J.J/$B1m=OG._q_r$(DJPJUJV(B\
$(DJkK;K>K?K@KA$B`R`U$(DLKLLLMLNLOLPLQLR$B`r`w`x$(DL~$Ba0$(DMBMEMpMqMrMsMtMuMvMwMx$BAiaiaj(B\
$Bakalaman$(DN:N;N<$Bb-b24FHW$(DO-$BbRbSbT$(DP!P"P#P$P%P&P'P(P)P*P+P,P-$B3NHXbvbwbxbybz(B\
$Bb{b|b}$(DPjQ:Q;Q<Q=Q>Q?$B2T9FJfcKcLcMcN$(DQ_Q`$B5gMRc_cc$(DR<R=R>R?R@RARBRCRDRERFRG(B\
$(DRHRIRJRK$B@}H"H$HOJSd:d;d<d>d?$(DS:S;S<S=S>$B8RA8drds$(DT1T2T3T4T5T6T7T8T9T:T;T<(B\
$(DT=T>$B1o4K6[@~DyFlJTLKeDeHeIeJeKeLeMeNeOHmf/$(DU2$Bf;f>$(DU>U?U@$B4efH$(DUWUeUf$Bf_$(DVLVM(B\
$(DVNVOVP$BI(Ifg1g2g3g4g6gI$(DVe$BgTIq$(DW"W#W$Y@YAYBYCYDYEYFYGYHYIYJYKYLYMYNYOYPYQ(B\
$B6><I>VB"F"HYIsJCOOhQhvhzi#i$$(DZB[.[/[0[1[2[3[4[5[6[7$B2\?*@fD3Ghiuiviwixiy(B\
$Bizi{i|i}i~j!j"j#$(D\/\0$B>W$(D\U\X\`\a\c\f$BK+jrjsjtju$(D]-]<]|]}]~^!^"^#^$^%^&^'^((B\
$(D^)^*^+^,^-^.$B1Z2]5C=t?[@ABzC/CBCLD4HpNJO@kYkZk[k\k]$(D^e$Bl2l?$(D_3_4_5_6_7$B;?;r(B\
$B<A>^GeIPIjlMlNlO$(D_H_R_S_T$B<q$(D_y_z_{_|_}_~`!`"`#$BF'lvlwlxlym)$(D`R`S`k`l`m`n`o(B\
$(D`p`q`r`s`t`u$B51GZNXmMmOmPmQmS$(Da0aeaf$B0d=eA*A+NKn-n/$(DbGbHbIbJbK$BE"nBnC$(Dbdbebf(B\
$(Dbgbh$B=fnLnMnN$(Dd*d+d,d-d.d/d0d1d2d3d4d5d6d7d8d9d:d;d<d=d>d?d@dAdBdCdDdEdF(B\
$(DdGdHdIdJdKdLdMdNdO$B1TCrIFJ_K/nwnxnynz$(Df-f.f/$B1\oc$(Dfjfkf~g!g"g#$B?LNnp<p=p>$(Dg5(B\
$BpQ$(DgC$B0Hp^p_p`$(Dgagbgmgzg{g|g}g~h!$BKK$(DhPhQhR$B1BL_M\q-q.$(Di&i'i(i)i*i+i,$B2o6o6pCs(B\
$BqJqKqLqMqN$(DiZi[i\i]ilisitiu$Bqyqzq{q|q}r)L%r0r1$(DjCjDjEjFjGjHjIjJjKjLjMjNjO(B\
$(DjP$BO%r7$(Dk[k\k]k^$B2*F>rmrnrprq$(Dl^l_li$B9msOsUL[$(Dm&m'm($Bso(B" ; 15
   "$BP.$(D2Q2R2S2T2U2V2W2X$B4\<tPVQ0Q1Q2Q3QCZ*QQ$(D3($B6E$(D3Q3R$BQyQzQ}R.pw1C$(D6H6I6J6K(B\
$(D6L6M6N6O6P6Q6R6S$BFUH8S`SaSbScSd$(D7+$BT($(D8O8P8Q8R$B2u:&>mCEJITTTY$(D8c9!$BJ3$(D:1:2:3:4(B\
$(D:5:6$B>nUJU\$(D:e$BUn$(D;p;q;r;s$BVTVU$(D<;<Z$BW(W)60$(D<z$BW4WU$(D>_>c>f>h>i>j>m>n>p>q>r>s>t$B21(B\
$B2{487F7{XZX[X`XaXdXeXhXjXkXnY%$(D@|@}@~A!A"A$A%A'A(A)A*$BA`MJY?Y~Z!Z"Z#Z$Z%(B\
$BZ'$(DAU$B@0$(DAZAaAb$BZZ$(DBbBc$BF^ZzZ{Z|Z}Z~[!["$(DD~E!E"E#E$E%E&E'E(E)E*E+E,E-E.E/E0E1(B\
$(DE2E3E4E5$B5!5L66<y>AC.FK\m\o\p\q\r\t\u\v\w$(DEuEv$B]@]A$(DF*$B]P]Q$(DFDFEHcHnHoHpHqHr(B\
$(DHsHtHuHvHwHxHyHzH{H|H}H~I!I"I#I$I%$B7cByECG;_2_4_5_6_7_8_9_:$(DJ0J1J2J3J4J5(B\
$(DJ6J7J8J9J:J;$BEuG3NU_s_t_u_v_w_x_y$(DK=KBKCKDKEKF$B3M=C`V`W$(DLSLTLULVLWLXLYLZL[(B\
$(DL\$B`e`yI;9ya.a/<2aJ$(DMyMzM{M|M}M~N!N"N#$Baoapaq$(DN=N>NR$Bb9b:$(DO.O/O0O1O2O3O4$BbUbV(B\
$(DP.P/P0P1P2P3$BKab~c!c"$(DPlPmPn$B5zc6c8$(DQ@QAQBQC$B0,1O2:7N@Q$(DQaQbQc$B1.c`$(DQn$BpP$(DRLRMRN(B\
$(DRORPRQRRRS$B<DC[FFO6d@dAdBdDdE$(DS?S@SASBSC$BE|dtdu$(DT?T@TATBTCTDTETF$B0^<J=DG{HK(B\
$BK%ePeQeReSeUeVeWeX$(DTp$BGMXmf<$(DUAUB$B4MfU$(DUgVFVQVRVS$BA7KDg7g8g9$(DVf$BgK6=$(DW%W&$BgZg[$(DYR(B\
$(DYSYTYUYVYWYXYYYZY[Y\Y]Y^Y_Y`YaYbYcYdYeYf$B1r70?EA&FeGvIyLtLyhVh{h|h}h~i!(B\
$Bi%i&i'i(i)i*i+i,i-i/i0i1i2i3j1$(DZCZD[8[9[:[;[<[=[>[?[@[A[B[C[D[E[F[G[H[I(B\
$(D[J[K$BB}M;Mfj%j&j'$(D\1\2$B1R9UjL$(D\b\d\e\g\h\j\k\l$Bjvjyjz?Fk/k0$(D]=^/^0^1^2^3^4^5(B\
$(D^6^7$B0b4R8A;pD5D|FfKEM!MXk^k_k`kakbkckdkekfkgkkl3$(D^x$Bl7$(D_#_$_%_8_9_:_;$B8-ER(B\
$BMj$(D_I$Bl`$(D_U`$`%`&`'`(`)`*`+`,$BD}lzl{l|l}m?$(D`v`w`x`y`z`{`|$B=4M"mTmUmV$(Da1a2$BQ~R!(B\
$(Dag$B4THrn.n0n1n2n3$(DbLbMbNbibjbkblbm$B8o@CBi$(DdPdQdRdSdTdUdVdWdXdYdZd[d\d]d^d_(B\
$(Dd`dadbdcdddedfdgdhdi$B5x6S9]:x;,<b>{?m?nIEO#O?n{n|n}n~o!o"o#o$o%o&o'$(Df0f1(B\
$(Df2f3$Bodoeofog$(Dflfm$BNYp*Nl$(Dft$Bp:p9p?p@pApBpC$(Dg6$BpS$(DgDgEgFgG$B>d$(Dgqh"h#h$h%h&h'h($B1P(B\
$B3\F,ptpx$(Dh>hShThUhV$B2n;Aq/q0q1$(Dhyi-i.i/i0i1$BqOqPqQqRqX$(Di^i_$B3<qn$(Diviwix$BI&q~r!(B\
$Br*$(Dj3jQjRjSjTjUjVjWjXjYjZj[j\j]$B0>J+r8r9r:r;r<$(Dk_k`kakbkckd$B1u2)3{rrrsrurv(B\
$Brxry$(Dl`la$BsG$(Dljlk$BLM$(Dlqlt$BBc`TsX$(Dm)m<m=mE$BN6(B" ; 16
   "$BiL$(D2Y2Z2[2\$B=~M%Q4MA$(D3S3x3y$BR/$(D426T6U6V6W6X$B3E87SeSfSgSiSj$(D8S8T8U8V8W8X$B9h(B\
$BTVTZT[T\$(D:7:8$B1ED\UKUMUNU^$(D:f$Bm!lP$(D:v:};t;u$BNfVVVXVY$(D<<<=<>$BW=5+$(D>o>v>w>x>z>{>|(B\
$(D>}$B:)XfXiXlXoY&$(DA#A&A+A-A/A0$B5<;$E'Z&Z(Z)Z+Z,Z.Z/$(DAV$BZL]B$(DA^AcAlBdBeBf$B[#$(DE6E7(B\
$(DE8E9E:E;E<E=E>E?E@EAEBEC$B3`8iCI[X\y\z\{\|\}\~]!],$(DEwF+F,F-F.$BmX$(DF9FF$B]a$(DI&I'(B\
$B9c9jBuG(^9_;_<_=_>_?_@_A_Boi;8?$AgRYS[_z_{_|_}<_`/5>$(DKGKHKI$B`X$(DL]L^L_L`La(B\
$(DLbLcLdLeLf$B4D$(DM!N$N%N&N'N(N)N*$B4bNEarasat$(DN?N@NANBNS$Bb;$(DO5O6O7O8O9O:$BF7JMNFbW(B\
$BbXbY$(DOI$B6:$(DP4P5P6P7P8P9P:P;$B0k>Lc#c$$(DPo$Bc9$(DQDQEQFQGQHQI$BKTcOcP3v$(DQoRTRURVRWRXRY(B\
$(DRZR[R\R]R^R_R`RaRbRcRdReRf$BRUdCdGdHdIdJdKdLdMdN$(DSDSESFSG$B9GAlJ5dvdw$(DTGTHTI(B\
$(DTJTKTLTMTNTOTPTQ$B=+=L@SA!eAeTeYeZe[e\e]e^e_e`ea$(DTq$Bf!$(DU"U$UC$BMcfJ$(DUXUh$BD0N~f`(B\
$Bfafb$(DVTVVVWVX$B22G?g:g;g<g=g>g?g@gEg\g]ge$(DYgYhYiYjYkYlYmYnYoYpYqYrYsYt$B;'=r(B\
$BONi4i7i8$(D[L[M[N[O[P[Q[R[S[T[U[V$Bj(j)j*j+j,j-j.j/j0j2j3$(D\i\m\n\o\p\q$Bjqjwjx(B\
$Bj{p7Mwk1k2$(D]>^8^9^:^;^<^=^>^?$B6`8,9V<UF%khkikjklkmknkol/l0$(D^j^y$Bl@$(D_<_=_>$B9X(B\
$BlQlR?v$(D`-`.`/`0$Bl~m"m#m$m%$(D`}`~a!$B3mmWmY$(Dah$Bcdmnn5$(DbObnbobp$B=9>_nO$(Ddjdkdldmdndo(B\
$(Ddpdqdrdsdtdudvdwdxdydzd{d|d}d~e!e"e#e$e%e&$B7-80>aCCDJDWEUFio(o)o*o+o,$(Df4(B\
$(Df5f6f7$B0Gohojokol$(Dfnfo$Bp+p,p1$(Dg$g%g&g'$B2bAzpD$(DgHgIgJ$B5Gpa$(Dgc$B4Z$(Dgnh)h*h+h,$BIQpy$(Dh?(B\
$Bq'$(DhWhXhYhZh[h\h]$B4[q2q3q4q5q6qE$(Di2i3i4i5i6i7i8$B=YqSqTqU$(Di`iyizi{i|i}j4j:j^(B\
$(Dj_j`jajbjcjdjejfjg$B:z;-A/Knr=r>r?r@$(Dkekfkgkhkikjkkklkmknkokp$Brwrzr{r|r}r~(B\
$(Dlb$BsH$(Dlllmlr$BsVsYsZs[sd$(Dm"m1m>$Bsmc7Npsps~(B" ; 17
   "$(D2]2^2_$BLYAQ$(D6Y6Z6[6\6]6^$BShT]T^fK$(D8d:9:~<?<@<[$BK{$(D<v$BW3$(D>u>y>~?"$BD(XpXsBWY'(B\
$(DA,A.A1A2A3A4A5A6A7A8A9$B>qZ1Z2Z3Z4Z6Z9ZMZRZY$(DBgBh$B=lMK[$[/$(DEDEEEFEGEHEIEJEK(B\
$(DELEM$B6{[m\j]#]$]%]&]'](]C]E]R$(DF6I(I)I*I+I,I-I.I0I1$BCuMt_C_D_E_F_G_H_I$(DJ<J=(B\
$(DJ>$B_n_~`!`"$(DKJ$B`Z$(DLgLhLi$B`za1a2$(DMCMDN+N,$BJJL~auav$(DNCNDNENHNTO;$B=VbZb[b\b]$(DP<P=P>(B\
$BACc%c&c'$(DPp$BG)$(DQJQKQLQM$B3O>wcQcRcacb$(DRgRhRiRjRkRlRm$B4JC=dOdPdQdRNH$(DTRTSTTTUTV(B\
$(DTWTXTY$B?%A6Kzebecedeeefeg$(DTrU#$Bf0$(DU3UD$BK]$(DUYUi$B?&fc$(DVYVZ$BgAgBNWgQ$(DVrW'$Bg^$(DYuYvYwYx(B\
$(DYyYzY{Y|$B=sF#HMMui.i6i9i:i;i<$(D[W[X[Y[Z[[[\[][^[_[`[a[b[c[d$Bj4j5j6j=$(D\r\s\t(B\
$(D\u\v\w$B2(6_j}J$$(D].$B4Qk3k<$(D^@^A^B^C$BI5kpkrksktkul4$(D^z_&$BlB$(D_?_@_A$BB#lSlT$(D`1`2`3`4(B\
$(D`5`6`7$B@Xm&m'm(m*m+$(D`T`Ua"$BmZm[m\$(Daiaj$Bn4$(DbPbQbRbqbrbs$BnPnQnRnZ$(De'e(e)e*e+e,e-(B\
$(De.e/e0e1e2e3e4e5e6e7e8e9e:e;$B3;3y:?AyDCo-o.o/o0o1$(Df8f9f:f;f<f=$BF.omonoo$(Dfp(B\
$Bp-p.$(Dfufvfwfxfy$B?wFqN%RVp8$(Dg(g)$BpE$(DgKgLgM$BJ\kqpbpcpd$(Dgdgegfgrh-h.h/$B3[4i82BjN`(B\
$Bpzp{$(Dh@hAh^h_h`hahb$Bq7q8qF$(Di9i:i;i<i=$B5383A{qVqW$(Diaib$Bqo$(Dimi~j!j"j#$Br"r+$(Dj5j;j<(B\
$Br2r3r4$(Djhjijjjkjljmjnjojpjqjr$B8qrArBrCrDrErFrG$(Dkqkrksktkukvkw$B1-9ts!s"s#s$(B\
$Bs%s&$(Dlc$BsI$(Dlslu$Bs\$(Dm#$Bsj$(Dm2m3m4$Bsl$(DmF$Bs}(B" ; 18
   "$(D2`2a2b3T3z4Q$B4f$(D6_6`6a6b6c6d6e$BSkSl$(D8Y8Z8[8\$BTUT`TbUO$(D:C:g$BC~Up$(D;v<A$BW*$(D?!?#(B\
$BXgXq$(DA:$BZ5Gx[%$(DENEOEPEQERESETEU$BO&])]*]+]-$(DExF/$B]T$(DI/$B@%BmFTIN_+_J_K_M_N$(DJ?J@JA(B\
$BGz`#`1`9$(DKK$B`Y`\$(DLjLk$B<%`{a"$(DM"$BaEaF$(DN-$Baw$(DO<O=O>$Bb^$(DOJP?P@PAPBPCPD$Bc(cS$(DQdRnRoRpRq(B\
$(DRr$BHvJmN|dSdTdUdZ$(DSHSITZT[T\T]T^$B7+7Reheiej$(DU%$BMef1f2f=f?f@$(DUEUFVUV[V\$BB!K2gD(B\
$(DVsW($Bg_g`1p$(DY}Y~Z!Z"Z#Z$Z%Z&Z'Z($BAIAtMvi"i=i>i?i@iAiBiCiD$(DZE[e[f[g[h[i[j[k(B\
$(D[l[m$B3*5Bj$j7j8j9j:j;j<$(D\x$Bj~k!$(D]$$BGFk*$(D]/]0]1]2]?]@^D^E^F^G^H^I^J^K^L^M$B7Y<1(B\
$BIhkvkwkxkykzk{k|k}$(D_B$BlUlV$(D_V_W`8`9`:`;`<`=`>`?`@$B=3m,m-m.$(D`V`W$Bm@$(Da#a$a%a&a'(B\
$BE2m]mf$(Dbtbubvbw$BH0$(De<e=e>e?e@eAeBeCeDeEeFeGeHeIeJeKeLeM$B6@E-o2o3o4o5o6o7o8(B\
$Bo9o:o;$(Df>$Bop$(Dg*$BL8pFsS$(DgNgOgPgQ$Bpepf$(Dgggh$Bpkpn1$$(Dh0h1h2h3$B4jE?$(DhBhChchdhehfhghhhi(B\
$Bq9q:q;$(Dhzi>i?i@iAiBiCiD$BBMqY$(Dic$B?q$(Dj$j%j&j'j(j6jsjtjujvjwjxjyjzj{j|$B037_;*Bd(B\
$BrHrIrJrKrLrNrOrP$(Dkxkykzk{k|k}k~l!l"l#l$l%l&l'l($B7\L9s's(s)s+s,84$(Dld$BNoO<sJ(B\
$BsKsL$(Dlnlo$Bse$(Dm$m+m,m?mGmHmImXmY(B" ; 19
   "$BlWR0b_$(D6f6g6h$BSmSnT_Ta$(D::$BUPUQUR$(D:D:E$BUoMT$(D;w;x;y;z$B4`VZW-7|Xr$(DA;A<A=A>$BZ7$(DAW(B\
$(DAmBi$B['$(DBo$B[0$(DEVEWEXEYEZ$BH'Ms].$(DI2I3I4I5I6$B_O_P_Q_R$(DJBJC$B`$$(DJl$B`:$(DKL$B`[$(DLlLm$B`|$(DN.N/$Bax(B\
$(DNFPEPF$Bbhbjc)c*$(DQN$Bce6%$(DRsRtRu$B;<@RdVdYdy$(DT`$Bekelemeoepeqf"fA$(DUG$Bfd$(DV]$BgCgF$(DW)$Bga$(DZ)(B\
$(DZ*Z+Z,Z-Z.Z/Z0$B]"]1b<iEiFq^$(D[n[o[p[q[r[s$Bj>j?j@$(D\y\z$Bk"k#k$k4k=$(D^N^O^P^Q$B5D8n(B\
$B>yk~l!l"l#l%$(D^k^{$BlX$(D_X`A`B`C$Bm/m0m1m2m=$(Da(a)$Bm^$(DbSbxbybz$B>znSnTnY$(DeNeOePeQeReS(B\
$(DeTeUeVeWeXeYeZe[e\e]e^e_$B>bF*o<o=o>o?o@oAoE$(Df?f@fA$Boqp/$(Dg+$BpG$(DgRgSgTgigj$B6A$(Dh4(B\
$(Dh5hDhE$Bq(q)$(Dhjhkhl$Bq<q=3>$(DiEiFiGiHiIiJ$BF-qZq[$(Didiej)j*$Br,$(Dj}j~k!k"k#k$k%k&k'k((B\
$(Dk)k*k+k,k-$B3bOLrQrRrSrTrUrVrWrXrYrZr\$(Dl)l*l+l,l-l.l/l0$Bs*s-s.s/sD$(Dlelflplv(B\
$(Dlw$Bs]s^$(Dm5mJmKmL$Bsqsrssst$(DmZ(B" ; 20
   "$(D0B2c2d$BQ5Q6$(D2m3U3V4:6i$BSoSpSqSrSs$(D8e$BV$V[W+sMXuXvXw$(DA?$BYpZ8[([1$(DE[E\E]E^$B]/(B\
$B]0]2]S$(DI7I8I9I:I;I<$B^u$(DJD$B`%$(DLn$B`}ayaza{a|$(DO?PGPHPq$Bc:cT$(DQe$Bc^$(DRvRwRx$BdWdXd[d_dz$(DT_(B\
$(DTaTbTcTd$BE;eresetevezf#$(DU4UZV^$B4Ogb$(DZ1[t[u[v[w[x$BiZjAjB$(D\(\{$Bk%$(D]3^R^S^T^U$Bl$$(D_C(B\
$BlYl]Lvm3m4$(D`Xa*a+$B9lm_mg$(Db{$BnU$(De`eaebecedeeefegeh$BBxLzoBoCoDoF$(DfBfC$Boros$(Dg,$BO*pH(B\
$(Dg8gUgVgWgkh6h7hF$B8\q*fL$(Dhmhn$Bq>q?q@qAqB$(DiKiLiM$Bq\q]q_q`$(Dif$Bqp$(Dj+j,$Br#$(Dj7j8j=$BKbr5(B\
$(Dk.k/k0k1k2k3k4k5k6$B0sIIr[r]r^r_r`$(Dl1l2l3l4l5l6l7l8l9l:l;$BDarts0s1s2s3s4s5(B\
$Bs6s7s8$(DlYlZlxly$Bs_$(Dm-m.m/m6$BlZ$(DmMmN$Bsusv$(Dm[m`(B" ; 21
   "$BG9Q7Q8s|$(D6j6k6l6m$B7%StSu$(D7,$BjF$(D:;:<:F;|$BV\V]W>$(D="$BXt$(DA@AAABAC$BZ:$(DE_E`Ea$B\^]D$(DFG(B\
$(DI=I>$BFg_S$(DJEJFKMLoLt$BaHaI$(DN0N1$Ba}$(DPIPJ$BcUcfQ?$(DRyRzR{R|R}R~S!$BdFd\d]d{$(DTe$Beue|$(DTs$Bf$(B\
$Bf4fe$(DV_$Bgc$(DZ2Z3Z4Z5Z6$BiG$(D[y\|$Bk&k'k5k6$(D]A^V^W^X^Y$B;>l&$(D_D$Bl[l^$(D`D`E`F$Bm5m6m7m`$(Dakal(B\
$Bn6$(DbTbUeiejekelem$BoGoHoI$(Df!$BpIpJ$(DgX$Bpg$(Dh8$Bp|$(Dhohphq$B6BqC$(DiNiOiPiQiRiS$B6Cqaqb$(Digj-j.(B\
$Br$$(Dj1$Bdx$(Dk7k8k9k:k;k<k=k>k?$B17C-rMrarbrcrd$(Dl<l=l>l?l@lAlBlC$Bs9s:$(Dlglzl{l|m7m8(B\
$Bswsx$(Dm\$B=1O8$(Dma(B" ; 22
   "$(D3W6n6o6p8f;{$BV^$(D?$?%?&$BXx$(DAD$BYxZ;Z<ZN$(DBjBkEbEcEd$B]3$(DKNKOLpN2$Ba~$(DNGS"S#$Bd^d`$(DSJ(B\
$(DTf$BeweygG$(D[z[{[|[}$BjC$(D\}^Z^[^\$B=2l'l($(D^f`G`H$Bm8mamb$(Db|eneoepeqeres$B4UoJoKoLoMoT(B\
$(Dg-$BpT$(DgYgZh9$Bp}$(DhrhsiT$Bqcqd$(Dih$Bqqqrqsqt$(Dj/$Br%$(Dj>k@kAkBkCkDkEkFkGkHkI$B3oKpNZre$(DlDlE(B\
$(DlFlGlHlIlJlK$BOIs;s<s=s>sW$(Dl}$Bs`$(Dm9m:m@mA$Bpm$(DmOmPmQmRmS(B" ; 23
   "$Br6b`$(D6q$BSvSw$(D8]9";!?'$BZ0$(DBlI?I@LqN3$Bb!$(DO@$Bexf%f3$(DW*$Bgf$(DZ7Z8[~\!$BjDjE$(D\)$BjM$(D\~]!]"(B\
$(D^]^^$Bl)l*l+$(D_E`I`J$BmA$(Db}b~$BnV$(Deteu$BoN$(Dg.$BpKpLpMpN$(Dg[$Bphpi$(Dgl$Bp~$(DiU$Bqe$(Dii$Br&$(Dj2j?kJkKkLkM(B\
$(DkNkOkPkQ$Brfrg$(DlLlMlNlO$B:mBks?$(Dl[$BN[sg$(DmBmCmDmTmU$Bsyszs{(B" ; 24
   "$BW,$(DAEEeEf$B]4_T$(DJGM#OAS$S%S&$Bda$(DTgTh$Be{d|$(DV`$BgHjGk+k7$(D]B$Bl,$(D_'`K$Bm:$(Dc!$BnW$(Devewexey(B\
$(Dez$BoPpOq!$(Dij$Br'$(DkRkSkTlPlQlRlS$BsEsT$(Dl~m%$Bsh$(Dm0mVmb(B" ; 25
   "$(D<{$B15$(DFHIAIC$Bba$(DS'\"]#$Bl-$(D_Y`Lc"$BoQoR$(Dg/g0g1g\hthu$Bqf$(Dik$Br-$(DkUkV$Brhsa$(Dmc(B" ; 26
   "$(DIBTi^_^`^l_(`M$Bm9$(Da,c#$BoSoUoVq"q#$(DhG$Bqgqh$(DkW$Bri$(DlTlU$Bsb(B" ; 27
   "$(DEg^m$BoWoX$(Dhv$Bqi$(DlV$Bs@$(Dm!m;mWm_(B" ; 28
   "$B]6`&$(DTj^ae{e|$Bqk]5$(DlW$BsA(B" ; 29
   "$(D4RN4g]$Bqj$(DlX$BsB(B" ; 30
   0
   "$(DS(m](B" ; 32
   "$(DkXlhm^(B" ; 33
  ])

(defvar radical-query-jis
  '("$B4A;z(B" "$BIt<s2h?t(B" "$BIt<s(B" "$BAm2h?t(B" "$B2h(B" ; for radical-input
    "$B2h?t(B"))                               ; for stroke-input

(defvar radical-data-jis
  (list radical-table-jis radical-strokes-alist-jis strokes-table-jis
	radical-query-jis))

;;;
(provide 'radical-jis)

;;; radical-jis.el ends here
